// *** THIS FILE IS GENERATED - DO NOT EDIT ***
// See error_location_helper_generator.py for modifications

/***************************************************************************
 *
 * Copyright (c) 2023-2026 The Khronos Group Inc.
 * Copyright (c) 2023-2026 Valve Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ****************************************************************************/

// NOLINTBEGIN

#pragma once
#include <vulkan/vulkan.h>
#include "containers/small_vector.h"
#include "generated/vk_api_version.h"

namespace vvl {
enum class Func {
    Empty = 0,
    vkAcquireDrmDisplayEXT,
    vkAcquireFullScreenExclusiveModeEXT,
    vkAcquireNextImage2KHR,
    vkAcquireNextImageKHR,
    vkAcquirePerformanceConfigurationINTEL,
    vkAcquireProfilingLockKHR,
    vkAcquireWinrtDisplayNV,
    vkAcquireXlibDisplayEXT,
    vkAllocateCommandBuffers,
    vkAllocateDescriptorSets,
    vkAllocateMemory,
    vkAntiLagUpdateAMD,
    vkBeginCommandBuffer,
    vkBindAccelerationStructureMemoryNV,
    vkBindBufferMemory,
    vkBindBufferMemory2,
    vkBindBufferMemory2KHR,
    vkBindDataGraphPipelineSessionMemoryARM,
    vkBindImageMemory,
    vkBindImageMemory2,
    vkBindImageMemory2KHR,
    vkBindOpticalFlowSessionImageNV,
    vkBindTensorMemoryARM,
    vkBindVideoSessionMemoryKHR,
    vkBuildAccelerationStructuresKHR,
    vkBuildMicromapsEXT,
    vkClearShaderInstrumentationMetricsARM,
    vkCmdBeginConditionalRendering2EXT,
    vkCmdBeginConditionalRenderingEXT,
    vkCmdBeginCustomResolveEXT,
    vkCmdBeginDebugUtilsLabelEXT,
    vkCmdBeginGpaSampleAMD,
    vkCmdBeginGpaSessionAMD,
    vkCmdBeginPerTileExecutionQCOM,
    vkCmdBeginQuery,
    vkCmdBeginQueryIndexedEXT,
    vkCmdBeginRenderPass,
    vkCmdBeginRenderPass2,
    vkCmdBeginRenderPass2KHR,
    vkCmdBeginRendering,
    vkCmdBeginRenderingKHR,
    vkCmdBeginShaderInstrumentationARM,
    vkCmdBeginTransformFeedback2EXT,
    vkCmdBeginTransformFeedbackEXT,
    vkCmdBeginVideoCodingKHR,
    vkCmdBindDescriptorBufferEmbeddedSamplers2EXT,
    vkCmdBindDescriptorBufferEmbeddedSamplersEXT,
    vkCmdBindDescriptorBuffersEXT,
    vkCmdBindDescriptorSets,
    vkCmdBindDescriptorSets2,
    vkCmdBindDescriptorSets2KHR,
    vkCmdBindIndexBuffer,
    vkCmdBindIndexBuffer2,
    vkCmdBindIndexBuffer2KHR,
    vkCmdBindIndexBuffer3KHR,
    vkCmdBindInvocationMaskHUAWEI,
    vkCmdBindPipeline,
    vkCmdBindPipelineShaderGroupNV,
    vkCmdBindResourceHeapEXT,
    vkCmdBindSamplerHeapEXT,
    vkCmdBindShadersEXT,
    vkCmdBindShadingRateImageNV,
    vkCmdBindTileMemoryQCOM,
    vkCmdBindTransformFeedbackBuffers2EXT,
    vkCmdBindTransformFeedbackBuffersEXT,
    vkCmdBindVertexBuffers,
    vkCmdBindVertexBuffers2,
    vkCmdBindVertexBuffers2EXT,
    vkCmdBindVertexBuffers3KHR,
    vkCmdBlitImage,
    vkCmdBlitImage2,
    vkCmdBlitImage2KHR,
    vkCmdBuildAccelerationStructureNV,
    vkCmdBuildAccelerationStructuresIndirectKHR,
    vkCmdBuildAccelerationStructuresKHR,
    vkCmdBuildClusterAccelerationStructureIndirectNV,
    vkCmdBuildMicromapsEXT,
    vkCmdBuildPartitionedAccelerationStructuresNV,
    vkCmdClearAttachments,
    vkCmdClearColorImage,
    vkCmdClearDepthStencilImage,
    vkCmdControlVideoCodingKHR,
    vkCmdConvertCooperativeVectorMatrixNV,
    vkCmdCopyAccelerationStructureKHR,
    vkCmdCopyAccelerationStructureNV,
    vkCmdCopyAccelerationStructureToMemoryKHR,
    vkCmdCopyBuffer,
    vkCmdCopyBuffer2,
    vkCmdCopyBuffer2KHR,
    vkCmdCopyBufferToImage,
    vkCmdCopyBufferToImage2,
    vkCmdCopyBufferToImage2KHR,
    vkCmdCopyGpaSessionResultsAMD,
    vkCmdCopyImage,
    vkCmdCopyImage2,
    vkCmdCopyImage2KHR,
    vkCmdCopyImageToBuffer,
    vkCmdCopyImageToBuffer2,
    vkCmdCopyImageToBuffer2KHR,
    vkCmdCopyImageToMemoryKHR,
    vkCmdCopyMemoryIndirectKHR,
    vkCmdCopyMemoryIndirectNV,
    vkCmdCopyMemoryKHR,
    vkCmdCopyMemoryToAccelerationStructureKHR,
    vkCmdCopyMemoryToImageIndirectKHR,
    vkCmdCopyMemoryToImageIndirectNV,
    vkCmdCopyMemoryToImageKHR,
    vkCmdCopyMemoryToMicromapEXT,
    vkCmdCopyMicromapEXT,
    vkCmdCopyMicromapToMemoryEXT,
    vkCmdCopyQueryPoolResults,
    vkCmdCopyQueryPoolResultsToMemoryKHR,
    vkCmdCopyTensorARM,
    vkCmdCuLaunchKernelNVX,
    vkCmdCudaLaunchKernelNV,
    vkCmdDebugMarkerBeginEXT,
    vkCmdDebugMarkerEndEXT,
    vkCmdDebugMarkerInsertEXT,
    vkCmdDecodeVideoKHR,
    vkCmdDecompressMemoryEXT,
    vkCmdDecompressMemoryIndirectCountEXT,
    vkCmdDecompressMemoryIndirectCountNV,
    vkCmdDecompressMemoryNV,
    vkCmdDispatch,
    vkCmdDispatchBase,
    vkCmdDispatchBaseKHR,
    vkCmdDispatchDataGraphARM,
    vkCmdDispatchGraphAMDX,
    vkCmdDispatchGraphIndirectAMDX,
    vkCmdDispatchGraphIndirectCountAMDX,
    vkCmdDispatchIndirect,
    vkCmdDispatchIndirect2KHR,
    vkCmdDispatchTileQCOM,
    vkCmdDraw,
    vkCmdDrawClusterHUAWEI,
    vkCmdDrawClusterIndirectHUAWEI,
    vkCmdDrawIndexed,
    vkCmdDrawIndexedIndirect,
    vkCmdDrawIndexedIndirect2KHR,
    vkCmdDrawIndexedIndirectCount,
    vkCmdDrawIndexedIndirectCount2KHR,
    vkCmdDrawIndexedIndirectCountAMD,
    vkCmdDrawIndexedIndirectCountKHR,
    vkCmdDrawIndirect,
    vkCmdDrawIndirect2KHR,
    vkCmdDrawIndirectByteCount2EXT,
    vkCmdDrawIndirectByteCountEXT,
    vkCmdDrawIndirectCount,
    vkCmdDrawIndirectCount2KHR,
    vkCmdDrawIndirectCountAMD,
    vkCmdDrawIndirectCountKHR,
    vkCmdDrawMeshTasksEXT,
    vkCmdDrawMeshTasksIndirect2EXT,
    vkCmdDrawMeshTasksIndirectCount2EXT,
    vkCmdDrawMeshTasksIndirectCountEXT,
    vkCmdDrawMeshTasksIndirectCountNV,
    vkCmdDrawMeshTasksIndirectEXT,
    vkCmdDrawMeshTasksIndirectNV,
    vkCmdDrawMeshTasksNV,
    vkCmdDrawMultiEXT,
    vkCmdDrawMultiIndexedEXT,
    vkCmdEncodeVideoKHR,
    vkCmdEndConditionalRenderingEXT,
    vkCmdEndDebugUtilsLabelEXT,
    vkCmdEndGpaSampleAMD,
    vkCmdEndGpaSessionAMD,
    vkCmdEndPerTileExecutionQCOM,
    vkCmdEndQuery,
    vkCmdEndQueryIndexedEXT,
    vkCmdEndRenderPass,
    vkCmdEndRenderPass2,
    vkCmdEndRenderPass2KHR,
    vkCmdEndRendering,
    vkCmdEndRendering2EXT,
    vkCmdEndRendering2KHR,
    vkCmdEndRenderingKHR,
    vkCmdEndShaderInstrumentationARM,
    vkCmdEndTransformFeedback2EXT,
    vkCmdEndTransformFeedbackEXT,
    vkCmdEndVideoCodingKHR,
    vkCmdExecuteCommands,
    vkCmdExecuteGeneratedCommandsEXT,
    vkCmdExecuteGeneratedCommandsNV,
    vkCmdFillBuffer,
    vkCmdFillMemoryKHR,
    vkCmdInitializeGraphScratchMemoryAMDX,
    vkCmdInsertDebugUtilsLabelEXT,
    vkCmdNextSubpass,
    vkCmdNextSubpass2,
    vkCmdNextSubpass2KHR,
    vkCmdOpticalFlowExecuteNV,
    vkCmdPipelineBarrier,
    vkCmdPipelineBarrier2,
    vkCmdPipelineBarrier2KHR,
    vkCmdPreprocessGeneratedCommandsEXT,
    vkCmdPreprocessGeneratedCommandsNV,
    vkCmdPushConstants,
    vkCmdPushConstants2,
    vkCmdPushConstants2KHR,
    vkCmdPushDataEXT,
    vkCmdPushDescriptorSet,
    vkCmdPushDescriptorSet2,
    vkCmdPushDescriptorSet2KHR,
    vkCmdPushDescriptorSetKHR,
    vkCmdPushDescriptorSetWithTemplate,
    vkCmdPushDescriptorSetWithTemplate2,
    vkCmdPushDescriptorSetWithTemplate2KHR,
    vkCmdPushDescriptorSetWithTemplateKHR,
    vkCmdResetEvent,
    vkCmdResetEvent2,
    vkCmdResetEvent2KHR,
    vkCmdResetQueryPool,
    vkCmdResolveImage,
    vkCmdResolveImage2,
    vkCmdResolveImage2KHR,
    vkCmdSetAlphaToCoverageEnableEXT,
    vkCmdSetAlphaToOneEnableEXT,
    vkCmdSetAttachmentFeedbackLoopEnableEXT,
    vkCmdSetBlendConstants,
    vkCmdSetCheckpointNV,
    vkCmdSetCoarseSampleOrderNV,
    vkCmdSetColorBlendAdvancedEXT,
    vkCmdSetColorBlendEnableEXT,
    vkCmdSetColorBlendEquationEXT,
    vkCmdSetColorWriteEnableEXT,
    vkCmdSetColorWriteMaskEXT,
    vkCmdSetComputeOccupancyPriorityNV,
    vkCmdSetConservativeRasterizationModeEXT,
    vkCmdSetCoverageModulationModeNV,
    vkCmdSetCoverageModulationTableEnableNV,
    vkCmdSetCoverageModulationTableNV,
    vkCmdSetCoverageReductionModeNV,
    vkCmdSetCoverageToColorEnableNV,
    vkCmdSetCoverageToColorLocationNV,
    vkCmdSetCullMode,
    vkCmdSetCullModeEXT,
    vkCmdSetDepthBias,
    vkCmdSetDepthBias2EXT,
    vkCmdSetDepthBiasEnable,
    vkCmdSetDepthBiasEnableEXT,
    vkCmdSetDepthBounds,
    vkCmdSetDepthBoundsTestEnable,
    vkCmdSetDepthBoundsTestEnableEXT,
    vkCmdSetDepthClampEnableEXT,
    vkCmdSetDepthClampRangeEXT,
    vkCmdSetDepthClipEnableEXT,
    vkCmdSetDepthClipNegativeOneToOneEXT,
    vkCmdSetDepthCompareOp,
    vkCmdSetDepthCompareOpEXT,
    vkCmdSetDepthTestEnable,
    vkCmdSetDepthTestEnableEXT,
    vkCmdSetDepthWriteEnable,
    vkCmdSetDepthWriteEnableEXT,
    vkCmdSetDescriptorBufferOffsets2EXT,
    vkCmdSetDescriptorBufferOffsetsEXT,
    vkCmdSetDeviceMask,
    vkCmdSetDeviceMaskKHR,
    vkCmdSetDiscardRectangleEXT,
    vkCmdSetDiscardRectangleEnableEXT,
    vkCmdSetDiscardRectangleModeEXT,
    vkCmdSetDispatchParametersARM,
    vkCmdSetEvent,
    vkCmdSetEvent2,
    vkCmdSetEvent2KHR,
    vkCmdSetExclusiveScissorEnableNV,
    vkCmdSetExclusiveScissorNV,
    vkCmdSetExtraPrimitiveOverestimationSizeEXT,
    vkCmdSetFragmentShadingRateEnumNV,
    vkCmdSetFragmentShadingRateKHR,
    vkCmdSetFrontFace,
    vkCmdSetFrontFaceEXT,
    vkCmdSetLineRasterizationModeEXT,
    vkCmdSetLineStipple,
    vkCmdSetLineStippleEXT,
    vkCmdSetLineStippleEnableEXT,
    vkCmdSetLineStippleKHR,
    vkCmdSetLineWidth,
    vkCmdSetLogicOpEXT,
    vkCmdSetLogicOpEnableEXT,
    vkCmdSetPatchControlPointsEXT,
    vkCmdSetPerformanceMarkerINTEL,
    vkCmdSetPerformanceOverrideINTEL,
    vkCmdSetPerformanceStreamMarkerINTEL,
    vkCmdSetPolygonModeEXT,
    vkCmdSetPrimitiveRestartEnable,
    vkCmdSetPrimitiveRestartEnableEXT,
    vkCmdSetPrimitiveRestartIndexEXT,
    vkCmdSetPrimitiveTopology,
    vkCmdSetPrimitiveTopologyEXT,
    vkCmdSetProvokingVertexModeEXT,
    vkCmdSetRasterizationSamplesEXT,
    vkCmdSetRasterizationStreamEXT,
    vkCmdSetRasterizerDiscardEnable,
    vkCmdSetRasterizerDiscardEnableEXT,
    vkCmdSetRayTracingPipelineStackSizeKHR,
    vkCmdSetRenderingAttachmentLocations,
    vkCmdSetRenderingAttachmentLocationsKHR,
    vkCmdSetRenderingInputAttachmentIndices,
    vkCmdSetRenderingInputAttachmentIndicesKHR,
    vkCmdSetRepresentativeFragmentTestEnableNV,
    vkCmdSetSampleLocationsEXT,
    vkCmdSetSampleLocationsEnableEXT,
    vkCmdSetSampleMaskEXT,
    vkCmdSetScissor,
    vkCmdSetScissorWithCount,
    vkCmdSetScissorWithCountEXT,
    vkCmdSetShadingRateImageEnableNV,
    vkCmdSetStencilCompareMask,
    vkCmdSetStencilOp,
    vkCmdSetStencilOpEXT,
    vkCmdSetStencilReference,
    vkCmdSetStencilTestEnable,
    vkCmdSetStencilTestEnableEXT,
    vkCmdSetStencilWriteMask,
    vkCmdSetTessellationDomainOriginEXT,
    vkCmdSetVertexInputEXT,
    vkCmdSetViewport,
    vkCmdSetViewportShadingRatePaletteNV,
    vkCmdSetViewportSwizzleNV,
    vkCmdSetViewportWScalingEnableNV,
    vkCmdSetViewportWScalingNV,
    vkCmdSetViewportWithCount,
    vkCmdSetViewportWithCountEXT,
    vkCmdSubpassShadingHUAWEI,
    vkCmdTraceRaysIndirect2KHR,
    vkCmdTraceRaysIndirectKHR,
    vkCmdTraceRaysKHR,
    vkCmdTraceRaysNV,
    vkCmdUpdateBuffer,
    vkCmdUpdateMemoryKHR,
    vkCmdUpdatePipelineIndirectBufferNV,
    vkCmdWaitEvents,
    vkCmdWaitEvents2,
    vkCmdWaitEvents2KHR,
    vkCmdWriteAccelerationStructuresPropertiesKHR,
    vkCmdWriteAccelerationStructuresPropertiesNV,
    vkCmdWriteBufferMarker2AMD,
    vkCmdWriteBufferMarkerAMD,
    vkCmdWriteMarkerToMemoryAMD,
    vkCmdWriteMicromapsPropertiesEXT,
    vkCmdWriteTimestamp,
    vkCmdWriteTimestamp2,
    vkCmdWriteTimestamp2KHR,
    vkCompileDeferredNV,
    vkConvertCooperativeVectorMatrixNV,
    vkCopyAccelerationStructureKHR,
    vkCopyAccelerationStructureToMemoryKHR,
    vkCopyImageToImage,
    vkCopyImageToImageEXT,
    vkCopyImageToMemory,
    vkCopyImageToMemoryEXT,
    vkCopyMemoryToAccelerationStructureKHR,
    vkCopyMemoryToImage,
    vkCopyMemoryToImageEXT,
    vkCopyMemoryToMicromapEXT,
    vkCopyMicromapEXT,
    vkCopyMicromapToMemoryEXT,
    vkCreateAccelerationStructure2KHR,
    vkCreateAccelerationStructureKHR,
    vkCreateAccelerationStructureNV,
    vkCreateAndroidSurfaceKHR,
    vkCreateBuffer,
    vkCreateBufferCollectionFUCHSIA,
    vkCreateBufferView,
    vkCreateCommandPool,
    vkCreateComputePipelines,
    vkCreateCuFunctionNVX,
    vkCreateCuModuleNVX,
    vkCreateCudaFunctionNV,
    vkCreateCudaModuleNV,
    vkCreateDataGraphPipelineSessionARM,
    vkCreateDataGraphPipelinesARM,
    vkCreateDebugReportCallbackEXT,
    vkCreateDebugUtilsMessengerEXT,
    vkCreateDeferredOperationKHR,
    vkCreateDescriptorPool,
    vkCreateDescriptorSetLayout,
    vkCreateDescriptorUpdateTemplate,
    vkCreateDescriptorUpdateTemplateKHR,
    vkCreateDevice,
    vkCreateDirectFBSurfaceEXT,
    vkCreateDisplayModeKHR,
    vkCreateDisplayPlaneSurfaceKHR,
    vkCreateEvent,
    vkCreateExecutionGraphPipelinesAMDX,
    vkCreateExternalComputeQueueNV,
    vkCreateFence,
    vkCreateFramebuffer,
    vkCreateGpaSessionAMD,
    vkCreateGraphicsPipelines,
    vkCreateHeadlessSurfaceEXT,
    vkCreateIOSSurfaceMVK,
    vkCreateImage,
    vkCreateImagePipeSurfaceFUCHSIA,
    vkCreateImageView,
    vkCreateIndirectCommandsLayoutEXT,
    vkCreateIndirectCommandsLayoutNV,
    vkCreateIndirectExecutionSetEXT,
    vkCreateInstance,
    vkCreateMacOSSurfaceMVK,
    vkCreateMetalSurfaceEXT,
    vkCreateMicromapEXT,
    vkCreateOpticalFlowSessionNV,
    vkCreatePipelineBinariesKHR,
    vkCreatePipelineCache,
    vkCreatePipelineLayout,
    vkCreatePrivateDataSlot,
    vkCreatePrivateDataSlotEXT,
    vkCreateQueryPool,
    vkCreateRayTracingPipelinesKHR,
    vkCreateRayTracingPipelinesNV,
    vkCreateRenderPass,
    vkCreateRenderPass2,
    vkCreateRenderPass2KHR,
    vkCreateSampler,
    vkCreateSamplerYcbcrConversion,
    vkCreateSamplerYcbcrConversionKHR,
    vkCreateScreenSurfaceQNX,
    vkCreateSemaphore,
    vkCreateShaderInstrumentationARM,
    vkCreateShaderModule,
    vkCreateShadersEXT,
    vkCreateSharedSwapchainsKHR,
    vkCreateStreamDescriptorSurfaceGGP,
    vkCreateSurfaceOHOS,
    vkCreateSwapchainKHR,
    vkCreateTensorARM,
    vkCreateTensorViewARM,
    vkCreateUbmSurfaceSEC,
    vkCreateValidationCacheEXT,
    vkCreateViSurfaceNN,
    vkCreateVideoSessionKHR,
    vkCreateVideoSessionParametersKHR,
    vkCreateWaylandSurfaceKHR,
    vkCreateWin32SurfaceKHR,
    vkCreateXcbSurfaceKHR,
    vkCreateXlibSurfaceKHR,
    vkDebugMarkerSetObjectNameEXT,
    vkDebugMarkerSetObjectTagEXT,
    vkDebugReportMessageEXT,
    vkDeferredOperationJoinKHR,
    vkDestroyAccelerationStructureKHR,
    vkDestroyAccelerationStructureNV,
    vkDestroyBuffer,
    vkDestroyBufferCollectionFUCHSIA,
    vkDestroyBufferView,
    vkDestroyCommandPool,
    vkDestroyCuFunctionNVX,
    vkDestroyCuModuleNVX,
    vkDestroyCudaFunctionNV,
    vkDestroyCudaModuleNV,
    vkDestroyDataGraphPipelineSessionARM,
    vkDestroyDebugReportCallbackEXT,
    vkDestroyDebugUtilsMessengerEXT,
    vkDestroyDeferredOperationKHR,
    vkDestroyDescriptorPool,
    vkDestroyDescriptorSetLayout,
    vkDestroyDescriptorUpdateTemplate,
    vkDestroyDescriptorUpdateTemplateKHR,
    vkDestroyDevice,
    vkDestroyEvent,
    vkDestroyExternalComputeQueueNV,
    vkDestroyFence,
    vkDestroyFramebuffer,
    vkDestroyGpaSessionAMD,
    vkDestroyImage,
    vkDestroyImageView,
    vkDestroyIndirectCommandsLayoutEXT,
    vkDestroyIndirectCommandsLayoutNV,
    vkDestroyIndirectExecutionSetEXT,
    vkDestroyInstance,
    vkDestroyMicromapEXT,
    vkDestroyOpticalFlowSessionNV,
    vkDestroyPipeline,
    vkDestroyPipelineBinaryKHR,
    vkDestroyPipelineCache,
    vkDestroyPipelineLayout,
    vkDestroyPrivateDataSlot,
    vkDestroyPrivateDataSlotEXT,
    vkDestroyQueryPool,
    vkDestroyRenderPass,
    vkDestroySampler,
    vkDestroySamplerYcbcrConversion,
    vkDestroySamplerYcbcrConversionKHR,
    vkDestroySemaphore,
    vkDestroyShaderEXT,
    vkDestroyShaderInstrumentationARM,
    vkDestroyShaderModule,
    vkDestroySurfaceKHR,
    vkDestroySwapchainKHR,
    vkDestroyTensorARM,
    vkDestroyTensorViewARM,
    vkDestroyValidationCacheEXT,
    vkDestroyVideoSessionKHR,
    vkDestroyVideoSessionParametersKHR,
    vkDeviceWaitIdle,
    vkDisplayPowerControlEXT,
    vkEndCommandBuffer,
    vkEnumerateDeviceExtensionProperties,
    vkEnumerateDeviceLayerProperties,
    vkEnumerateInstanceExtensionProperties,
    vkEnumerateInstanceLayerProperties,
    vkEnumerateInstanceVersion,
    vkEnumeratePhysicalDeviceGroups,
    vkEnumeratePhysicalDeviceGroupsKHR,
    vkEnumeratePhysicalDeviceQueueFamilyPerformanceCountersByRegionARM,
    vkEnumeratePhysicalDeviceQueueFamilyPerformanceQueryCountersKHR,
    vkEnumeratePhysicalDeviceShaderInstrumentationMetricsARM,
    vkEnumeratePhysicalDevices,
    vkExportMetalObjectsEXT,
    vkFlushMappedMemoryRanges,
    vkFreeCommandBuffers,
    vkFreeDescriptorSets,
    vkFreeMemory,
    vkGetAccelerationStructureBuildSizesKHR,
    vkGetAccelerationStructureDeviceAddressKHR,
    vkGetAccelerationStructureHandleNV,
    vkGetAccelerationStructureMemoryRequirementsNV,
    vkGetAccelerationStructureOpaqueCaptureDescriptorDataEXT,
    vkGetAndroidHardwareBufferPropertiesANDROID,
    vkGetBufferCollectionPropertiesFUCHSIA,
    vkGetBufferDeviceAddress,
    vkGetBufferDeviceAddressEXT,
    vkGetBufferDeviceAddressKHR,
    vkGetBufferMemoryRequirements,
    vkGetBufferMemoryRequirements2,
    vkGetBufferMemoryRequirements2KHR,
    vkGetBufferOpaqueCaptureAddress,
    vkGetBufferOpaqueCaptureAddressKHR,
    vkGetBufferOpaqueCaptureDescriptorDataEXT,
    vkGetCalibratedTimestampsEXT,
    vkGetCalibratedTimestampsKHR,
    vkGetClusterAccelerationStructureBuildSizesNV,
    vkGetCudaModuleCacheNV,
    vkGetDataGraphPipelineAvailablePropertiesARM,
    vkGetDataGraphPipelinePropertiesARM,
    vkGetDataGraphPipelineSessionBindPointRequirementsARM,
    vkGetDataGraphPipelineSessionMemoryRequirementsARM,
    vkGetDeferredOperationMaxConcurrencyKHR,
    vkGetDeferredOperationResultKHR,
    vkGetDescriptorEXT,
    vkGetDescriptorSetHostMappingVALVE,
    vkGetDescriptorSetLayoutBindingOffsetEXT,
    vkGetDescriptorSetLayoutHostMappingInfoVALVE,
    vkGetDescriptorSetLayoutSizeEXT,
    vkGetDescriptorSetLayoutSupport,
    vkGetDescriptorSetLayoutSupportKHR,
    vkGetDeviceAccelerationStructureCompatibilityKHR,
    vkGetDeviceBufferMemoryRequirements,
    vkGetDeviceBufferMemoryRequirementsKHR,
    vkGetDeviceCombinedImageSamplerIndexNVX,
    vkGetDeviceFaultDebugInfoKHR,
    vkGetDeviceFaultInfoEXT,
    vkGetDeviceFaultReportsKHR,
    vkGetDeviceGroupPeerMemoryFeatures,
    vkGetDeviceGroupPeerMemoryFeaturesKHR,
    vkGetDeviceGroupPresentCapabilitiesKHR,
    vkGetDeviceGroupSurfacePresentModes2EXT,
    vkGetDeviceGroupSurfacePresentModesKHR,
    vkGetDeviceImageMemoryRequirements,
    vkGetDeviceImageMemoryRequirementsKHR,
    vkGetDeviceImageSparseMemoryRequirements,
    vkGetDeviceImageSparseMemoryRequirementsKHR,
    vkGetDeviceImageSubresourceLayout,
    vkGetDeviceImageSubresourceLayoutKHR,
    vkGetDeviceMemoryCommitment,
    vkGetDeviceMemoryOpaqueCaptureAddress,
    vkGetDeviceMemoryOpaqueCaptureAddressKHR,
    vkGetDeviceMicromapCompatibilityEXT,
    vkGetDeviceProcAddr,
    vkGetDeviceQueue,
    vkGetDeviceQueue2,
    vkGetDeviceSubpassShadingMaxWorkgroupSizeHUAWEI,
    vkGetDeviceTensorMemoryRequirementsARM,
    vkGetDisplayModeProperties2KHR,
    vkGetDisplayModePropertiesKHR,
    vkGetDisplayPlaneCapabilities2KHR,
    vkGetDisplayPlaneCapabilitiesKHR,
    vkGetDisplayPlaneSupportedDisplaysKHR,
    vkGetDrmDisplayEXT,
    vkGetDynamicRenderingTilePropertiesQCOM,
    vkGetEncodedVideoSessionParametersKHR,
    vkGetEventStatus,
    vkGetExecutionGraphPipelineNodeIndexAMDX,
    vkGetExecutionGraphPipelineScratchSizeAMDX,
    vkGetExternalComputeQueueDataNV,
    vkGetFenceFdKHR,
    vkGetFenceStatus,
    vkGetFenceWin32HandleKHR,
    vkGetFramebufferTilePropertiesQCOM,
    vkGetGeneratedCommandsMemoryRequirementsEXT,
    vkGetGeneratedCommandsMemoryRequirementsNV,
    vkGetGpaDeviceClockInfoAMD,
    vkGetGpaSessionResultsAMD,
    vkGetGpaSessionStatusAMD,
    vkGetImageDrmFormatModifierPropertiesEXT,
    vkGetImageMemoryRequirements,
    vkGetImageMemoryRequirements2,
    vkGetImageMemoryRequirements2KHR,
    vkGetImageOpaqueCaptureDataEXT,
    vkGetImageOpaqueCaptureDescriptorDataEXT,
    vkGetImageSparseMemoryRequirements,
    vkGetImageSparseMemoryRequirements2,
    vkGetImageSparseMemoryRequirements2KHR,
    vkGetImageSubresourceLayout,
    vkGetImageSubresourceLayout2,
    vkGetImageSubresourceLayout2EXT,
    vkGetImageSubresourceLayout2KHR,
    vkGetImageViewAddressNVX,
    vkGetImageViewHandle64NVX,
    vkGetImageViewHandleNVX,
    vkGetImageViewOpaqueCaptureDescriptorDataEXT,
    vkGetInstanceProcAddr,
    vkGetLatencyTimingsLegacyNV,
    vkGetLatencyTimingsNV,
    vkGetMemoryAndroidHardwareBufferANDROID,
    vkGetMemoryFdKHR,
    vkGetMemoryFdPropertiesKHR,
    vkGetMemoryHostPointerPropertiesEXT,
    vkGetMemoryMetalHandleEXT,
    vkGetMemoryMetalHandlePropertiesEXT,
    vkGetMemoryNativeBufferOHOS,
    vkGetMemoryRemoteAddressNV,
    vkGetMemoryWin32HandleKHR,
    vkGetMemoryWin32HandleNV,
    vkGetMemoryWin32HandlePropertiesKHR,
    vkGetMemoryZirconHandleFUCHSIA,
    vkGetMemoryZirconHandlePropertiesFUCHSIA,
    vkGetMicromapBuildSizesEXT,
    vkGetNativeBufferPropertiesOHOS,
    vkGetPartitionedAccelerationStructuresBuildSizesNV,
    vkGetPastPresentationTimingEXT,
    vkGetPastPresentationTimingGOOGLE,
    vkGetPerformanceParameterINTEL,
    vkGetPhysicalDeviceCalibrateableTimeDomainsEXT,
    vkGetPhysicalDeviceCalibrateableTimeDomainsKHR,
    vkGetPhysicalDeviceCooperativeMatrixFlexibleDimensionsPropertiesNV,
    vkGetPhysicalDeviceCooperativeMatrixPropertiesKHR,
    vkGetPhysicalDeviceCooperativeMatrixPropertiesNV,
    vkGetPhysicalDeviceCooperativeVectorPropertiesNV,
    vkGetPhysicalDeviceDescriptorSizeEXT,
    vkGetPhysicalDeviceDirectFBPresentationSupportEXT,
    vkGetPhysicalDeviceDisplayPlaneProperties2KHR,
    vkGetPhysicalDeviceDisplayPlanePropertiesKHR,
    vkGetPhysicalDeviceDisplayProperties2KHR,
    vkGetPhysicalDeviceDisplayPropertiesKHR,
    vkGetPhysicalDeviceExternalBufferProperties,
    vkGetPhysicalDeviceExternalBufferPropertiesKHR,
    vkGetPhysicalDeviceExternalFenceProperties,
    vkGetPhysicalDeviceExternalFencePropertiesKHR,
    vkGetPhysicalDeviceExternalImageFormatPropertiesNV,
    vkGetPhysicalDeviceExternalSemaphoreProperties,
    vkGetPhysicalDeviceExternalSemaphorePropertiesKHR,
    vkGetPhysicalDeviceExternalTensorPropertiesARM,
    vkGetPhysicalDeviceFeatures,
    vkGetPhysicalDeviceFeatures2,
    vkGetPhysicalDeviceFeatures2KHR,
    vkGetPhysicalDeviceFormatProperties,
    vkGetPhysicalDeviceFormatProperties2,
    vkGetPhysicalDeviceFormatProperties2KHR,
    vkGetPhysicalDeviceFragmentShadingRatesKHR,
    vkGetPhysicalDeviceImageFormatProperties,
    vkGetPhysicalDeviceImageFormatProperties2,
    vkGetPhysicalDeviceImageFormatProperties2KHR,
    vkGetPhysicalDeviceMemoryProperties,
    vkGetPhysicalDeviceMemoryProperties2,
    vkGetPhysicalDeviceMemoryProperties2KHR,
    vkGetPhysicalDeviceMultisamplePropertiesEXT,
    vkGetPhysicalDeviceOpticalFlowImageFormatsNV,
    vkGetPhysicalDevicePresentRectanglesKHR,
    vkGetPhysicalDeviceProperties,
    vkGetPhysicalDeviceProperties2,
    vkGetPhysicalDeviceProperties2KHR,
    vkGetPhysicalDeviceQueueFamilyDataGraphEngineOperationPropertiesARM,
    vkGetPhysicalDeviceQueueFamilyDataGraphOpticalFlowImageFormatsARM,
    vkGetPhysicalDeviceQueueFamilyDataGraphProcessingEnginePropertiesARM,
    vkGetPhysicalDeviceQueueFamilyDataGraphPropertiesARM,
    vkGetPhysicalDeviceQueueFamilyPerformanceQueryPassesKHR,
    vkGetPhysicalDeviceQueueFamilyProperties,
    vkGetPhysicalDeviceQueueFamilyProperties2,
    vkGetPhysicalDeviceQueueFamilyProperties2KHR,
    vkGetPhysicalDeviceScreenPresentationSupportQNX,
    vkGetPhysicalDeviceSparseImageFormatProperties,
    vkGetPhysicalDeviceSparseImageFormatProperties2,
    vkGetPhysicalDeviceSparseImageFormatProperties2KHR,
    vkGetPhysicalDeviceSupportedFramebufferMixedSamplesCombinationsNV,
    vkGetPhysicalDeviceSurfaceCapabilities2EXT,
    vkGetPhysicalDeviceSurfaceCapabilities2KHR,
    vkGetPhysicalDeviceSurfaceCapabilitiesKHR,
    vkGetPhysicalDeviceSurfaceFormats2KHR,
    vkGetPhysicalDeviceSurfaceFormatsKHR,
    vkGetPhysicalDeviceSurfacePresentModes2EXT,
    vkGetPhysicalDeviceSurfacePresentModesKHR,
    vkGetPhysicalDeviceSurfaceSupportKHR,
    vkGetPhysicalDeviceToolProperties,
    vkGetPhysicalDeviceToolPropertiesEXT,
    vkGetPhysicalDeviceUbmPresentationSupportSEC,
    vkGetPhysicalDeviceVideoCapabilitiesKHR,
    vkGetPhysicalDeviceVideoEncodeQualityLevelPropertiesKHR,
    vkGetPhysicalDeviceVideoFormatPropertiesKHR,
    vkGetPhysicalDeviceWaylandPresentationSupportKHR,
    vkGetPhysicalDeviceWin32PresentationSupportKHR,
    vkGetPhysicalDeviceXcbPresentationSupportKHR,
    vkGetPhysicalDeviceXlibPresentationSupportKHR,
    vkGetPipelineBinaryDataKHR,
    vkGetPipelineCacheData,
    vkGetPipelineExecutableInternalRepresentationsKHR,
    vkGetPipelineExecutablePropertiesKHR,
    vkGetPipelineExecutableStatisticsKHR,
    vkGetPipelineIndirectDeviceAddressNV,
    vkGetPipelineIndirectMemoryRequirementsNV,
    vkGetPipelineKeyKHR,
    vkGetPipelinePropertiesEXT,
    vkGetPrivateData,
    vkGetPrivateDataEXT,
    vkGetQueryPoolResults,
    vkGetQueueCheckpointData2NV,
    vkGetQueueCheckpointDataNV,
    vkGetRandROutputDisplayEXT,
    vkGetRayTracingCaptureReplayShaderGroupHandlesKHR,
    vkGetRayTracingShaderGroupHandlesKHR,
    vkGetRayTracingShaderGroupHandlesNV,
    vkGetRayTracingShaderGroupStackSizeKHR,
    vkGetRefreshCycleDurationGOOGLE,
    vkGetRenderAreaGranularity,
    vkGetRenderingAreaGranularity,
    vkGetRenderingAreaGranularityKHR,
    vkGetSamplerOpaqueCaptureDescriptorDataEXT,
    vkGetScreenBufferPropertiesQNX,
    vkGetSemaphoreCounterValue,
    vkGetSemaphoreCounterValueKHR,
    vkGetSemaphoreFdKHR,
    vkGetSemaphoreWin32HandleKHR,
    vkGetSemaphoreZirconHandleFUCHSIA,
    vkGetShaderBinaryDataEXT,
    vkGetShaderInfoAMD,
    vkGetShaderInstrumentationValuesARM,
    vkGetShaderModuleCreateInfoIdentifierEXT,
    vkGetShaderModuleIdentifierEXT,
    vkGetSleepStatusLegacyNV,
    vkGetSwapchainCounterEXT,
    vkGetSwapchainImagesKHR,
    vkGetSwapchainStatusKHR,
    vkGetSwapchainTimeDomainPropertiesEXT,
    vkGetSwapchainTimingPropertiesEXT,
    vkGetTensorMemoryRequirementsARM,
    vkGetTensorOpaqueCaptureDataARM,
    vkGetTensorOpaqueCaptureDescriptorDataARM,
    vkGetTensorViewOpaqueCaptureDescriptorDataARM,
    vkGetValidationCacheDataEXT,
    vkGetVideoSessionMemoryRequirementsKHR,
    vkGetWinrtDisplayNV,
    vkImportFenceFdKHR,
    vkImportFenceWin32HandleKHR,
    vkImportSemaphoreFdKHR,
    vkImportSemaphoreWin32HandleKHR,
    vkImportSemaphoreZirconHandleFUCHSIA,
    vkInitializePerformanceApiINTEL,
    vkInvalidateMappedMemoryRanges,
    vkLatencySleepLegacyNV,
    vkLatencySleepNV,
    vkMapMemory,
    vkMapMemory2,
    vkMapMemory2KHR,
    vkMergePipelineCaches,
    vkMergeValidationCachesEXT,
    vkQueueBeginDebugUtilsLabelEXT,
    vkQueueBindSparse,
    vkQueueEndDebugUtilsLabelEXT,
    vkQueueInsertDebugUtilsLabelEXT,
    vkQueueNotifyOutOfBandLegacyNV,
    vkQueueNotifyOutOfBandNV,
    vkQueuePresentKHR,
    vkQueueSetPerfHintQCOM,
    vkQueueSetPerformanceConfigurationINTEL,
    vkQueueSubmit,
    vkQueueSubmit2,
    vkQueueSubmit2KHR,
    vkQueueWaitIdle,
    vkRegisterCustomBorderColorEXT,
    vkRegisterDeviceEventEXT,
    vkRegisterDisplayEventEXT,
    vkReleaseCapturedPipelineDataKHR,
    vkReleaseDisplayEXT,
    vkReleaseFullScreenExclusiveModeEXT,
    vkReleasePerformanceConfigurationINTEL,
    vkReleaseProfilingLockKHR,
    vkReleaseSwapchainImagesEXT,
    vkReleaseSwapchainImagesKHR,
    vkResetCommandBuffer,
    vkResetCommandPool,
    vkResetDescriptorPool,
    vkResetEvent,
    vkResetFences,
    vkResetGpaSessionAMD,
    vkResetQueryPool,
    vkResetQueryPoolEXT,
    vkSetBufferCollectionBufferConstraintsFUCHSIA,
    vkSetBufferCollectionImageConstraintsFUCHSIA,
    vkSetDebugUtilsObjectNameEXT,
    vkSetDebugUtilsObjectTagEXT,
    vkSetDeviceMemoryPriorityEXT,
    vkSetEvent,
    vkSetGpaDeviceClockModeAMD,
    vkSetHdrMetadataEXT,
    vkSetLatencyMarkerLegacyNV,
    vkSetLatencyMarkerNV,
    vkSetLatencySleepModeLegacyNV,
    vkSetLatencySleepModeNV,
    vkSetLocalDimmingAMD,
    vkSetPrivateData,
    vkSetPrivateDataEXT,
    vkSetSwapchainPresentTimingQueueSizeEXT,
    vkShutdownLatencyDeviceLegacyNV,
    vkSignalSemaphore,
    vkSignalSemaphoreKHR,
    vkSubmitDebugUtilsMessageEXT,
    vkTransitionImageLayout,
    vkTransitionImageLayoutEXT,
    vkTrimCommandPool,
    vkTrimCommandPoolKHR,
    vkUninitializePerformanceApiINTEL,
    vkUnmapMemory,
    vkUnmapMemory2,
    vkUnmapMemory2KHR,
    vkUnregisterCustomBorderColorEXT,
    vkUpdateDescriptorSetWithTemplate,
    vkUpdateDescriptorSetWithTemplateKHR,
    vkUpdateDescriptorSets,
    vkUpdateIndirectExecutionSetPipelineEXT,
    vkUpdateIndirectExecutionSetShaderEXT,
    vkUpdateVideoSessionParametersKHR,
    vkWaitForFences,
    vkWaitForPresent2KHR,
    vkWaitForPresentKHR,
    vkWaitSemaphores,
    vkWaitSemaphoresKHR,
    vkWriteAccelerationStructuresPropertiesKHR,
    vkWriteMicromapsPropertiesEXT,
    vkWriteResourceDescriptorsEXT,
    vkWriteSamplerDescriptorsEXT,
};

enum class Struct {
    Empty = 0,
    VkAabbPositionsKHR,
    VkAccelerationStructureBuildGeometryInfoKHR,
    VkAccelerationStructureBuildRangeInfoKHR,
    VkAccelerationStructureBuildSizesInfoKHR,
    VkAccelerationStructureCaptureDescriptorDataInfoEXT,
    VkAccelerationStructureCreateInfo2KHR,
    VkAccelerationStructureCreateInfoKHR,
    VkAccelerationStructureCreateInfoNV,
    VkAccelerationStructureDenseGeometryFormatTrianglesDataAMDX,
    VkAccelerationStructureDeviceAddressInfoKHR,
    VkAccelerationStructureGeometryAabbsDataKHR,
    VkAccelerationStructureGeometryDataKHR,
    VkAccelerationStructureGeometryInstancesDataKHR,
    VkAccelerationStructureGeometryKHR,
    VkAccelerationStructureGeometryLinearSweptSpheresDataNV,
    VkAccelerationStructureGeometryMicromapDataKHR,
    VkAccelerationStructureGeometryMotionTrianglesDataNV,
    VkAccelerationStructureGeometrySpheresDataNV,
    VkAccelerationStructureGeometryTrianglesDataKHR,
    VkAccelerationStructureInfoNV,
    VkAccelerationStructureInstanceKHR,
    VkAccelerationStructureMatrixMotionInstanceNV,
    VkAccelerationStructureMemoryRequirementsInfoNV,
    VkAccelerationStructureMotionInfoNV,
    VkAccelerationStructureMotionInstanceDataNV,
    VkAccelerationStructureMotionInstanceNV,
    VkAccelerationStructureSRTMotionInstanceNV,
    VkAccelerationStructureTrianglesDisplacementMicromapNV,
    VkAccelerationStructureTrianglesOpacityMicromapEXT,
    VkAccelerationStructureTrianglesOpacityMicromapKHR,
    VkAccelerationStructureVersionInfoKHR,
    VkAcquireNextImageInfoKHR,
    VkAcquireProfilingLockInfoKHR,
    VkAllocationCallbacks,
    VkAmigoProfilingSubmitInfoSEC,
    VkAndroidHardwareBufferFormatProperties2ANDROID,
    VkAndroidHardwareBufferFormatPropertiesANDROID,
    VkAndroidHardwareBufferFormatResolvePropertiesANDROID,
    VkAndroidHardwareBufferPropertiesANDROID,
    VkAndroidHardwareBufferUsageANDROID,
    VkAndroidSurfaceCreateInfoKHR,
    VkAntiLagDataAMD,
    VkAntiLagPresentationInfoAMD,
    VkApplicationInfo,
    VkAttachmentDescription,
    VkAttachmentDescription2,
    VkAttachmentDescriptionStencilLayout,
    VkAttachmentFeedbackLoopInfoEXT,
    VkAttachmentReference,
    VkAttachmentReference2,
    VkAttachmentReferenceStencilLayout,
    VkAttachmentSampleCountInfoAMD,
    VkAttachmentSampleLocationsEXT,
    VkBaseInStructure,
    VkBaseOutStructure,
    VkBeginCustomResolveInfoEXT,
    VkBindAccelerationStructureMemoryInfoNV,
    VkBindBufferMemoryDeviceGroupInfo,
    VkBindBufferMemoryInfo,
    VkBindDataGraphPipelineSessionMemoryInfoARM,
    VkBindDescriptorBufferEmbeddedSamplersInfoEXT,
    VkBindDescriptorSetsInfo,
    VkBindHeapInfoEXT,
    VkBindImageMemoryDeviceGroupInfo,
    VkBindImageMemoryInfo,
    VkBindImageMemorySwapchainInfoKHR,
    VkBindImagePlaneMemoryInfo,
    VkBindIndexBuffer3InfoKHR,
    VkBindIndexBufferIndirectCommandEXT,
    VkBindIndexBufferIndirectCommandNV,
    VkBindMemoryStatus,
    VkBindPipelineIndirectCommandNV,
    VkBindShaderGroupIndirectCommandNV,
    VkBindSparseInfo,
    VkBindTensorMemoryInfoARM,
    VkBindTransformFeedbackBuffer2InfoEXT,
    VkBindVertexBuffer3InfoKHR,
    VkBindVertexBufferIndirectCommandEXT,
    VkBindVertexBufferIndirectCommandNV,
    VkBindVideoSessionMemoryInfoKHR,
    VkBlitImageCubicWeightsInfoQCOM,
    VkBlitImageInfo2,
    VkBufferCaptureDescriptorDataInfoEXT,
    VkBufferCollectionBufferCreateInfoFUCHSIA,
    VkBufferCollectionConstraintsInfoFUCHSIA,
    VkBufferCollectionCreateInfoFUCHSIA,
    VkBufferCollectionImageCreateInfoFUCHSIA,
    VkBufferCollectionPropertiesFUCHSIA,
    VkBufferConstraintsInfoFUCHSIA,
    VkBufferCopy,
    VkBufferCopy2,
    VkBufferCreateInfo,
    VkBufferDeviceAddressCreateInfoEXT,
    VkBufferDeviceAddressInfo,
    VkBufferImageCopy,
    VkBufferImageCopy2,
    VkBufferMemoryBarrier,
    VkBufferMemoryBarrier2,
    VkBufferMemoryRequirementsInfo2,
    VkBufferOpaqueCaptureAddressCreateInfo,
    VkBufferUsageFlags2CreateInfo,
    VkBufferViewCreateInfo,
    VkBuildPartitionedAccelerationStructureIndirectCommandNV,
    VkBuildPartitionedAccelerationStructureInfoNV,
    VkCalibratedTimestampInfoKHR,
    VkCheckpointData2NV,
    VkCheckpointDataNV,
    VkClearAttachment,
    VkClearColorValue,
    VkClearDepthStencilValue,
    VkClearRect,
    VkClearValue,
    VkClusterAccelerationStructureBuildClustersBottomLevelInfoNV,
    VkClusterAccelerationStructureBuildTriangleClusterInfoNV,
    VkClusterAccelerationStructureBuildTriangleClusterTemplateInfoNV,
    VkClusterAccelerationStructureClustersBottomLevelInputNV,
    VkClusterAccelerationStructureCommandsInfoNV,
    VkClusterAccelerationStructureGeometryIndexAndGeometryFlagsNV,
    VkClusterAccelerationStructureGetTemplateIndicesInfoNV,
    VkClusterAccelerationStructureInputInfoNV,
    VkClusterAccelerationStructureInstantiateClusterInfoNV,
    VkClusterAccelerationStructureMoveObjectsInfoNV,
    VkClusterAccelerationStructureMoveObjectsInputNV,
    VkClusterAccelerationStructureOpInputNV,
    VkClusterAccelerationStructureTriangleClusterInputNV,
    VkCoarseSampleLocationNV,
    VkCoarseSampleOrderCustomNV,
    VkColorBlendAdvancedEXT,
    VkColorBlendEquationEXT,
    VkCommandBufferAllocateInfo,
    VkCommandBufferBeginInfo,
    VkCommandBufferInheritanceConditionalRenderingInfoEXT,
    VkCommandBufferInheritanceDescriptorHeapInfoEXT,
    VkCommandBufferInheritanceInfo,
    VkCommandBufferInheritanceRenderPassTransformInfoQCOM,
    VkCommandBufferInheritanceRenderingInfo,
    VkCommandBufferInheritanceViewportScissorInfoNV,
    VkCommandBufferSubmitInfo,
    VkCommandPoolCreateInfo,
    VkComponentMapping,
    VkComputeOccupancyPriorityParametersNV,
    VkComputePipelineCreateInfo,
    VkComputePipelineIndirectBufferInfoNV,
    VkConditionalRenderingBeginInfo2EXT,
    VkConditionalRenderingBeginInfoEXT,
    VkConformanceVersion,
    VkConvertCooperativeVectorMatrixInfoNV,
    VkCooperativeMatrixFlexibleDimensionsPropertiesNV,
    VkCooperativeMatrixPropertiesKHR,
    VkCooperativeMatrixPropertiesNV,
    VkCooperativeVectorPropertiesNV,
    VkCopyAccelerationStructureInfoKHR,
    VkCopyAccelerationStructureToMemoryInfoKHR,
    VkCopyBufferInfo2,
    VkCopyBufferToImageInfo2,
    VkCopyCommandTransformInfoQCOM,
    VkCopyDescriptorSet,
    VkCopyDeviceMemoryImageInfoKHR,
    VkCopyDeviceMemoryInfoKHR,
    VkCopyImageInfo2,
    VkCopyImageToBufferInfo2,
    VkCopyImageToImageInfo,
    VkCopyImageToMemoryInfo,
    VkCopyMemoryIndirectCommandKHR,
    VkCopyMemoryIndirectInfoKHR,
    VkCopyMemoryToAccelerationStructureInfoKHR,
    VkCopyMemoryToImageIndirectCommandKHR,
    VkCopyMemoryToImageIndirectInfoKHR,
    VkCopyMemoryToImageInfo,
    VkCopyMemoryToMicromapInfoEXT,
    VkCopyMicromapInfoEXT,
    VkCopyMicromapToMemoryInfoEXT,
    VkCopyTensorInfoARM,
    VkCuFunctionCreateInfoNVX,
    VkCuLaunchInfoNVX,
    VkCuModuleCreateInfoNVX,
    VkCuModuleTexturingModeCreateInfoNVX,
    VkCudaFunctionCreateInfoNV,
    VkCudaLaunchInfoNV,
    VkCudaModuleCreateInfoNV,
    VkCustomResolveCreateInfoEXT,
    VkD3D12FenceSubmitInfoKHR,
    VkDataGraphOpticalFlowImageFormatInfoARM,
    VkDataGraphOpticalFlowImageFormatPropertiesARM,
    VkDataGraphPipelineBuiltinModelCreateInfoQCOM,
    VkDataGraphPipelineCompilerControlCreateInfoARM,
    VkDataGraphPipelineConstantARM,
    VkDataGraphPipelineConstantTensorSemiStructuredSparsityInfoARM,
    VkDataGraphPipelineCreateInfoARM,
    VkDataGraphPipelineDispatchInfoARM,
    VkDataGraphPipelineIdentifierCreateInfoARM,
    VkDataGraphPipelineInfoARM,
    VkDataGraphPipelineNeuralStatisticsCreateInfoARM,
    VkDataGraphPipelineOpticalFlowCreateInfoARM,
    VkDataGraphPipelineOpticalFlowDispatchInfoARM,
    VkDataGraphPipelinePropertyQueryResultARM,
    VkDataGraphPipelineResourceInfoARM,
    VkDataGraphPipelineResourceInfoImageLayoutARM,
    VkDataGraphPipelineSessionBindPointRequirementARM,
    VkDataGraphPipelineSessionBindPointRequirementsInfoARM,
    VkDataGraphPipelineSessionCreateInfoARM,
    VkDataGraphPipelineSessionMemoryRequirementsInfoARM,
    VkDataGraphPipelineSessionNeuralStatisticsCreateInfoARM,
    VkDataGraphPipelineShaderModuleCreateInfoARM,
    VkDataGraphPipelineSingleNodeConnectionARM,
    VkDataGraphPipelineSingleNodeCreateInfoARM,
    VkDataGraphProcessingEngineCreateInfoARM,
    VkDataGraphTOSANameQualityARM,
    VkDebugMarkerMarkerInfoEXT,
    VkDebugMarkerObjectNameInfoEXT,
    VkDebugMarkerObjectTagInfoEXT,
    VkDebugReportCallbackCreateInfoEXT,
    VkDebugUtilsLabelEXT,
    VkDebugUtilsMessengerCallbackDataEXT,
    VkDebugUtilsMessengerCreateInfoEXT,
    VkDebugUtilsObjectNameInfoEXT,
    VkDebugUtilsObjectTagInfoEXT,
    VkDecompressMemoryInfoEXT,
    VkDecompressMemoryRegionEXT,
    VkDecompressMemoryRegionNV,
    VkDedicatedAllocationBufferCreateInfoNV,
    VkDedicatedAllocationImageCreateInfoNV,
    VkDedicatedAllocationMemoryAllocateInfoNV,
    VkDependencyInfo,
    VkDepthBiasInfoEXT,
    VkDepthBiasRepresentationInfoEXT,
    VkDepthClampRangeEXT,
    VkDescriptorAddressInfoEXT,
    VkDescriptorBufferBindingInfoEXT,
    VkDescriptorBufferBindingPushDescriptorBufferHandleEXT,
    VkDescriptorBufferInfo,
    VkDescriptorDataEXT,
    VkDescriptorGetInfoEXT,
    VkDescriptorGetTensorInfoARM,
    VkDescriptorImageInfo,
    VkDescriptorMappingSourceConstantOffsetEXT,
    VkDescriptorMappingSourceDataEXT,
    VkDescriptorMappingSourceHeapDataEXT,
    VkDescriptorMappingSourceIndirectAddressEXT,
    VkDescriptorMappingSourceIndirectIndexArrayEXT,
    VkDescriptorMappingSourceIndirectIndexEXT,
    VkDescriptorMappingSourcePushIndexEXT,
    VkDescriptorMappingSourceShaderRecordIndexEXT,
    VkDescriptorPoolCreateInfo,
    VkDescriptorPoolInlineUniformBlockCreateInfo,
    VkDescriptorPoolSize,
    VkDescriptorSetAllocateInfo,
    VkDescriptorSetAndBindingMappingEXT,
    VkDescriptorSetBindingReferenceVALVE,
    VkDescriptorSetLayoutBinding,
    VkDescriptorSetLayoutBindingFlagsCreateInfo,
    VkDescriptorSetLayoutCreateInfo,
    VkDescriptorSetLayoutHostMappingInfoVALVE,
    VkDescriptorSetLayoutSupport,
    VkDescriptorSetVariableDescriptorCountAllocateInfo,
    VkDescriptorSetVariableDescriptorCountLayoutSupport,
    VkDescriptorUpdateTemplateCreateInfo,
    VkDescriptorUpdateTemplateEntry,
    VkDeviceAddressBindingCallbackDataEXT,
    VkDeviceAddressRangeKHR,
    VkDeviceBufferMemoryRequirements,
    VkDeviceCreateInfo,
    VkDeviceDeviceMemoryReportCreateInfoEXT,
    VkDeviceDiagnosticsConfigCreateInfoNV,
    VkDeviceEventInfoEXT,
    VkDeviceFaultAddressInfoKHR,
    VkDeviceFaultCountsEXT,
    VkDeviceFaultDebugInfoKHR,
    VkDeviceFaultInfoEXT,
    VkDeviceFaultInfoKHR,
    VkDeviceFaultShaderAbortMessageInfoKHR,
    VkDeviceFaultVendorBinaryHeaderVersionOneKHR,
    VkDeviceFaultVendorInfoKHR,
    VkDeviceGroupBindSparseInfo,
    VkDeviceGroupCommandBufferBeginInfo,
    VkDeviceGroupDeviceCreateInfo,
    VkDeviceGroupPresentCapabilitiesKHR,
    VkDeviceGroupPresentInfoKHR,
    VkDeviceGroupRenderPassBeginInfo,
    VkDeviceGroupSubmitInfo,
    VkDeviceGroupSwapchainCreateInfoKHR,
    VkDeviceImageMemoryRequirements,
    VkDeviceImageSubresourceInfo,
    VkDeviceMemoryCopyKHR,
    VkDeviceMemoryImageCopyKHR,
    VkDeviceMemoryOpaqueCaptureAddressInfo,
    VkDeviceMemoryOverallocationCreateInfoAMD,
    VkDeviceMemoryReportCallbackDataEXT,
    VkDeviceOrHostAddressConstAMDX,
    VkDeviceOrHostAddressConstKHR,
    VkDeviceOrHostAddressKHR,
    VkDevicePipelineBinaryInternalCacheControlKHR,
    VkDevicePrivateDataCreateInfo,
    VkDeviceQueueCreateInfo,
    VkDeviceQueueGlobalPriorityCreateInfo,
    VkDeviceQueueInfo2,
    VkDeviceQueueShaderCoreControlCreateInfoARM,
    VkDeviceTensorMemoryRequirementsARM,
    VkDirectDriverLoadingInfoLUNARG,
    VkDirectDriverLoadingListLUNARG,
    VkDirectFBSurfaceCreateInfoEXT,
    VkDispatchGraphCountInfoAMDX,
    VkDispatchGraphInfoAMDX,
    VkDispatchIndirect2InfoKHR,
    VkDispatchIndirectCommand,
    VkDispatchParametersARM,
    VkDispatchTileInfoQCOM,
    VkDisplayEventInfoEXT,
    VkDisplayModeCreateInfoKHR,
    VkDisplayModeParametersKHR,
    VkDisplayModeProperties2KHR,
    VkDisplayModePropertiesKHR,
    VkDisplayModeStereoPropertiesNV,
    VkDisplayNativeHdrSurfaceCapabilitiesAMD,
    VkDisplayPlaneCapabilities2KHR,
    VkDisplayPlaneCapabilitiesKHR,
    VkDisplayPlaneInfo2KHR,
    VkDisplayPlaneProperties2KHR,
    VkDisplayPlanePropertiesKHR,
    VkDisplayPowerInfoEXT,
    VkDisplayPresentInfoKHR,
    VkDisplayProperties2KHR,
    VkDisplayPropertiesKHR,
    VkDisplaySurfaceCreateInfoKHR,
    VkDisplaySurfaceStereoCreateInfoNV,
    VkDrawIndexedIndirectCommand,
    VkDrawIndirect2InfoKHR,
    VkDrawIndirectCommand,
    VkDrawIndirectCount2InfoKHR,
    VkDrawIndirectCountIndirectCommandEXT,
    VkDrawMeshTasksIndirectCommandEXT,
    VkDrawMeshTasksIndirectCommandNV,
    VkDrmFormatModifierProperties2EXT,
    VkDrmFormatModifierPropertiesEXT,
    VkDrmFormatModifierPropertiesList2EXT,
    VkDrmFormatModifierPropertiesListEXT,
    VkEventCreateInfo,
    VkExecutionGraphPipelineCreateInfoAMDX,
    VkExecutionGraphPipelineScratchSizeAMDX,
    VkExportFenceCreateInfo,
    VkExportFenceWin32HandleInfoKHR,
    VkExportMemoryAllocateInfo,
    VkExportMemoryAllocateInfoNV,
    VkExportMemoryWin32HandleInfoKHR,
    VkExportMemoryWin32HandleInfoNV,
    VkExportMetalBufferInfoEXT,
    VkExportMetalCommandQueueInfoEXT,
    VkExportMetalDeviceInfoEXT,
    VkExportMetalIOSurfaceInfoEXT,
    VkExportMetalObjectCreateInfoEXT,
    VkExportMetalObjectsInfoEXT,
    VkExportMetalSharedEventInfoEXT,
    VkExportMetalTextureInfoEXT,
    VkExportSemaphoreCreateInfo,
    VkExportSemaphoreWin32HandleInfoKHR,
    VkExtensionProperties,
    VkExtent2D,
    VkExtent3D,
    VkExternalBufferProperties,
    VkExternalComputeQueueCreateInfoNV,
    VkExternalComputeQueueDataParamsNV,
    VkExternalComputeQueueDeviceCreateInfoNV,
    VkExternalFenceProperties,
    VkExternalFormatANDROID,
    VkExternalFormatOHOS,
    VkExternalFormatQNX,
    VkExternalImageFormatProperties,
    VkExternalImageFormatPropertiesNV,
    VkExternalMemoryAcquireUnmodifiedEXT,
    VkExternalMemoryBufferCreateInfo,
    VkExternalMemoryImageCreateInfo,
    VkExternalMemoryImageCreateInfoNV,
    VkExternalMemoryProperties,
    VkExternalMemoryTensorCreateInfoARM,
    VkExternalSemaphoreProperties,
    VkExternalTensorPropertiesARM,
    VkFenceCreateInfo,
    VkFenceGetFdInfoKHR,
    VkFenceGetWin32HandleInfoKHR,
    VkFilterCubicImageViewImageFormatPropertiesEXT,
    VkFormatProperties,
    VkFormatProperties2,
    VkFormatProperties3,
    VkFormatProperties4KHR,
    VkFragmentShadingRateAttachmentInfoKHR,
    VkFrameBoundaryEXT,
    VkFrameBoundaryTensorsARM,
    VkFramebufferAttachmentImageInfo,
    VkFramebufferAttachmentsCreateInfo,
    VkFramebufferCreateInfo,
    VkFramebufferMixedSamplesCombinationNV,
    VkGeneratedCommandsInfoEXT,
    VkGeneratedCommandsInfoNV,
    VkGeneratedCommandsMemoryRequirementsInfoEXT,
    VkGeneratedCommandsMemoryRequirementsInfoNV,
    VkGeneratedCommandsPipelineInfoEXT,
    VkGeneratedCommandsShaderInfoEXT,
    VkGeometryAABBNV,
    VkGeometryDataNV,
    VkGeometryNV,
    VkGeometryTrianglesNV,
    VkGetLatencyMarkerInfoNV,
    VkGpaDeviceClockModeInfoAMD,
    VkGpaDeviceGetClockInfoAMD,
    VkGpaPerfBlockPropertiesAMD,
    VkGpaPerfCounterAMD,
    VkGpaSampleBeginInfoAMD,
    VkGpaSessionCreateInfoAMD,
    VkGraphicsPipelineCreateInfo,
    VkGraphicsPipelineLibraryCreateInfoEXT,
    VkGraphicsPipelineShaderGroupsCreateInfoNV,
    VkGraphicsShaderGroupCreateInfoNV,
    VkHdrMetadataEXT,
    VkHdrVividDynamicMetadataHUAWEI,
    VkHeadlessSurfaceCreateInfoEXT,
    VkHostAddressRangeConstEXT,
    VkHostAddressRangeEXT,
    VkHostImageCopyDevicePerformanceQuery,
    VkHostImageLayoutTransitionInfo,
    VkIOSSurfaceCreateInfoMVK,
    VkImageAlignmentControlCreateInfoMESA,
    VkImageBlit,
    VkImageBlit2,
    VkImageCaptureDescriptorDataInfoEXT,
    VkImageCompressionControlEXT,
    VkImageCompressionPropertiesEXT,
    VkImageConstraintsInfoFUCHSIA,
    VkImageCopy,
    VkImageCopy2,
    VkImageCreateFlags2CreateInfoKHR,
    VkImageCreateInfo,
    VkImageDescriptorInfoEXT,
    VkImageDrmFormatModifierExplicitCreateInfoEXT,
    VkImageDrmFormatModifierListCreateInfoEXT,
    VkImageDrmFormatModifierPropertiesEXT,
    VkImageFormatConstraintsInfoFUCHSIA,
    VkImageFormatListCreateInfo,
    VkImageFormatProperties,
    VkImageFormatProperties2,
    VkImageMemoryBarrier,
    VkImageMemoryBarrier2,
    VkImageMemoryRequirementsInfo2,
    VkImagePipeSurfaceCreateInfoFUCHSIA,
    VkImagePlaneMemoryRequirementsInfo,
    VkImageResolve,
    VkImageResolve2,
    VkImageSparseMemoryRequirementsInfo2,
    VkImageStencilUsage2CreateInfoKHR,
    VkImageStencilUsageCreateInfo,
    VkImageSubresource,
    VkImageSubresource2,
    VkImageSubresourceLayers,
    VkImageSubresourceRange,
    VkImageSwapchainCreateInfoKHR,
    VkImageToMemoryCopy,
    VkImageUsageFlags2CreateInfoKHR,
    VkImageViewASTCDecodeModeEXT,
    VkImageViewAddressPropertiesNVX,
    VkImageViewCaptureDescriptorDataInfoEXT,
    VkImageViewCreateInfo,
    VkImageViewHandleInfoNVX,
    VkImageViewMinLodCreateInfoEXT,
    VkImageViewSampleWeightCreateInfoQCOM,
    VkImageViewSlicedCreateInfoEXT,
    VkImageViewUsage2CreateInfoKHR,
    VkImageViewUsageCreateInfo,
    VkImportAndroidHardwareBufferInfoANDROID,
    VkImportFenceFdInfoKHR,
    VkImportFenceWin32HandleInfoKHR,
    VkImportMemoryBufferCollectionFUCHSIA,
    VkImportMemoryFdInfoKHR,
    VkImportMemoryHostPointerInfoEXT,
    VkImportMemoryMetalHandleInfoEXT,
    VkImportMemoryWin32HandleInfoKHR,
    VkImportMemoryWin32HandleInfoNV,
    VkImportMemoryZirconHandleInfoFUCHSIA,
    VkImportMetalBufferInfoEXT,
    VkImportMetalIOSurfaceInfoEXT,
    VkImportMetalSharedEventInfoEXT,
    VkImportMetalTextureInfoEXT,
    VkImportNativeBufferInfoOHOS,
    VkImportScreenBufferInfoQNX,
    VkImportSemaphoreFdInfoKHR,
    VkImportSemaphoreWin32HandleInfoKHR,
    VkImportSemaphoreZirconHandleInfoFUCHSIA,
    VkIndirectCommandsExecutionSetTokenEXT,
    VkIndirectCommandsIndexBufferTokenEXT,
    VkIndirectCommandsLayoutCreateInfoEXT,
    VkIndirectCommandsLayoutCreateInfoNV,
    VkIndirectCommandsLayoutPushDataTokenNV,
    VkIndirectCommandsLayoutTokenEXT,
    VkIndirectCommandsLayoutTokenNV,
    VkIndirectCommandsPushConstantTokenEXT,
    VkIndirectCommandsStreamNV,
    VkIndirectCommandsTokenDataEXT,
    VkIndirectCommandsVertexBufferTokenEXT,
    VkIndirectExecutionSetCreateInfoEXT,
    VkIndirectExecutionSetInfoEXT,
    VkIndirectExecutionSetPipelineInfoEXT,
    VkIndirectExecutionSetShaderInfoEXT,
    VkIndirectExecutionSetShaderLayoutInfoEXT,
    VkInitializePerformanceApiInfoINTEL,
    VkInputAttachmentAspectReference,
    VkInstanceCreateInfo,
    VkLatencySleepInfoNV,
    VkLatencySleepModeInfoNV,
    VkLatencySubmissionPresentIdNV,
    VkLatencySurfaceCapabilitiesNV,
    VkLatencyTimingsFrameReportNV,
    VkLayerProperties,
    VkLayerSettingEXT,
    VkLayerSettingsCreateInfoEXT,
    VkMacOSSurfaceCreateInfoMVK,
    VkMappedMemoryRange,
    VkMemoryAllocateFlagsInfo,
    VkMemoryAllocateInfo,
    VkMemoryBarrier,
    VkMemoryBarrier2,
    VkMemoryBarrierAccessFlags3KHR,
    VkMemoryDedicatedAllocateInfo,
    VkMemoryDedicatedAllocateInfoTensorARM,
    VkMemoryDedicatedRequirements,
    VkMemoryFdPropertiesKHR,
    VkMemoryGetAndroidHardwareBufferInfoANDROID,
    VkMemoryGetFdInfoKHR,
    VkMemoryGetMetalHandleInfoEXT,
    VkMemoryGetNativeBufferInfoOHOS,
    VkMemoryGetRemoteAddressInfoNV,
    VkMemoryGetWin32HandleInfoKHR,
    VkMemoryGetZirconHandleInfoFUCHSIA,
    VkMemoryHeap,
    VkMemoryHostPointerPropertiesEXT,
    VkMemoryMapInfo,
    VkMemoryMapPlacedInfoEXT,
    VkMemoryMarkerInfoAMD,
    VkMemoryMetalHandlePropertiesEXT,
    VkMemoryOpaqueCaptureAddressAllocateInfo,
    VkMemoryPriorityAllocateInfoEXT,
    VkMemoryRangeBarrierKHR,
    VkMemoryRangeBarriersInfoKHR,
    VkMemoryRequirements,
    VkMemoryRequirements2,
    VkMemoryToImageCopy,
    VkMemoryType,
    VkMemoryUnmapInfo,
    VkMemoryWin32HandlePropertiesKHR,
    VkMemoryZirconHandlePropertiesFUCHSIA,
    VkMetalSurfaceCreateInfoEXT,
    VkMicromapBuildInfoEXT,
    VkMicromapBuildSizesInfoEXT,
    VkMicromapCreateInfoEXT,
    VkMicromapTriangleKHR,
    VkMicromapUsageEXT,
    VkMicromapUsageKHR,
    VkMicromapVersionInfoEXT,
    VkMultiDrawIndexedInfoEXT,
    VkMultiDrawInfoEXT,
    VkMultisamplePropertiesEXT,
    VkMultisampledRenderToSingleSampledInfoEXT,
    VkMultiviewPerViewAttributesInfoNVX,
    VkMultiviewPerViewRenderAreasRenderPassBeginInfoQCOM,
    VkMutableDescriptorTypeCreateInfoEXT,
    VkMutableDescriptorTypeListEXT,
    VkNativeBufferFormatPropertiesOHOS,
    VkNativeBufferPropertiesOHOS,
    VkNativeBufferUsageOHOS,
    VkOffset2D,
    VkOffset3D,
    VkOpaqueCaptureDataCreateInfoEXT,
    VkOpaqueCaptureDescriptorDataCreateInfoEXT,
    VkOpticalFlowExecuteInfoNV,
    VkOpticalFlowImageFormatInfoNV,
    VkOpticalFlowImageFormatPropertiesNV,
    VkOpticalFlowSessionCreateInfoNV,
    VkOpticalFlowSessionCreatePrivateDataInfoNV,
    VkOutOfBandQueueTypeInfoNV,
    VkPartitionedAccelerationStructureFlagsNV,
    VkPartitionedAccelerationStructureInstancesInputNV,
    VkPartitionedAccelerationStructureUpdateInstanceDataNV,
    VkPartitionedAccelerationStructureWriteInstanceDataNV,
    VkPartitionedAccelerationStructureWritePartitionTranslationDataNV,
    VkPastPresentationTimingEXT,
    VkPastPresentationTimingGOOGLE,
    VkPastPresentationTimingInfoEXT,
    VkPastPresentationTimingPropertiesEXT,
    VkPerTileBeginInfoQCOM,
    VkPerTileEndInfoQCOM,
    VkPerfHintInfoQCOM,
    VkPerformanceConfigurationAcquireInfoINTEL,
    VkPerformanceCounterARM,
    VkPerformanceCounterDescriptionARM,
    VkPerformanceCounterDescriptionKHR,
    VkPerformanceCounterKHR,
    VkPerformanceCounterResultKHR,
    VkPerformanceMarkerInfoINTEL,
    VkPerformanceOverrideInfoINTEL,
    VkPerformanceQuerySubmitInfoKHR,
    VkPerformanceStreamMarkerInfoINTEL,
    VkPerformanceValueDataINTEL,
    VkPerformanceValueINTEL,
    VkPhysicalDevice16BitStorageFeatures,
    VkPhysicalDevice4444FormatsFeaturesEXT,
    VkPhysicalDevice8BitStorageFeatures,
    VkPhysicalDeviceASTCDecodeFeaturesEXT,
    VkPhysicalDeviceAccelerationStructureFeaturesKHR,
    VkPhysicalDeviceAccelerationStructurePropertiesKHR,
    VkPhysicalDeviceAddressBindingReportFeaturesEXT,
    VkPhysicalDeviceAmigoProfilingFeaturesSEC,
    VkPhysicalDeviceAntiLagFeaturesAMD,
    VkPhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT,
    VkPhysicalDeviceAttachmentFeedbackLoopLayoutFeaturesEXT,
    VkPhysicalDeviceBlendOperationAdvancedFeaturesEXT,
    VkPhysicalDeviceBlendOperationAdvancedPropertiesEXT,
    VkPhysicalDeviceBorderColorSwizzleFeaturesEXT,
    VkPhysicalDeviceBufferDeviceAddressFeatures,
    VkPhysicalDeviceBufferDeviceAddressFeaturesEXT,
    VkPhysicalDeviceClusterAccelerationStructureFeaturesNV,
    VkPhysicalDeviceClusterAccelerationStructurePropertiesNV,
    VkPhysicalDeviceClusterCullingShaderFeaturesHUAWEI,
    VkPhysicalDeviceClusterCullingShaderPropertiesHUAWEI,
    VkPhysicalDeviceClusterCullingShaderVrsFeaturesHUAWEI,
    VkPhysicalDeviceCoherentMemoryFeaturesAMD,
    VkPhysicalDeviceColorWriteEnableFeaturesEXT,
    VkPhysicalDeviceCommandBufferInheritanceFeaturesNV,
    VkPhysicalDeviceComputeOccupancyPriorityFeaturesNV,
    VkPhysicalDeviceComputeShaderDerivativesFeaturesKHR,
    VkPhysicalDeviceComputeShaderDerivativesPropertiesKHR,
    VkPhysicalDeviceConditionalRenderingFeaturesEXT,
    VkPhysicalDeviceConservativeRasterizationPropertiesEXT,
    VkPhysicalDeviceCooperativeMatrix2FeaturesNV,
    VkPhysicalDeviceCooperativeMatrix2PropertiesNV,
    VkPhysicalDeviceCooperativeMatrixConversionFeaturesQCOM,
    VkPhysicalDeviceCooperativeMatrixDecodeVectorFeaturesNV,
    VkPhysicalDeviceCooperativeMatrixFeaturesKHR,
    VkPhysicalDeviceCooperativeMatrixFeaturesNV,
    VkPhysicalDeviceCooperativeMatrixPropertiesKHR,
    VkPhysicalDeviceCooperativeMatrixPropertiesNV,
    VkPhysicalDeviceCooperativeVectorFeaturesNV,
    VkPhysicalDeviceCooperativeVectorPropertiesNV,
    VkPhysicalDeviceCopyMemoryIndirectFeaturesKHR,
    VkPhysicalDeviceCopyMemoryIndirectFeaturesNV,
    VkPhysicalDeviceCopyMemoryIndirectPropertiesKHR,
    VkPhysicalDeviceCornerSampledImageFeaturesNV,
    VkPhysicalDeviceCoverageReductionModeFeaturesNV,
    VkPhysicalDeviceCubicClampFeaturesQCOM,
    VkPhysicalDeviceCubicWeightsFeaturesQCOM,
    VkPhysicalDeviceCudaKernelLaunchFeaturesNV,
    VkPhysicalDeviceCudaKernelLaunchPropertiesNV,
    VkPhysicalDeviceCustomBorderColorFeaturesEXT,
    VkPhysicalDeviceCustomBorderColorPropertiesEXT,
    VkPhysicalDeviceCustomResolveFeaturesEXT,
    VkPhysicalDeviceDataGraphFeaturesARM,
    VkPhysicalDeviceDataGraphModelFeaturesQCOM,
    VkPhysicalDeviceDataGraphNeuralAcceleratorStatisticsFeaturesARM,
    VkPhysicalDeviceDataGraphOperationSupportARM,
    VkPhysicalDeviceDataGraphOpticalFlowFeaturesARM,
    VkPhysicalDeviceDataGraphProcessingEngineARM,
    VkPhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV,
    VkPhysicalDeviceDenseGeometryFormatFeaturesAMDX,
    VkPhysicalDeviceDepthBiasControlFeaturesEXT,
    VkPhysicalDeviceDepthClampControlFeaturesEXT,
    VkPhysicalDeviceDepthClampZeroOneFeaturesKHR,
    VkPhysicalDeviceDepthClipControlFeaturesEXT,
    VkPhysicalDeviceDepthClipEnableFeaturesEXT,
    VkPhysicalDeviceDepthStencilResolveProperties,
    VkPhysicalDeviceDescriptorBufferDensityMapPropertiesEXT,
    VkPhysicalDeviceDescriptorBufferFeaturesEXT,
    VkPhysicalDeviceDescriptorBufferPropertiesEXT,
    VkPhysicalDeviceDescriptorBufferTensorFeaturesARM,
    VkPhysicalDeviceDescriptorBufferTensorPropertiesARM,
    VkPhysicalDeviceDescriptorHeapFeaturesEXT,
    VkPhysicalDeviceDescriptorHeapPropertiesEXT,
    VkPhysicalDeviceDescriptorHeapTensorPropertiesARM,
    VkPhysicalDeviceDescriptorIndexingFeatures,
    VkPhysicalDeviceDescriptorIndexingProperties,
    VkPhysicalDeviceDescriptorPoolOverallocationFeaturesNV,
    VkPhysicalDeviceDescriptorSetHostMappingFeaturesVALVE,
    VkPhysicalDeviceDeviceAddressCommandsFeaturesKHR,
    VkPhysicalDeviceDeviceGeneratedCommandsComputeFeaturesNV,
    VkPhysicalDeviceDeviceGeneratedCommandsFeaturesEXT,
    VkPhysicalDeviceDeviceGeneratedCommandsFeaturesNV,
    VkPhysicalDeviceDeviceGeneratedCommandsPropertiesEXT,
    VkPhysicalDeviceDeviceGeneratedCommandsPropertiesNV,
    VkPhysicalDeviceDeviceMemoryReportFeaturesEXT,
    VkPhysicalDeviceDiagnosticsConfigFeaturesNV,
    VkPhysicalDeviceDiscardRectanglePropertiesEXT,
    VkPhysicalDeviceDisplacementMicromapFeaturesNV,
    VkPhysicalDeviceDisplacementMicromapPropertiesNV,
    VkPhysicalDeviceDriverProperties,
    VkPhysicalDeviceDrmPropertiesEXT,
    VkPhysicalDeviceDynamicRenderingFeatures,
    VkPhysicalDeviceDynamicRenderingLocalReadFeatures,
    VkPhysicalDeviceDynamicRenderingUnusedAttachmentsFeaturesEXT,
    VkPhysicalDeviceElapsedTimerQueryFeaturesQCOM,
    VkPhysicalDeviceExclusiveScissorFeaturesNV,
    VkPhysicalDeviceExtendedDynamicState2FeaturesEXT,
    VkPhysicalDeviceExtendedDynamicState3FeaturesEXT,
    VkPhysicalDeviceExtendedDynamicState3PropertiesEXT,
    VkPhysicalDeviceExtendedDynamicStateFeaturesEXT,
    VkPhysicalDeviceExtendedFlagsFeaturesKHR,
    VkPhysicalDeviceExtendedSparseAddressSpaceFeaturesNV,
    VkPhysicalDeviceExtendedSparseAddressSpacePropertiesNV,
    VkPhysicalDeviceExternalBufferInfo,
    VkPhysicalDeviceExternalComputeQueuePropertiesNV,
    VkPhysicalDeviceExternalFenceInfo,
    VkPhysicalDeviceExternalFormatResolveFeaturesANDROID,
    VkPhysicalDeviceExternalFormatResolvePropertiesANDROID,
    VkPhysicalDeviceExternalImageFormatInfo,
    VkPhysicalDeviceExternalMemoryHostPropertiesEXT,
    VkPhysicalDeviceExternalMemoryRDMAFeaturesNV,
    VkPhysicalDeviceExternalMemoryScreenBufferFeaturesQNX,
    VkPhysicalDeviceExternalSemaphoreInfo,
    VkPhysicalDeviceExternalTensorInfoARM,
    VkPhysicalDeviceFaultFeaturesEXT,
    VkPhysicalDeviceFaultFeaturesKHR,
    VkPhysicalDeviceFaultPropertiesKHR,
    VkPhysicalDeviceFeatures,
    VkPhysicalDeviceFeatures2,
    VkPhysicalDeviceFloatControlsProperties,
    VkPhysicalDeviceFormatPackFeaturesARM,
    VkPhysicalDeviceFragmentDensityMap2FeaturesEXT,
    VkPhysicalDeviceFragmentDensityMap2PropertiesEXT,
    VkPhysicalDeviceFragmentDensityMapFeaturesEXT,
    VkPhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE,
    VkPhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE,
    VkPhysicalDeviceFragmentDensityMapOffsetFeaturesEXT,
    VkPhysicalDeviceFragmentDensityMapOffsetPropertiesEXT,
    VkPhysicalDeviceFragmentDensityMapPropertiesEXT,
    VkPhysicalDeviceFragmentShaderBarycentricFeaturesKHR,
    VkPhysicalDeviceFragmentShaderBarycentricPropertiesKHR,
    VkPhysicalDeviceFragmentShaderInterlockFeaturesEXT,
    VkPhysicalDeviceFragmentShadingRateEnumsFeaturesNV,
    VkPhysicalDeviceFragmentShadingRateEnumsPropertiesNV,
    VkPhysicalDeviceFragmentShadingRateFeaturesKHR,
    VkPhysicalDeviceFragmentShadingRateKHR,
    VkPhysicalDeviceFragmentShadingRatePropertiesKHR,
    VkPhysicalDeviceFrameBoundaryFeaturesEXT,
    VkPhysicalDeviceGlobalPriorityQueryFeatures,
    VkPhysicalDeviceGpaFeaturesAMD,
    VkPhysicalDeviceGpaProperties2AMD,
    VkPhysicalDeviceGpaPropertiesAMD,
    VkPhysicalDeviceGraphicsPipelineLibraryFeaturesEXT,
    VkPhysicalDeviceGraphicsPipelineLibraryPropertiesEXT,
    VkPhysicalDeviceGroupProperties,
    VkPhysicalDeviceHdrVividFeaturesHUAWEI,
    VkPhysicalDeviceHostImageCopyFeatures,
    VkPhysicalDeviceHostImageCopyProperties,
    VkPhysicalDeviceHostQueryResetFeatures,
    VkPhysicalDeviceIDProperties,
    VkPhysicalDeviceImage2DViewOf3DFeaturesEXT,
    VkPhysicalDeviceImageAlignmentControlFeaturesMESA,
    VkPhysicalDeviceImageAlignmentControlPropertiesMESA,
    VkPhysicalDeviceImageCompressionControlFeaturesEXT,
    VkPhysicalDeviceImageCompressionControlSwapchainFeaturesEXT,
    VkPhysicalDeviceImageDrmFormatModifierInfoEXT,
    VkPhysicalDeviceImageFormatInfo2,
    VkPhysicalDeviceImageProcessing2FeaturesQCOM,
    VkPhysicalDeviceImageProcessing2PropertiesQCOM,
    VkPhysicalDeviceImageProcessing3FeaturesQCOM,
    VkPhysicalDeviceImageProcessingFeaturesQCOM,
    VkPhysicalDeviceImageProcessingPropertiesQCOM,
    VkPhysicalDeviceImageRobustnessFeatures,
    VkPhysicalDeviceImageSlicedViewOf3DFeaturesEXT,
    VkPhysicalDeviceImageViewImageFormatInfoEXT,
    VkPhysicalDeviceImageViewMinLodFeaturesEXT,
    VkPhysicalDeviceImagelessFramebufferFeatures,
    VkPhysicalDeviceIndexTypeUint8Features,
    VkPhysicalDeviceInheritedViewportScissorFeaturesNV,
    VkPhysicalDeviceInlineUniformBlockFeatures,
    VkPhysicalDeviceInlineUniformBlockProperties,
    VkPhysicalDeviceInternallySynchronizedQueuesFeaturesKHR,
    VkPhysicalDeviceInvocationMaskFeaturesHUAWEI,
    VkPhysicalDeviceLayeredApiPropertiesKHR,
    VkPhysicalDeviceLayeredApiPropertiesListKHR,
    VkPhysicalDeviceLayeredApiVulkanPropertiesKHR,
    VkPhysicalDeviceLayeredDriverPropertiesMSFT,
    VkPhysicalDeviceLegacyDitheringFeaturesEXT,
    VkPhysicalDeviceLegacyVertexAttributesFeaturesEXT,
    VkPhysicalDeviceLegacyVertexAttributesPropertiesEXT,
    VkPhysicalDeviceLimits,
    VkPhysicalDeviceLineRasterizationFeatures,
    VkPhysicalDeviceLineRasterizationProperties,
    VkPhysicalDeviceLinearColorAttachmentFeaturesNV,
    VkPhysicalDeviceMaintenance10FeaturesKHR,
    VkPhysicalDeviceMaintenance10PropertiesKHR,
    VkPhysicalDeviceMaintenance11FeaturesKHR,
    VkPhysicalDeviceMaintenance3Properties,
    VkPhysicalDeviceMaintenance4Features,
    VkPhysicalDeviceMaintenance4Properties,
    VkPhysicalDeviceMaintenance5Features,
    VkPhysicalDeviceMaintenance5Properties,
    VkPhysicalDeviceMaintenance6Features,
    VkPhysicalDeviceMaintenance6Properties,
    VkPhysicalDeviceMaintenance7FeaturesKHR,
    VkPhysicalDeviceMaintenance7PropertiesKHR,
    VkPhysicalDeviceMaintenance8FeaturesKHR,
    VkPhysicalDeviceMaintenance9FeaturesKHR,
    VkPhysicalDeviceMaintenance9PropertiesKHR,
    VkPhysicalDeviceMapMemoryPlacedFeaturesEXT,
    VkPhysicalDeviceMapMemoryPlacedPropertiesEXT,
    VkPhysicalDeviceMemoryBudgetPropertiesEXT,
    VkPhysicalDeviceMemoryDecompressionFeaturesEXT,
    VkPhysicalDeviceMemoryDecompressionPropertiesEXT,
    VkPhysicalDeviceMemoryPriorityFeaturesEXT,
    VkPhysicalDeviceMemoryProperties,
    VkPhysicalDeviceMemoryProperties2,
    VkPhysicalDeviceMeshShaderFeaturesEXT,
    VkPhysicalDeviceMeshShaderFeaturesNV,
    VkPhysicalDeviceMeshShaderPropertiesEXT,
    VkPhysicalDeviceMeshShaderPropertiesNV,
    VkPhysicalDeviceMultiDrawFeaturesEXT,
    VkPhysicalDeviceMultiDrawPropertiesEXT,
    VkPhysicalDeviceMultisampledRenderToSingleSampledFeaturesEXT,
    VkPhysicalDeviceMultisampledRenderToSwapchainFeaturesEXT,
    VkPhysicalDeviceMultiviewFeatures,
    VkPhysicalDeviceMultiviewPerViewAttributesPropertiesNVX,
    VkPhysicalDeviceMultiviewPerViewRenderAreasFeaturesQCOM,
    VkPhysicalDeviceMultiviewPerViewViewportsFeaturesQCOM,
    VkPhysicalDeviceMultiviewProperties,
    VkPhysicalDeviceMutableDescriptorTypeFeaturesEXT,
    VkPhysicalDeviceNestedCommandBufferFeaturesEXT,
    VkPhysicalDeviceNestedCommandBufferPropertiesEXT,
    VkPhysicalDeviceNonSeamlessCubeMapFeaturesEXT,
    VkPhysicalDeviceOpacityMicromapFeaturesEXT,
    VkPhysicalDeviceOpacityMicromapFeaturesKHR,
    VkPhysicalDeviceOpacityMicromapPropertiesEXT,
    VkPhysicalDeviceOpacityMicromapPropertiesKHR,
    VkPhysicalDeviceOpticalFlowFeaturesNV,
    VkPhysicalDeviceOpticalFlowPropertiesNV,
    VkPhysicalDevicePCIBusInfoPropertiesEXT,
    VkPhysicalDevicePageableDeviceLocalMemoryFeaturesEXT,
    VkPhysicalDevicePartitionedAccelerationStructureFeaturesNV,
    VkPhysicalDevicePartitionedAccelerationStructurePropertiesNV,
    VkPhysicalDevicePerStageDescriptorSetFeaturesNV,
    VkPhysicalDevicePerformanceCountersByRegionFeaturesARM,
    VkPhysicalDevicePerformanceCountersByRegionPropertiesARM,
    VkPhysicalDevicePerformanceQueryFeaturesKHR,
    VkPhysicalDevicePerformanceQueryPropertiesKHR,
    VkPhysicalDevicePipelineBinaryFeaturesKHR,
    VkPhysicalDevicePipelineBinaryPropertiesKHR,
    VkPhysicalDevicePipelineCacheIncrementalModeFeaturesSEC,
    VkPhysicalDevicePipelineCreationCacheControlFeatures,
    VkPhysicalDevicePipelineExecutablePropertiesFeaturesKHR,
    VkPhysicalDevicePipelineLibraryGroupHandlesFeaturesEXT,
    VkPhysicalDevicePipelineOpacityMicromapFeaturesARM,
    VkPhysicalDevicePipelinePropertiesFeaturesEXT,
    VkPhysicalDevicePipelineProtectedAccessFeatures,
    VkPhysicalDevicePipelineRobustnessFeatures,
    VkPhysicalDevicePipelineRobustnessProperties,
    VkPhysicalDevicePointClippingProperties,
    VkPhysicalDevicePortabilitySubsetFeaturesKHR,
    VkPhysicalDevicePortabilitySubsetPropertiesKHR,
    VkPhysicalDevicePresentBarrierFeaturesNV,
    VkPhysicalDevicePresentId2FeaturesKHR,
    VkPhysicalDevicePresentIdFeaturesKHR,
    VkPhysicalDevicePresentMeteringFeaturesNV,
    VkPhysicalDevicePresentModeFifoLatestReadyFeaturesKHR,
    VkPhysicalDevicePresentTimingFeaturesEXT,
    VkPhysicalDevicePresentWait2FeaturesKHR,
    VkPhysicalDevicePresentWaitFeaturesKHR,
    VkPhysicalDevicePrimitiveRestartIndexFeaturesEXT,
    VkPhysicalDevicePrimitiveTopologyListRestartFeaturesEXT,
    VkPhysicalDevicePrimitivesGeneratedQueryFeaturesEXT,
    VkPhysicalDevicePrivateDataFeatures,
    VkPhysicalDeviceProperties,
    VkPhysicalDeviceProperties2,
    VkPhysicalDeviceProtectedMemoryFeatures,
    VkPhysicalDeviceProtectedMemoryProperties,
    VkPhysicalDeviceProvokingVertexFeaturesEXT,
    VkPhysicalDeviceProvokingVertexPropertiesEXT,
    VkPhysicalDevicePushConstantBankFeaturesNV,
    VkPhysicalDevicePushConstantBankPropertiesNV,
    VkPhysicalDevicePushDescriptorProperties,
    VkPhysicalDeviceQueueFamilyDataGraphProcessingEngineInfoARM,
    VkPhysicalDeviceQueuePerfHintFeaturesQCOM,
    VkPhysicalDeviceQueuePerfHintPropertiesQCOM,
    VkPhysicalDeviceRGBA10X6FormatsFeaturesEXT,
    VkPhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT,
    VkPhysicalDeviceRawAccessChainsFeaturesNV,
    VkPhysicalDeviceRayQueryFeaturesKHR,
    VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT,
    VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV,
    VkPhysicalDeviceRayTracingInvocationReorderPropertiesEXT,
    VkPhysicalDeviceRayTracingInvocationReorderPropertiesNV,
    VkPhysicalDeviceRayTracingLinearSweptSpheresFeaturesNV,
    VkPhysicalDeviceRayTracingMaintenance1FeaturesKHR,
    VkPhysicalDeviceRayTracingMotionBlurFeaturesNV,
    VkPhysicalDeviceRayTracingPipelineFeaturesKHR,
    VkPhysicalDeviceRayTracingPipelinePropertiesKHR,
    VkPhysicalDeviceRayTracingPositionFetchFeaturesKHR,
    VkPhysicalDeviceRayTracingPropertiesNV,
    VkPhysicalDeviceRayTracingValidationFeaturesNV,
    VkPhysicalDeviceRelaxedLineRasterizationFeaturesIMG,
    VkPhysicalDeviceRenderPassStripedFeaturesARM,
    VkPhysicalDeviceRenderPassStripedPropertiesARM,
    VkPhysicalDeviceRepresentativeFragmentTestFeaturesNV,
    VkPhysicalDeviceRobustness2FeaturesKHR,
    VkPhysicalDeviceRobustness2PropertiesKHR,
    VkPhysicalDeviceSampleLocationsPropertiesEXT,
    VkPhysicalDeviceSamplerFilterMinmaxProperties,
    VkPhysicalDeviceSamplerYcbcrConversionFeatures,
    VkPhysicalDeviceScalarBlockLayoutFeatures,
    VkPhysicalDeviceSchedulingControlsDispatchParametersPropertiesARM,
    VkPhysicalDeviceSchedulingControlsFeaturesARM,
    VkPhysicalDeviceSchedulingControlsPropertiesARM,
    VkPhysicalDeviceSeparateDepthStencilLayoutsFeatures,
    VkPhysicalDeviceShader64BitIndexingFeaturesEXT,
    VkPhysicalDeviceShaderAbortFeaturesKHR,
    VkPhysicalDeviceShaderAbortPropertiesKHR,
    VkPhysicalDeviceShaderAtomicFloat16VectorFeaturesNV,
    VkPhysicalDeviceShaderAtomicFloat2FeaturesEXT,
    VkPhysicalDeviceShaderAtomicFloatFeaturesEXT,
    VkPhysicalDeviceShaderAtomicInt64Features,
    VkPhysicalDeviceShaderBfloat16FeaturesKHR,
    VkPhysicalDeviceShaderClockFeaturesKHR,
    VkPhysicalDeviceShaderConstantDataFeaturesKHR,
    VkPhysicalDeviceShaderCoreBuiltinsFeaturesARM,
    VkPhysicalDeviceShaderCoreBuiltinsPropertiesARM,
    VkPhysicalDeviceShaderCoreProperties2AMD,
    VkPhysicalDeviceShaderCorePropertiesAMD,
    VkPhysicalDeviceShaderCorePropertiesARM,
    VkPhysicalDeviceShaderDemoteToHelperInvocationFeatures,
    VkPhysicalDeviceShaderDrawParametersFeatures,
    VkPhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD,
    VkPhysicalDeviceShaderEnqueueFeaturesAMDX,
    VkPhysicalDeviceShaderEnqueuePropertiesAMDX,
    VkPhysicalDeviceShaderExpectAssumeFeatures,
    VkPhysicalDeviceShaderFloat16Int8Features,
    VkPhysicalDeviceShaderFloat8FeaturesEXT,
    VkPhysicalDeviceShaderFloatControls2Features,
    VkPhysicalDeviceShaderFmaFeaturesKHR,
    VkPhysicalDeviceShaderImageAtomicInt64FeaturesEXT,
    VkPhysicalDeviceShaderImageFootprintFeaturesNV,
    VkPhysicalDeviceShaderInstrumentationFeaturesARM,
    VkPhysicalDeviceShaderInstrumentationPropertiesARM,
    VkPhysicalDeviceShaderIntegerDotProductFeatures,
    VkPhysicalDeviceShaderIntegerDotProductProperties,
    VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTEL,
    VkPhysicalDeviceShaderLongVectorFeaturesEXT,
    VkPhysicalDeviceShaderLongVectorPropertiesEXT,
    VkPhysicalDeviceShaderMaximalReconvergenceFeaturesKHR,
    VkPhysicalDeviceShaderMixedFloatDotProductFeaturesVALVE,
    VkPhysicalDeviceShaderModuleIdentifierFeaturesEXT,
    VkPhysicalDeviceShaderModuleIdentifierPropertiesEXT,
    VkPhysicalDeviceShaderMultipleWaitQueuesFeaturesQCOM,
    VkPhysicalDeviceShaderMultipleWaitQueuesPropertiesQCOM,
    VkPhysicalDeviceShaderOCPMicroscalingTypesFeaturesEXT,
    VkPhysicalDeviceShaderObjectFeaturesEXT,
    VkPhysicalDeviceShaderObjectPropertiesEXT,
    VkPhysicalDeviceShaderQuadControlFeaturesKHR,
    VkPhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR,
    VkPhysicalDeviceShaderReplicatedCompositesFeaturesEXT,
    VkPhysicalDeviceShaderSMBuiltinsFeaturesNV,
    VkPhysicalDeviceShaderSMBuiltinsPropertiesNV,
    VkPhysicalDeviceShaderSplitBarrierFeaturesEXT,
    VkPhysicalDeviceShaderSplitBarrierPropertiesEXT,
    VkPhysicalDeviceShaderSubgroupExtendedTypesFeatures,
    VkPhysicalDeviceShaderSubgroupPartitionedFeaturesEXT,
    VkPhysicalDeviceShaderSubgroupRotateFeatures,
    VkPhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR,
    VkPhysicalDeviceShaderTerminateInvocationFeatures,
    VkPhysicalDeviceShaderTileImageFeaturesEXT,
    VkPhysicalDeviceShaderTileImagePropertiesEXT,
    VkPhysicalDeviceShaderUniformBufferUnsizedArrayFeaturesEXT,
    VkPhysicalDeviceShaderUntypedPointersFeaturesKHR,
    VkPhysicalDeviceShadingRateImageFeaturesNV,
    VkPhysicalDeviceShadingRateImagePropertiesNV,
    VkPhysicalDeviceSparseImageFormatInfo2,
    VkPhysicalDeviceSparseProperties,
    VkPhysicalDeviceSubgroupProperties,
    VkPhysicalDeviceSubgroupSizeControlFeatures,
    VkPhysicalDeviceSubgroupSizeControlProperties,
    VkPhysicalDeviceSubpassMergeFeedbackFeaturesEXT,
    VkPhysicalDeviceSubpassShadingFeaturesHUAWEI,
    VkPhysicalDeviceSubpassShadingPropertiesHUAWEI,
    VkPhysicalDeviceSurfaceInfo2KHR,
    VkPhysicalDeviceSwapchainMaintenance1FeaturesKHR,
    VkPhysicalDeviceSynchronization2Features,
    VkPhysicalDeviceTensorFeaturesARM,
    VkPhysicalDeviceTensorPropertiesARM,
    VkPhysicalDeviceTexelBufferAlignmentFeaturesEXT,
    VkPhysicalDeviceTexelBufferAlignmentProperties,
    VkPhysicalDeviceTextureCompressionASTC3DFeaturesEXT,
    VkPhysicalDeviceTextureCompressionASTCHDRFeatures,
    VkPhysicalDeviceThrottleHintFeaturesSEC,
    VkPhysicalDeviceTileMemoryHeapFeaturesQCOM,
    VkPhysicalDeviceTileMemoryHeapPropertiesQCOM,
    VkPhysicalDeviceTilePropertiesFeaturesQCOM,
    VkPhysicalDeviceTileShadingFeaturesQCOM,
    VkPhysicalDeviceTileShadingPropertiesQCOM,
    VkPhysicalDeviceTimelineSemaphoreFeatures,
    VkPhysicalDeviceTimelineSemaphoreProperties,
    VkPhysicalDeviceToolProperties,
    VkPhysicalDeviceTransformFeedbackFeaturesEXT,
    VkPhysicalDeviceTransformFeedbackPropertiesEXT,
    VkPhysicalDeviceUnifiedImageLayoutsFeaturesKHR,
    VkPhysicalDeviceUniformBufferStandardLayoutFeatures,
    VkPhysicalDeviceVariablePointersFeatures,
    VkPhysicalDeviceVertexAttributeDivisorFeatures,
    VkPhysicalDeviceVertexAttributeDivisorProperties,
    VkPhysicalDeviceVertexAttributeDivisorPropertiesEXT,
    VkPhysicalDeviceVertexAttributeRobustnessFeaturesEXT,
    VkPhysicalDeviceVertexInputDynamicStateFeaturesEXT,
    VkPhysicalDeviceVideoDecodeVP9FeaturesKHR,
    VkPhysicalDeviceVideoEncodeAV1FeaturesKHR,
    VkPhysicalDeviceVideoEncodeFeedback2FeaturesKHR,
    VkPhysicalDeviceVideoEncodeIntraRefreshFeaturesKHR,
    VkPhysicalDeviceVideoEncodeQualityLevelInfoKHR,
    VkPhysicalDeviceVideoEncodeQuantizationMapFeaturesKHR,
    VkPhysicalDeviceVideoEncodeRgbConversionFeaturesVALVE,
    VkPhysicalDeviceVideoFormatInfoKHR,
    VkPhysicalDeviceVideoMaintenance1FeaturesKHR,
    VkPhysicalDeviceVideoMaintenance2FeaturesKHR,
    VkPhysicalDeviceVulkan11Features,
    VkPhysicalDeviceVulkan11Properties,
    VkPhysicalDeviceVulkan12Features,
    VkPhysicalDeviceVulkan12Properties,
    VkPhysicalDeviceVulkan13Features,
    VkPhysicalDeviceVulkan13Properties,
    VkPhysicalDeviceVulkan14Features,
    VkPhysicalDeviceVulkan14Properties,
    VkPhysicalDeviceVulkanMemoryModelFeatures,
    VkPhysicalDeviceWorkgroupMemoryExplicitLayoutFeaturesKHR,
    VkPhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT,
    VkPhysicalDeviceYcbcrDegammaFeaturesQCOM,
    VkPhysicalDeviceYcbcrImageArraysFeaturesEXT,
    VkPhysicalDeviceZeroInitializeDeviceMemoryFeaturesEXT,
    VkPhysicalDeviceZeroInitializeWorkgroupMemoryFeatures,
    VkPipelineBinaryCreateInfoKHR,
    VkPipelineBinaryDataInfoKHR,
    VkPipelineBinaryDataKHR,
    VkPipelineBinaryHandlesInfoKHR,
    VkPipelineBinaryInfoKHR,
    VkPipelineBinaryKeyKHR,
    VkPipelineBinaryKeysAndDataKHR,
    VkPipelineCacheCreateInfo,
    VkPipelineCacheHeaderVersionDataGraphQCOM,
    VkPipelineCacheHeaderVersionOne,
    VkPipelineColorBlendAdvancedStateCreateInfoEXT,
    VkPipelineColorBlendAttachmentState,
    VkPipelineColorBlendStateCreateInfo,
    VkPipelineColorWriteCreateInfoEXT,
    VkPipelineCompilerControlCreateInfoAMD,
    VkPipelineCoverageModulationStateCreateInfoNV,
    VkPipelineCoverageReductionStateCreateInfoNV,
    VkPipelineCoverageToColorStateCreateInfoNV,
    VkPipelineCreateFlags2CreateInfo,
    VkPipelineCreateInfoKHR,
    VkPipelineCreationFeedback,
    VkPipelineCreationFeedbackCreateInfo,
    VkPipelineDepthStencilStateCreateInfo,
    VkPipelineDiscardRectangleStateCreateInfoEXT,
    VkPipelineDynamicStateCreateInfo,
    VkPipelineExecutableInfoKHR,
    VkPipelineExecutableInternalRepresentationKHR,
    VkPipelineExecutablePropertiesKHR,
    VkPipelineExecutableStatisticKHR,
    VkPipelineExecutableStatisticValueKHR,
    VkPipelineFragmentDensityMapLayeredCreateInfoVALVE,
    VkPipelineFragmentShadingRateEnumStateCreateInfoNV,
    VkPipelineFragmentShadingRateStateCreateInfoKHR,
    VkPipelineIndirectDeviceAddressInfoNV,
    VkPipelineInfoKHR,
    VkPipelineInputAssemblyStateCreateInfo,
    VkPipelineLayoutCreateInfo,
    VkPipelineLibraryCreateInfoKHR,
    VkPipelineMultisampleStateCreateInfo,
    VkPipelinePropertiesIdentifierEXT,
    VkPipelineRasterizationConservativeStateCreateInfoEXT,
    VkPipelineRasterizationDepthClipStateCreateInfoEXT,
    VkPipelineRasterizationLineStateCreateInfo,
    VkPipelineRasterizationProvokingVertexStateCreateInfoEXT,
    VkPipelineRasterizationStateCreateInfo,
    VkPipelineRasterizationStateRasterizationOrderAMD,
    VkPipelineRasterizationStateStreamCreateInfoEXT,
    VkPipelineRenderingCreateInfo,
    VkPipelineRepresentativeFragmentTestStateCreateInfoNV,
    VkPipelineRobustnessCreateInfo,
    VkPipelineSampleLocationsStateCreateInfoEXT,
    VkPipelineShaderStageCreateInfo,
    VkPipelineShaderStageModuleIdentifierCreateInfoEXT,
    VkPipelineShaderStageNodeCreateInfoAMDX,
    VkPipelineShaderStageRequiredSubgroupSizeCreateInfo,
    VkPipelineTessellationDomainOriginStateCreateInfo,
    VkPipelineTessellationStateCreateInfo,
    VkPipelineVertexInputDivisorStateCreateInfo,
    VkPipelineVertexInputStateCreateInfo,
    VkPipelineViewportCoarseSampleOrderStateCreateInfoNV,
    VkPipelineViewportDepthClampControlCreateInfoEXT,
    VkPipelineViewportDepthClipControlCreateInfoEXT,
    VkPipelineViewportExclusiveScissorStateCreateInfoNV,
    VkPipelineViewportShadingRateImageStateCreateInfoNV,
    VkPipelineViewportStateCreateInfo,
    VkPipelineViewportSwizzleStateCreateInfoNV,
    VkPipelineViewportWScalingStateCreateInfoNV,
    VkPresentFrameTokenGGP,
    VkPresentId2KHR,
    VkPresentIdKHR,
    VkPresentInfoKHR,
    VkPresentRegionKHR,
    VkPresentRegionsKHR,
    VkPresentStageTimeEXT,
    VkPresentTimeGOOGLE,
    VkPresentTimesInfoGOOGLE,
    VkPresentTimingInfoEXT,
    VkPresentTimingSurfaceCapabilitiesEXT,
    VkPresentTimingsInfoEXT,
    VkPresentWait2InfoKHR,
    VkPrivateDataSlotCreateInfo,
    VkProtectedSubmitInfo,
    VkPushConstantBankInfoNV,
    VkPushConstantRange,
    VkPushConstantsInfo,
    VkPushDataInfoEXT,
    VkPushDescriptorSetInfo,
    VkPushDescriptorSetWithTemplateInfo,
    VkQueryLowLatencySupportNV,
    VkQueryPoolCreateInfo,
    VkQueryPoolPerformanceCreateInfoKHR,
    VkQueryPoolPerformanceQueryCreateInfoINTEL,
    VkQueryPoolVideoEncodeFeedbackCreateInfoKHR,
    VkQueryPoolVideoEncodePerPartitionFeedbackCreateInfoKHR,
    VkQueueFamilyCheckpointProperties2NV,
    VkQueueFamilyCheckpointPropertiesNV,
    VkQueueFamilyDataGraphOpticalFlowPropertiesARM,
    VkQueueFamilyDataGraphProcessingEnginePropertiesARM,
    VkQueueFamilyDataGraphPropertiesARM,
    VkQueueFamilyDataGraphTOSAPropertiesARM,
    VkQueueFamilyGlobalPriorityProperties,
    VkQueueFamilyOptimalImageTransferGranularityPropertiesKHR,
    VkQueueFamilyOwnershipTransferPropertiesKHR,
    VkQueueFamilyProperties,
    VkQueueFamilyProperties2,
    VkQueueFamilyQueryResultStatusPropertiesKHR,
    VkQueueFamilyVideoPropertiesKHR,
    VkRayTracingPipelineClusterAccelerationStructureCreateInfoNV,
    VkRayTracingPipelineCreateInfoKHR,
    VkRayTracingPipelineCreateInfoNV,
    VkRayTracingPipelineInterfaceCreateInfoKHR,
    VkRayTracingShaderGroupCreateInfoKHR,
    VkRayTracingShaderGroupCreateInfoNV,
    VkRect2D,
    VkRectLayerKHR,
    VkRefreshCycleDurationGOOGLE,
    VkReleaseCapturedPipelineDataInfoKHR,
    VkReleaseSwapchainImagesInfoKHR,
    VkRenderPassAttachmentBeginInfo,
    VkRenderPassBeginInfo,
    VkRenderPassCreateInfo,
    VkRenderPassCreateInfo2,
    VkRenderPassCreationControlEXT,
    VkRenderPassCreationFeedbackCreateInfoEXT,
    VkRenderPassCreationFeedbackInfoEXT,
    VkRenderPassFragmentDensityMapCreateInfoEXT,
    VkRenderPassFragmentDensityMapOffsetEndInfoEXT,
    VkRenderPassInputAttachmentAspectCreateInfo,
    VkRenderPassMultiviewCreateInfo,
    VkRenderPassPerformanceCountersByRegionBeginInfoARM,
    VkRenderPassSampleLocationsBeginInfoEXT,
    VkRenderPassStripeBeginInfoARM,
    VkRenderPassStripeInfoARM,
    VkRenderPassStripeSubmitInfoARM,
    VkRenderPassSubpassFeedbackCreateInfoEXT,
    VkRenderPassSubpassFeedbackInfoEXT,
    VkRenderPassTileShadingCreateInfoQCOM,
    VkRenderPassTransformBeginInfoQCOM,
    VkRenderingAreaInfo,
    VkRenderingAttachmentFlagsInfoKHR,
    VkRenderingAttachmentInfo,
    VkRenderingAttachmentLocationInfo,
    VkRenderingEndInfoKHR,
    VkRenderingFragmentDensityMapAttachmentInfoEXT,
    VkRenderingFragmentShadingRateAttachmentInfoKHR,
    VkRenderingInfo,
    VkRenderingInputAttachmentIndexInfo,
    VkResolveImageInfo2,
    VkResolveImageModeInfoKHR,
    VkResourceDescriptorDataEXT,
    VkResourceDescriptorInfoEXT,
    VkSRTDataNV,
    VkSampleLocationEXT,
    VkSampleLocationsInfoEXT,
    VkSamplerBlockMatchWindowCreateInfoQCOM,
    VkSamplerBorderColorComponentMappingCreateInfoEXT,
    VkSamplerCaptureDescriptorDataInfoEXT,
    VkSamplerCreateInfo,
    VkSamplerCubicWeightsCreateInfoQCOM,
    VkSamplerCustomBorderColorCreateInfoEXT,
    VkSamplerCustomBorderColorIndexCreateInfoEXT,
    VkSamplerReductionModeCreateInfo,
    VkSamplerYcbcrConversionCreateInfo,
    VkSamplerYcbcrConversionImageFormatProperties,
    VkSamplerYcbcrConversionInfo,
    VkSamplerYcbcrConversionYcbcrDegammaCreateInfoQCOM,
    VkScreenBufferFormatPropertiesQNX,
    VkScreenBufferPropertiesQNX,
    VkScreenSurfaceCreateInfoQNX,
    VkSemaphoreCreateInfo,
    VkSemaphoreGetFdInfoKHR,
    VkSemaphoreGetWin32HandleInfoKHR,
    VkSemaphoreGetZirconHandleInfoFUCHSIA,
    VkSemaphoreSignalInfo,
    VkSemaphoreSubmitInfo,
    VkSemaphoreTypeCreateInfo,
    VkSemaphoreWaitInfo,
    VkSetDescriptorBufferOffsetsInfoEXT,
    VkSetLatencyMarkerInfoNV,
    VkSetPresentConfigNV,
    VkSetStateFlagsIndirectCommandNV,
    VkShaderCreateInfoEXT,
    VkShaderDescriptorSetAndBindingMappingInfoEXT,
    VkShaderInstrumentationCreateInfoARM,
    VkShaderInstrumentationMetricDataHeaderARM,
    VkShaderInstrumentationMetricDescriptionARM,
    VkShaderModuleCreateInfo,
    VkShaderModuleIdentifierEXT,
    VkShaderModuleValidationCacheCreateInfoEXT,
    VkShaderResourceUsageAMD,
    VkShaderStatisticsInfoAMD,
    VkShadingRatePaletteNV,
    VkSharedPresentSurfaceCapabilities2KHR,
    VkSharedPresentSurfaceCapabilitiesKHR,
    VkSparseBufferMemoryBindInfo,
    VkSparseImageFormatProperties,
    VkSparseImageFormatProperties2,
    VkSparseImageMemoryBind,
    VkSparseImageMemoryBindInfo,
    VkSparseImageMemoryRequirements,
    VkSparseImageMemoryRequirements2,
    VkSparseImageOpaqueMemoryBindInfo,
    VkSparseMemoryBind,
    VkSpecializationInfo,
    VkSpecializationMapEntry,
    VkStencilOpState,
    VkStreamDescriptorSurfaceCreateInfoGGP,
    VkStridedDeviceAddressNV,
    VkStridedDeviceAddressRangeKHR,
    VkStridedDeviceAddressRegionKHR,
    VkSubmitInfo,
    VkSubmitInfo2,
    VkSubpassBeginInfo,
    VkSubpassDependency,
    VkSubpassDependency2,
    VkSubpassDescription,
    VkSubpassDescription2,
    VkSubpassDescriptionDepthStencilResolve,
    VkSubpassEndInfo,
    VkSubpassResolvePerformanceQueryEXT,
    VkSubpassSampleLocationsEXT,
    VkSubpassShadingPipelineCreateInfoHUAWEI,
    VkSubresourceHostMemcpySize,
    VkSubresourceLayout,
    VkSubresourceLayout2,
    VkSubsampledImageFormatPropertiesEXT,
    VkSurfaceCapabilities2EXT,
    VkSurfaceCapabilities2KHR,
    VkSurfaceCapabilitiesFullScreenExclusiveEXT,
    VkSurfaceCapabilitiesKHR,
    VkSurfaceCapabilitiesPresentBarrierNV,
    VkSurfaceCapabilitiesPresentId2KHR,
    VkSurfaceCapabilitiesPresentWait2KHR,
    VkSurfaceCreateInfoOHOS,
    VkSurfaceFormat2KHR,
    VkSurfaceFormatKHR,
    VkSurfaceFullScreenExclusiveInfoEXT,
    VkSurfaceFullScreenExclusiveWin32InfoEXT,
    VkSurfacePresentModeCompatibilityKHR,
    VkSurfacePresentModeKHR,
    VkSurfacePresentScalingCapabilitiesKHR,
    VkSurfaceProtectedCapabilitiesKHR,
    VkSwapchainCalibratedTimestampInfoEXT,
    VkSwapchainCounterCreateInfoEXT,
    VkSwapchainCreateInfoKHR,
    VkSwapchainDisplayNativeHdrCreateInfoAMD,
    VkSwapchainFlagsSurfaceCapabilitiesEXT,
    VkSwapchainLatencyCreateInfoNV,
    VkSwapchainPresentBarrierCreateInfoNV,
    VkSwapchainPresentFenceInfoKHR,
    VkSwapchainPresentModeInfoKHR,
    VkSwapchainPresentModesCreateInfoKHR,
    VkSwapchainPresentScalingCreateInfoKHR,
    VkSwapchainTimeDomainPropertiesEXT,
    VkSwapchainTimingPropertiesEXT,
    VkSysmemColorSpaceFUCHSIA,
    VkTensorCaptureDescriptorDataInfoARM,
    VkTensorCopyARM,
    VkTensorCreateInfoARM,
    VkTensorDependencyInfoARM,
    VkTensorDescriptionARM,
    VkTensorExplicitTilingFormatPropertiesARM,
    VkTensorFormatPropertiesARM,
    VkTensorMemoryBarrierARM,
    VkTensorMemoryRequirementsInfoARM,
    VkTensorRollingBackingCreateInfoARM,
    VkTensorViewCaptureDescriptorDataInfoARM,
    VkTensorViewCreateInfoARM,
    VkTexelBufferDescriptorInfoEXT,
    VkTextureLODGatherFormatPropertiesAMD,
    VkThrottleHintSubmitInfoSEC,
    VkTileMemoryBindInfoQCOM,
    VkTileMemoryRequirementsQCOM,
    VkTileMemorySizeInfoQCOM,
    VkTilePropertiesQCOM,
    VkTimelineSemaphoreSubmitInfo,
    VkTraceRaysIndirectCommand2KHR,
    VkTraceRaysIndirectCommandKHR,
    VkTransformMatrixKHR,
    VkUbmSurfaceCreateInfoSEC,
    VkValidationCacheCreateInfoEXT,
    VkValidationFeaturesEXT,
    VkValidationFlagsEXT,
    VkVertexInputAttributeDescription,
    VkVertexInputAttributeDescription2EXT,
    VkVertexInputBindingDescription,
    VkVertexInputBindingDescription2EXT,
    VkVertexInputBindingDivisorDescription,
    VkViSurfaceCreateInfoNN,
    VkVideoBeginCodingInfoKHR,
    VkVideoCapabilitiesKHR,
    VkVideoCodingControlInfoKHR,
    VkVideoDecodeAV1CapabilitiesKHR,
    VkVideoDecodeAV1DpbSlotInfoKHR,
    VkVideoDecodeAV1InlineSessionParametersInfoKHR,
    VkVideoDecodeAV1PictureInfoKHR,
    VkVideoDecodeAV1ProfileInfoKHR,
    VkVideoDecodeAV1SessionParametersCreateInfoKHR,
    VkVideoDecodeCapabilitiesKHR,
    VkVideoDecodeH264CapabilitiesKHR,
    VkVideoDecodeH264DpbSlotInfoKHR,
    VkVideoDecodeH264InlineSessionParametersInfoKHR,
    VkVideoDecodeH264PictureInfoKHR,
    VkVideoDecodeH264ProfileInfoKHR,
    VkVideoDecodeH264SessionParametersAddInfoKHR,
    VkVideoDecodeH264SessionParametersCreateInfoKHR,
    VkVideoDecodeH265CapabilitiesKHR,
    VkVideoDecodeH265DpbSlotInfoKHR,
    VkVideoDecodeH265InlineSessionParametersInfoKHR,
    VkVideoDecodeH265PictureInfoKHR,
    VkVideoDecodeH265ProfileInfoKHR,
    VkVideoDecodeH265SessionParametersAddInfoKHR,
    VkVideoDecodeH265SessionParametersCreateInfoKHR,
    VkVideoDecodeInfoKHR,
    VkVideoDecodeUsageInfoKHR,
    VkVideoDecodeVP9CapabilitiesKHR,
    VkVideoDecodeVP9PictureInfoKHR,
    VkVideoDecodeVP9ProfileInfoKHR,
    VkVideoEncodeAV1CapabilitiesKHR,
    VkVideoEncodeAV1DpbSlotInfoKHR,
    VkVideoEncodeAV1FrameSizeKHR,
    VkVideoEncodeAV1GopRemainingFrameInfoKHR,
    VkVideoEncodeAV1PictureInfoKHR,
    VkVideoEncodeAV1ProfileInfoKHR,
    VkVideoEncodeAV1QIndexKHR,
    VkVideoEncodeAV1QualityLevelPropertiesKHR,
    VkVideoEncodeAV1QuantizationMapCapabilitiesKHR,
    VkVideoEncodeAV1RateControlInfoKHR,
    VkVideoEncodeAV1RateControlLayerInfoKHR,
    VkVideoEncodeAV1SessionCreateInfoKHR,
    VkVideoEncodeAV1SessionParametersCreateInfoKHR,
    VkVideoEncodeCapabilitiesKHR,
    VkVideoEncodeFeedback2CapabilitiesKHR,
    VkVideoEncodeH264CapabilitiesKHR,
    VkVideoEncodeH264DpbSlotInfoKHR,
    VkVideoEncodeH264FrameSizeKHR,
    VkVideoEncodeH264GopRemainingFrameInfoKHR,
    VkVideoEncodeH264NaluSliceInfoKHR,
    VkVideoEncodeH264PictureInfoKHR,
    VkVideoEncodeH264ProfileInfoKHR,
    VkVideoEncodeH264QpKHR,
    VkVideoEncodeH264QualityLevelPropertiesKHR,
    VkVideoEncodeH264QuantizationMapCapabilitiesKHR,
    VkVideoEncodeH264RateControlInfoKHR,
    VkVideoEncodeH264RateControlLayerInfoKHR,
    VkVideoEncodeH264SessionCreateInfoKHR,
    VkVideoEncodeH264SessionParametersAddInfoKHR,
    VkVideoEncodeH264SessionParametersCreateInfoKHR,
    VkVideoEncodeH264SessionParametersFeedbackInfoKHR,
    VkVideoEncodeH264SessionParametersGetInfoKHR,
    VkVideoEncodeH265CapabilitiesKHR,
    VkVideoEncodeH265DpbSlotInfoKHR,
    VkVideoEncodeH265FrameSizeKHR,
    VkVideoEncodeH265GopRemainingFrameInfoKHR,
    VkVideoEncodeH265NaluSliceSegmentInfoKHR,
    VkVideoEncodeH265PictureInfoKHR,
    VkVideoEncodeH265ProfileInfoKHR,
    VkVideoEncodeH265QpKHR,
    VkVideoEncodeH265QualityLevelPropertiesKHR,
    VkVideoEncodeH265QuantizationMapCapabilitiesKHR,
    VkVideoEncodeH265RateControlInfoKHR,
    VkVideoEncodeH265RateControlLayerInfoKHR,
    VkVideoEncodeH265SessionCreateInfoKHR,
    VkVideoEncodeH265SessionParametersAddInfoKHR,
    VkVideoEncodeH265SessionParametersCreateInfoKHR,
    VkVideoEncodeH265SessionParametersFeedbackInfoKHR,
    VkVideoEncodeH265SessionParametersGetInfoKHR,
    VkVideoEncodeInfoKHR,
    VkVideoEncodeIntraRefreshCapabilitiesKHR,
    VkVideoEncodeIntraRefreshInfoKHR,
    VkVideoEncodeProfileRgbConversionInfoVALVE,
    VkVideoEncodeQualityLevelInfoKHR,
    VkVideoEncodeQualityLevelPropertiesKHR,
    VkVideoEncodeQuantizationMapCapabilitiesKHR,
    VkVideoEncodeQuantizationMapInfoKHR,
    VkVideoEncodeQuantizationMapSessionParametersCreateInfoKHR,
    VkVideoEncodeRateControlInfoKHR,
    VkVideoEncodeRateControlLayerInfoKHR,
    VkVideoEncodeRgbConversionCapabilitiesVALVE,
    VkVideoEncodeSessionIntraRefreshCreateInfoKHR,
    VkVideoEncodeSessionParametersFeedbackInfoKHR,
    VkVideoEncodeSessionParametersGetInfoKHR,
    VkVideoEncodeSessionRgbConversionCreateInfoVALVE,
    VkVideoEncodeUsageInfoKHR,
    VkVideoEndCodingInfoKHR,
    VkVideoFormatAV1QuantizationMapPropertiesKHR,
    VkVideoFormatH265QuantizationMapPropertiesKHR,
    VkVideoFormatPropertiesKHR,
    VkVideoFormatQuantizationMapPropertiesKHR,
    VkVideoInlineQueryInfoKHR,
    VkVideoPictureResourceInfoKHR,
    VkVideoProfileInfoKHR,
    VkVideoProfileListInfoKHR,
    VkVideoReferenceIntraRefreshInfoKHR,
    VkVideoReferenceSlotInfoKHR,
    VkVideoSessionCreateInfoKHR,
    VkVideoSessionMemoryRequirementsKHR,
    VkVideoSessionParametersCreateInfoKHR,
    VkVideoSessionParametersUpdateInfoKHR,
    VkViewport,
    VkViewportSwizzleNV,
    VkViewportWScalingNV,
    VkWaylandSurfaceCreateInfoKHR,
    VkWin32KeyedMutexAcquireReleaseInfoKHR,
    VkWin32KeyedMutexAcquireReleaseInfoNV,
    VkWin32SurfaceCreateInfoKHR,
    VkWriteDescriptorSet,
    VkWriteDescriptorSetAccelerationStructureKHR,
    VkWriteDescriptorSetAccelerationStructureNV,
    VkWriteDescriptorSetInlineUniformBlock,
    VkWriteDescriptorSetPartitionedAccelerationStructureNV,
    VkWriteDescriptorSetTensorARM,
    VkWriteIndirectExecutionSetPipelineEXT,
    VkWriteIndirectExecutionSetShaderEXT,
    VkXYColorEXT,
    VkXcbSurfaceCreateInfoKHR,
    VkXlibSurfaceCreateInfoKHR,
};

enum class Field {
    Empty = 0,  // Field::Empty (if something tries to print it, it will be empty)
    AType,
    BType,
    CType,
    DType,
    KGranularity,
    KSize,
    MGranularity,
    MSize,
    NGranularity,
    NSize,
    OHOSNativeBufferUsage,
    ResultType,
    a,
    aabbData,
    aabbs,
    accelerationStructure,
    accelerationStructureCaptureReplay,
    accelerationStructureCaptureReplayDescriptorDataSize,
    accelerationStructureCount,
    accelerationStructureDescriptorSize,
    accelerationStructureHostCommands,
    accelerationStructureIndirectBuild,
    accelerationStructureNV,
    accelerationStructureReference,
    accelerationStructureSize,
    acquireCount,
    acquireUnmodifiedMemory,
    activeComputeUnitCount,
    actualPresentTime,
    address,
    addressFlags,
    addressImageHeight,
    addressInfoCount,
    addressModeU,
    addressModeV,
    addressModeW,
    addressOffset,
    addressPrecision,
    addressRange,
    addressResolutionFlags,
    addressRowLength,
    addressType,
    advancedBlendAllOperations,
    advancedBlendCoherentOperations,
    advancedBlendCorrelatedOverlap,
    advancedBlendIndependentBlend,
    advancedBlendMaxColorAttachments,
    advancedBlendNonPremultipliedDstColor,
    advancedBlendNonPremultipliedSrcColor,
    advancedBlendOp,
    alignment,
    allocationSize,
    allowClusterAccelerationStructure,
    allowCommandBufferQueryCopies,
    allowNeuralStatistics,
    allowSamplerImageViewPostSubmitCreation,
    alphaBlendOp,
    alphaMode,
    alphaToCoverageEnable,
    alphaToOne,
    alphaToOneEnable,
    amigoProfiling,
    androidHardwareBufferUsage,
    anisotropyEnable,
    antiLag,
    anyHitShader,
    apiVersion,
    applicationNameOffset,
    applicationVersion,
    apronSize,
    argCount,
    argData,
    arrayElement,
    arrayLayer,
    arrayLayers,
    arrayOfPointers,
    arrayPitch,
    aspectMask,
    aspectReferenceCount,
    attachment,
    attachmentCount,
    attachmentFeedbackLoopDynamicState,
    attachmentFeedbackLoopLayout,
    attachmentFragmentShadingRate,
    attachmentImageInfoCount,
    attachmentIndex,
    attachmentInitialSampleLocationsCount,
    averageBitrate,
    b,
    b32,
    back,
    bank,
    baseAddress,
    baseArrayLayer,
    baseGeometryIndexAndGeometryFlags,
    baseGroupX,
    baseGroupY,
    baseGroupZ,
    baseMipLevel,
    basePipelineHandle,
    basePipelineIndex,
    baseTriangle,
    basicBlockIndex,
    biasInterpretation,
    bidirectionalCompoundReferenceNameMask,
    bidirectionalFlowSupported,
    binaryCount,
    bindCount,
    bindInfoCount,
    bindPoint,
    bindPointType,
    bindSessionMemoryInfoCount,
    binding,
    bindingCount,
    bindingPoint,
    bindingType,
    bipredictiveFrameSize,
    bipredictiveQIndex,
    blendConstants,
    blendEnable,
    blendOverlap,
    blockDimX,
    blockDimY,
    blockDimZ,
    blockInstance,
    blockMatchExtendedClampToEdge,
    blockTexelViewCompatibleMultipleLayers,
    blockType,
    blockU64kTilingTensorFeatures,
    blockUTilingTensorFeatures,
    borderColor,
    borderColorSwizzle,
    borderColorSwizzleFromImage,
    bresenhamLines,
    brick16TilingTensorFeatures,
    brick4TilingTensorFeatures,
    brick8TilingTensorFeatures,
    buffer,
    bufferAddress,
    bufferBindCount,
    bufferCaptureReplayDescriptorDataSize,
    bufferCollectionConstraints,
    bufferCount,
    bufferDescriptorAlignment,
    bufferDescriptorSize,
    bufferDeviceAddress,
    bufferDeviceAddressCaptureReplay,
    bufferDeviceAddressMultiDevice,
    bufferFeatures,
    bufferImageGranularity,
    bufferImageHeight,
    bufferMemoryBarrierCount,
    bufferOffset,
    bufferRowLength,
    bufferView,
    bufferlessPushDescriptors,
    buildScratchSize,
    buildType,
    c,
    cacheFlushOnCounterCollection,
    cacheType,
    cacheVersion,
    callableShaderBindingOffset,
    callableShaderBindingStride,
    callableShaderBindingTableAddress,
    callableShaderBindingTableBuffer,
    callableShaderBindingTableSize,
    callableShaderBindingTableStride,
    callback,
    capabilities,
    category,
    checkpointExecutionStageMask,
    chromaBitDepth,
    chromaFilter,
    chromaSubsampling,
    clampResults,
    clearValue,
    clearValueCount,
    clipped,
    clockMode,
    clockModes,
    closestHitShader,
    clusterAccelerationStructure,
    clusterBottomLevelByteAlignment,
    clusterByteAlignment,
    clusterFlags,
    clusterID,
    clusterIdOffset,
    clusterReferences,
    clusterReferencesCount,
    clusterReferencesStride,
    clusterScratchByteAlignment,
    clusterShadingRate,
    clusterTemplateAddress,
    clusterTemplateBoundsByteAlignment,
    clusterTemplateByteAlignment,
    clustercullingShader,
    cmdBufLabelCount,
    codeSize,
    codeType,
    codedExtent,
    codedOffset,
    codedPictureAlignment,
    collection,
    collectionToken,
    color,
    colorAttachment,
    colorAttachmentCount,
    colorAttachmentFormat,
    colorBlendOp,
    colorSamples,
    colorSpace,
    colorSpaceCount,
    colorWriteEnable,
    colorWriteMask,
    combinedImageSamplerDensityMapDescriptorSize,
    combinedImageSamplerDescriptorCount,
    combinedImageSamplerDescriptorSingleArray,
    combinedImageSamplerDescriptorSize,
    combinerOps,
    commandBuffer,
    commandBufferCount,
    commandBufferInfoCount,
    commandBufferInheritance,
    commandCount,
    commandPool,
    compactedSize,
    compareEnable,
    compareMask,
    compareOp,
    compatibleCtbSizes,
    compatibleHandleTypes,
    compatibleSuperblockSizes,
    compilerControlFlags,
    componentMapping,
    components,
    compositeAlpha,
    compressedData,
    compressedHeaderOffset,
    compressedSize,
    compressionControlPlaneCount,
    computeCapabilityMajor,
    computeCapabilityMinor,
    computeDerivativeGroupLinear,
    computeDerivativeGroupQuads,
    computeFullSubgroups,
    computeOccupancyPriority,
    computeUnitsPerShaderArray,
    computeWorkGroupSize,
    conditionalRendering,
    conditionalRenderingEnable,
    configuration,
    conformanceVersion,
    connection,
    connectionCount,
    connectorId,
    consecutiveBFrameCount,
    consecutiveBipredictiveFrameCount,
    conservativePointAndLineRasterization,
    conservativeRasterizationMode,
    conservativeRasterizationPostDepthCoverage,
    constantAlphaColorBlendFactors,
    constantCount,
    constantID,
    constantOffset,
    constantQIndex,
    constantQp,
    contents,
    context,
    conversion,
    cooperativeMatrix,
    cooperativeMatrixBlockLoads,
    cooperativeMatrixConversion,
    cooperativeMatrixConversions,
    cooperativeMatrixDecodeVector,
    cooperativeMatrixFlexibleDimensions,
    cooperativeMatrixFlexibleDimensionsMaxDimension,
    cooperativeMatrixPerElementOperations,
    cooperativeMatrixReductions,
    cooperativeMatrixRobustBufferAccess,
    cooperativeMatrixSupportedStages,
    cooperativeMatrixTensorAddressing,
    cooperativeMatrixWorkgroupScope,
    cooperativeMatrixWorkgroupScopeMaxWorkgroupSize,
    cooperativeMatrixWorkgroupScopeReservedSharedMemory,
    cooperativeVector,
    cooperativeVectorSupportedStages,
    cooperativeVectorTraining,
    cooperativeVectorTrainingFloat16Accumulation,
    cooperativeVectorTrainingFloat32Accumulation,
    copyAddressRange,
    copyBufferAddress,
    copyCount,
    copyDstLayoutCount,
    copySrcLayoutCount,
    cornerSampledImage,
    correlatedViewMaskCount,
    correlationMaskCount,
    costFormat,
    costSupported,
    count,
    countAddressFlags,
    countAddressRange,
    countBuffer,
    countBufferOffset,
    countInfo,
    counter,
    counterAddressCount,
    counterBuffer,
    counterBufferCount,
    counterBufferOffset,
    counterID,
    counterIndexCount,
    counterOffset,
    counterPassIndex,
    counterRangeCount,
    coverageModulationMode,
    coverageModulationTableCount,
    coverageModulationTableEnable,
    coverageReductionMode,
    coverageToColorEnable,
    coverageToColorLocation,
    createFlags,
    createInfo,
    createInfoCount,
    createInfoIndex,
    ctbSizes,
    cubicRangeClamp,
    cubicWeights,
    cudaKernelLaunchFeatures,
    cullMode,
    currentDisplay,
    currentExtent,
    currentStackIndex,
    currentTransform,
    customBorderColor,
    customBorderColorWithoutFormat,
    customBorderColors,
    customResolve,
    customSampleOrderCount,
    data,
    dataGraph,
    dataGraphDescriptorBuffer,
    dataGraphModel,
    dataGraphNeuralAcceleratorStatistics,
    dataGraphOpticalFlow,
    dataGraphPipeline,
    dataGraphShaderModule,
    dataGraphSpecializationConstants,
    dataGraphUpdateAfterBind,
    dataOffset,
    dataSize,
    decodeMode,
    decodeModeSharedExponent,
    decompressRegionCount,
    decompressedSize,
    decompressionMethod,
    decompressionMethods,
    dedicatedAllocation,
    dedicatedAllocationImageAliasing,
    defaultRobustnessImages,
    defaultRobustnessStorageBuffers,
    defaultRobustnessUniformBuffers,
    defaultRobustnessVertexInputs,
    defaultVertexAttributeValue,
    deferredOperation,
    degenerateLinesRasterized,
    degenerateTrianglesRasterized,
    denormBehaviorIndependence,
    denseGeometryFormat,
    dependencyCount,
    dependencyFlags,
    depth,
    depthAttachmentFormat,
    depthBiasClamp,
    depthBiasConstantFactor,
    depthBiasControl,
    depthBiasEnable,
    depthBiasExact,
    depthBiasRepresentation,
    depthBiasSlopeFactor,
    depthBounds,
    depthBoundsTestEnable,
    depthClamp,
    depthClampControl,
    depthClampEnable,
    depthClampMode,
    depthClampZeroOne,
    depthClipControl,
    depthClipEnable,
    depthCompareOp,
    depthFailOp,
    depthPitch,
    depthResolveMode,
    depthStencil,
    depthStencilAttachmentSamples,
    depthStencilSamples,
    depthStencilSwizzleOneSupport,
    depthTestEnable,
    depthWriteEnable,
    description,
    descriptorBindingAccelerationStructureUpdateAfterBind,
    descriptorBindingInlineUniformBlockUpdateAfterBind,
    descriptorBindingPartiallyBound,
    descriptorBindingSampledImageUpdateAfterBind,
    descriptorBindingStorageBufferUpdateAfterBind,
    descriptorBindingStorageImageUpdateAfterBind,
    descriptorBindingStorageTensorUpdateAfterBind,
    descriptorBindingStorageTexelBufferUpdateAfterBind,
    descriptorBindingUniformBufferUpdateAfterBind,
    descriptorBindingUniformTexelBufferUpdateAfterBind,
    descriptorBindingUpdateUnusedWhilePending,
    descriptorBindingVariableDescriptorCount,
    descriptorBuffer,
    descriptorBufferAddressSpaceSize,
    descriptorBufferCaptureReplay,
    descriptorBufferImageLayoutIgnored,
    descriptorBufferOffsetAlignment,
    descriptorBufferPushDescriptors,
    descriptorBufferTensorDescriptors,
    descriptorCopyCount,
    descriptorCount,
    descriptorHeap,
    descriptorHeapCaptureReplay,
    descriptorIndexing,
    descriptorOffset,
    descriptorPool,
    descriptorPoolOverallocation,
    descriptorSet,
    descriptorSetCount,
    descriptorSetHostMapping,
    descriptorSetLayout,
    descriptorSize,
    descriptorType,
    descriptorTypeCount,
    descriptorUpdateEntryCount,
    descriptorUpdateTemplate,
    descriptorWriteCount,
    desiredPresentTime,
    device,
    deviceAddress,
    deviceAddressCommands,
    deviceCoherentMemory,
    deviceEvent,
    deviceFault,
    deviceFaultDeviceLostOnMasked,
    deviceFaultReportMasked,
    deviceFaultVendorBinary,
    deviceGeneratedCommands,
    deviceGeneratedCommandsMultiDrawIndirectCount,
    deviceGeneratedCommandsTransformFeedback,
    deviceGeneratedCompute,
    deviceGeneratedComputeCaptureReplay,
    deviceGeneratedComputePipelines,
    deviceID,
    deviceIndex,
    deviceIndexCount,
    deviceLUID,
    deviceLUIDValid,
    deviceMask,
    deviceMemoryReport,
    deviceName,
    deviceNodeMask,
    deviceRelativeId,
    deviceRenderAreaCount,
    deviceType,
    deviceUUID,
    dfb,
    diagnosticsConfig,
    dimension,
    dimensionCount,
    dirtyIntraRefreshRegions,
    disableInternalCache,
    disabledValidationCheckCount,
    disabledValidationFeatureCount,
    disallowMerging,
    discardRectangleCount,
    discardRectangleEnable,
    discardRectangleMode,
    discardable,
    discreteQueuePriorities,
    displacedMicromapPrimitiveFlags,
    displacedMicromapPrimitiveFlagsStride,
    displacementBiasAndScaleBuffer,
    displacementBiasAndScaleFormat,
    displacementBiasAndScaleStride,
    displacementMicromap,
    displacementVectorBuffer,
    displacementVectorFormat,
    displacementVectorStride,
    display,
    displayEvent,
    displayMode,
    displayModeProperties,
    displayName,
    displayPlaneProperties,
    displayPrimaryBlue,
    displayPrimaryGreen,
    displayPrimaryRed,
    displayProperties,
    divisor,
    domainOrigin,
    dpy,
    drawCount,
    drawIndirectCount,
    drawIndirectFirstInstance,
    driverCount,
    driverEndTimeUs,
    driverID,
    driverInfo,
    driverName,
    driverStartTimeUs,
    driverUUID,
    driverVersion,
    drmFd,
    drmFormatModifier,
    drmFormatModifierCount,
    drmFormatModifierPlaneCount,
    drmFormatModifierTilingFeatures,
    dst,
    dstAccelerationStructure,
    dstAccelerationStructureData,
    dstAccessMask,
    dstAccessMask3,
    dstAddress,
    dstAddressesArray,
    dstAlphaBlendFactor,
    dstArrayElement,
    dstBinding,
    dstBuffer,
    dstBufferOffset,
    dstBufferRange,
    dstCache,
    dstColorBlendFactor,
    dstComponentType,
    dstCopyFlags,
    dstData,
    dstFlags,
    dstImage,
    dstImageLayout,
    dstImplicitData,
    dstLayout,
    dstMicromap,
    dstOffset,
    dstOffsets,
    dstPictureResource,
    dstPremultiplied,
    dstQueueFamilyIndex,
    dstRange,
    dstRect,
    dstSet,
    dstSizesArray,
    dstStageMask,
    dstStride,
    dstSubpass,
    dstSubresource,
    dstTensor,
    dualSrcBlend,
    duration,
    dwAccess,
    dynamicGeneratedPipelineLayout,
    dynamicMetadataSize,
    dynamicOffsetCount,
    dynamicPipelineLayout,
    dynamicPrimitiveTopologyUnrestricted,
    dynamicRendering,
    dynamicRenderingLocalRead,
    dynamicRenderingLocalReadDepthStencilAttachments,
    dynamicRenderingLocalReadMultisampledAttachments,
    dynamicRenderingUnusedAttachments,
    dynamicStateCount,
    earliestPresentTime,
    earlyFragmentMultisampleCoverageAfterSampleCounting,
    earlyFragmentSampleMaskTestBeforeSampleCounting,
    elapsedTimerQuery,
    enable,
    enableCbCrDegamma,
    enablePartitionTranslation,
    enableYDegamma,
    enabledExtensionCount,
    enabledLayerCount,
    enabledValidationFeatureCount,
    encodeFeedbackFlags,
    encodeInputPictureGranularity,
    endCapsMode,
    engine,
    engineClockFrequency,
    engineClockRatioToPeak,
    engineNameOffset,
    engineType,
    engineVersion,
    event,
    eventCount,
    eventID,
    events,
    exclusiveScissor,
    exclusiveScissorCount,
    executableIndex,
    executionGraph,
    executionGraphDispatchAddressAlignment,
    executionSetWriteCount,
    expectDyadicTemporalLayerPattern,
    expectDyadicTemporalSubLayerPattern,
    explicitAABB,
    exportFromImportedHandleTypes,
    exportObjectType,
    extendedDynamicState,
    extendedDynamicState2,
    extendedDynamicState2LogicOp,
    extendedDynamicState2PatchControlPoints,
    extendedDynamicState3AlphaToCoverageEnable,
    extendedDynamicState3AlphaToOneEnable,
    extendedDynamicState3ColorBlendAdvanced,
    extendedDynamicState3ColorBlendEnable,
    extendedDynamicState3ColorBlendEquation,
    extendedDynamicState3ColorWriteMask,
    extendedDynamicState3ConservativeRasterizationMode,
    extendedDynamicState3CoverageModulationMode,
    extendedDynamicState3CoverageModulationTable,
    extendedDynamicState3CoverageModulationTableEnable,
    extendedDynamicState3CoverageReductionMode,
    extendedDynamicState3CoverageToColorEnable,
    extendedDynamicState3CoverageToColorLocation,
    extendedDynamicState3DepthClampEnable,
    extendedDynamicState3DepthClipEnable,
    extendedDynamicState3DepthClipNegativeOneToOne,
    extendedDynamicState3ExtraPrimitiveOverestimationSize,
    extendedDynamicState3LineRasterizationMode,
    extendedDynamicState3LineStippleEnable,
    extendedDynamicState3LogicOpEnable,
    extendedDynamicState3PolygonMode,
    extendedDynamicState3ProvokingVertexMode,
    extendedDynamicState3RasterizationSamples,
    extendedDynamicState3RasterizationStream,
    extendedDynamicState3RepresentativeFragmentTestEnable,
    extendedDynamicState3SampleLocationsEnable,
    extendedDynamicState3SampleMask,
    extendedDynamicState3ShadingRateImageEnable,
    extendedDynamicState3TessellationDomainOrigin,
    extendedDynamicState3ViewportSwizzle,
    extendedDynamicState3ViewportWScalingEnable,
    extendedFlags,
    extendedSparseAddressSpace,
    extendedSparseAddressSpaceSize,
    extendedSparseBufferUsageFlags,
    extendedSparseImageUsageFlags,
    extensionCount,
    extensionName,
    extent,
    externalDataSize,
    externalFenceFeatures,
    externalFormat,
    externalFormatResolve,
    externalFormatResolveChromaOffsetX,
    externalFormatResolveChromaOffsetY,
    externalHandleType,
    externalMemoryFeatures,
    externalMemoryProperties,
    externalMemoryRDMA,
    externalQueue,
    externalSemaphoreFeatures,
    extraCount,
    extraPrimitiveOverestimationSize,
    extraPrimitiveOverestimationSizeGranularity,
    f64,
    faceMask,
    failOp,
    faultAddressInfo,
    fd,
    features,
    feedbackLoopEnable,
    fence,
    fenceCount,
    fieldOffsetGranularity,
    fillModeNonSolid,
    filmGrainSupport,
    filter,
    filterCenter,
    filterCubic,
    filterCubicMinmax,
    filterMinmaxImageComponentMapping,
    filterMinmaxSingleComponentFormats,
    filterSize,
    finalLayout,
    firstAttachment,
    firstBinding,
    firstCounterBuffer,
    firstCounterRange,
    firstDiscardRectangle,
    firstDrawTimestamp,
    firstExclusiveScissor,
    firstGroup,
    firstIndex,
    firstInstance,
    firstQuery,
    firstScissor,
    firstSet,
    firstTask,
    firstVertex,
    firstViewport,
    flags,
    float32,
    float64,
    floatRepresentation,
    flowVectorFormat,
    fmaRate,
    forceExplicitReconstruction,
    foreignMemoryHandleTypes,
    foreignSemaphoreHandleTypes,
    format,
    formatA4B4G4R4,
    formatA4R4G4B4,
    formatConstraintsCount,
    formatFeatures,
    formatPack,
    formatProperties,
    formatRgba10x6WithoutYCbCrSampler,
    fragmentDensityInvocations,
    fragmentDensityMap,
    fragmentDensityMapAttachment,
    fragmentDensityMapDeferred,
    fragmentDensityMapDynamic,
    fragmentDensityMapLayered,
    fragmentDensityMapNonSubsampledImages,
    fragmentDensityMapOffset,
    fragmentDensityOffsetCount,
    fragmentDensityOffsetGranularity,
    fragmentShaderBarycentric,
    fragmentShaderPixelInterlock,
    fragmentShaderSampleInterlock,
    fragmentShaderShadingRateInterlock,
    fragmentShadingRateClampCombinerInputs,
    fragmentShadingRateEnums,
    fragmentShadingRateNonTrivialCombinerOps,
    fragmentShadingRateStrictMultiplyCombiner,
    fragmentShadingRateWithConservativeRasterization,
    fragmentShadingRateWithCustomSampleLocations,
    fragmentShadingRateWithFragmentShaderInterlock,
    fragmentShadingRateWithSampleMask,
    fragmentShadingRateWithShaderDepthStencilWrites,
    fragmentShadingRateWithShaderSampleMask,
    fragmentSize,
    fragmentStoresAndAtomics,
    frameBSize,
    frameBoundary,
    frameHeaderOffset,
    frameID,
    frameISize,
    frameIndex,
    framePSize,
    frameRateDenominator,
    frameRateNumerator,
    frameToken,
    framebuffer,
    framebufferColorSampleCounts,
    framebufferDepthSampleCounts,
    framebufferIntegerColorSampleCounts,
    framebufferNoAttachmentsSampleCounts,
    framebufferStencilSampleCounts,
    front,
    frontFace,
    fullDrawIndexUint32,
    fullScreenExclusive,
    fullScreenExclusiveSupported,
    fullyCoveredFragmentShaderInputVariable,
    function,
    g,
    generalShader,
    generateObuExtensionHeader,
    generatePrefixNalu,
    geometry,
    geometryCount,
    geometryFlags,
    geometryIndex,
    geometryIndexAndFlagsBuffer,
    geometryIndexAndFlagsBufferStride,
    geometryIndexOffset,
    geometryShader,
    geometryStreams,
    geometryType,
    globalAlpha,
    globalFlowSupported,
    globalPriority,
    globalPriorityQuery,
    gopFrameCount,
    gopRemainingB,
    gopRemainingBipredictive,
    gopRemainingI,
    gopRemainingIntra,
    gopRemainingP,
    gopRemainingPredictive,
    gpaSession,
    gpuRenderEndTimeUs,
    gpuRenderStartTimeUs,
    graphicsPipelineLibrary,
    graphicsPipelineLibraryFastLinking,
    graphicsPipelineLibraryIndependentInterpolationDecoration,
    gridDimX,
    gridDimY,
    gridDimZ,
    group,
    groupCount,
    groupCountX,
    groupCountY,
    groupCountZ,
    groupId,
    groupIndex,
    groupShader,
    groupSize,
    handle,
    handleType,
    handleTypes,
    hasOverrides,
    hasPrimary,
    hasRender,
    hasStdPPSOverrides,
    hasStdSPSOverrides,
    hasStdVPSOverrides,
    hdmi3DSupported,
    hdrVivid,
    headerSize,
    headerVersion,
    heapArrayStride,
    heapBudget,
    heapData,
    heapIndex,
    heapIndexStride,
    heapOffset,
    heapRange,
    heapUsage,
    height,
    hinstance,
    hintGridSize,
    hintSupported,
    hitShaderBindingOffset,
    hitShaderBindingStride,
    hitShaderBindingTableAddress,
    hitShaderBindingTableBuffer,
    hitShaderBindingTableSize,
    hitShaderBindingTableStride,
    hmonitor,
    hostAddress,
    hostImageCopy,
    hostQueryReset,
    hwnd,
    i64,
    id,
    identicalMemoryLayout,
    identicalMemoryTypeRequirements,
    identifier,
    identifierSize,
    identityTransformOrder,
    idrPeriod,
    image,
    image2DViewOf3D,
    image2DViewOf3DSparse,
    imageAlignmentControl,
    imageArrayLayers,
    imageBindCount,
    imageCaptureReplayDescriptorDataSize,
    imageCaptureReplayOpaqueDataSize,
    imageColorSpace,
    imageCompressionControl,
    imageCompressionControlSwapchain,
    imageCompressionFixedRateFlags,
    imageCompressionFlags,
    imageCount,
    imageCreateFlags,
    imageCreateInfo,
    imageCubeArray,
    imageDescriptorAlignment,
    imageDescriptorSize,
    imageExtent,
    imageFootprint,
    imageFormat,
    imageFormatProperties,
    imageGatherExtendedModes,
    imageGatherLinear,
    imageGranularity,
    imageIndex,
    imageIndexCount,
    imageLayout,
    imageMemoryBarrierCount,
    imageMipTailFirstLod,
    imageMipTailOffset,
    imageMipTailSize,
    imageMipTailStride,
    imageOffset,
    imageOpaqueBindCount,
    imagePipeHandle,
    imageSharingMode,
    imageSlicedViewOf3D,
    imageSubresource,
    imageTiling,
    imageType,
    imageUsage,
    imageUsageFlags,
    imageView,
    imageView2DOn3DImage,
    imageViewBinding,
    imageViewCaptureReplayDescriptorDataSize,
    imageViewFormatReinterpretation,
    imageViewFormatSwizzle,
    imageViewIndex,
    imageViewType,
    imagelessFramebuffer,
    images,
    implementationVersion,
    independentBlend,
    independentResolve,
    independentResolveNone,
    index,
    indexBuffer,
    indexBufferStride,
    indexCount,
    indexData,
    indexOffset,
    indexStride,
    indexType,
    indexTypeCount,
    indexTypeUint8,
    indexingMode,
    indirectAddress,
    indirectAddressSize,
    indirectBufferOffsetAlignment,
    indirectCommandsAddress,
    indirectCommandsCountAddress,
    indirectCommandsLayout,
    indirectCopy,
    indirectDeviceAddress,
    indirectExecutionSet,
    indirectIndex,
    indirectIndexArray,
    indirectMemoryCopy,
    indirectMemoryToImageCopy,
    indirectStateFlags,
    indirectStride,
    info,
    infoCount,
    infoType,
    infos,
    inheritedConditionalRendering,
    inheritedQueries,
    inheritedViewportScissor2D,
    initialDataSize,
    initialLayout,
    initialPipeline,
    initialValue,
    initialVirtualBufferSizeInMs,
    inlineUniformBlock,
    input,
    inputAttachmentCount,
    inputAttachmentDescriptorSize,
    inputAttachmentIndex,
    inputInterpretation,
    inputRate,
    inputSampleTimeUs,
    inputType,
    instance,
    instanceContributionToHitGroupIndex,
    instanceCount,
    instanceCustomIndex,
    instanceData,
    instanceFlags,
    instanceID,
    instanceIndex,
    instanceMask,
    instanceOffset,
    instanceShaderBindingTableRecordOffset,
    instances,
    instantiationBoundingBoxLimit,
    instructionAddressInfo,
    instrumentation,
    int32,
    int64,
    integerDotProduct16BitMixedSignednessAccelerated,
    integerDotProduct16BitSignedAccelerated,
    integerDotProduct16BitUnsignedAccelerated,
    integerDotProduct32BitMixedSignednessAccelerated,
    integerDotProduct32BitSignedAccelerated,
    integerDotProduct32BitUnsignedAccelerated,
    integerDotProduct4x8BitPackedMixedSignednessAccelerated,
    integerDotProduct4x8BitPackedSignedAccelerated,
    integerDotProduct4x8BitPackedUnsignedAccelerated,
    integerDotProduct64BitMixedSignednessAccelerated,
    integerDotProduct64BitSignedAccelerated,
    integerDotProduct64BitUnsignedAccelerated,
    integerDotProduct8BitMixedSignednessAccelerated,
    integerDotProduct8BitSignedAccelerated,
    integerDotProduct8BitUnsignedAccelerated,
    integerDotProductAccumulatingSaturating16BitMixedSignednessAccelerated,
    integerDotProductAccumulatingSaturating16BitSignedAccelerated,
    integerDotProductAccumulatingSaturating16BitUnsignedAccelerated,
    integerDotProductAccumulatingSaturating32BitMixedSignednessAccelerated,
    integerDotProductAccumulatingSaturating32BitSignedAccelerated,
    integerDotProductAccumulatingSaturating32BitUnsignedAccelerated,
    integerDotProductAccumulatingSaturating4x8BitPackedMixedSignednessAccelerated,
    integerDotProductAccumulatingSaturating4x8BitPackedSignedAccelerated,
    integerDotProductAccumulatingSaturating4x8BitPackedUnsignedAccelerated,
    integerDotProductAccumulatingSaturating64BitMixedSignednessAccelerated,
    integerDotProductAccumulatingSaturating64BitSignedAccelerated,
    integerDotProductAccumulatingSaturating64BitUnsignedAccelerated,
    integerDotProductAccumulatingSaturating8BitMixedSignednessAccelerated,
    integerDotProductAccumulatingSaturating8BitSignedAccelerated,
    integerDotProductAccumulatingSaturating8BitUnsignedAccelerated,
    internallySynchronizedQueues,
    intersectionShader,
    intraFrameSize,
    intraQIndex,
    intraRefreshCycleDuration,
    intraRefreshIndex,
    intraRefreshMode,
    intraRefreshModes,
    invocationMask,
    ioSurface,
    isForeign,
    isPreprocessed,
    isText,
    key,
    keyFramePeriod,
    keySize,
    largePoints,
    latencyModeEnable,
    layer,
    layerCount,
    layerName,
    layeredAPI,
    layeredApiCount,
    layeredShadingRateAttachments,
    layers,
    layout,
    ldsSizePerLocalWorkGroup,
    ldsUsageSizeInBytes,
    leastRepresentableValueForceUnormRepresentation,
    legacyDithering,
    legacyVertexAttributes,
    level,
    levelCount,
    libraryCount,
    limits,
    lineRasterizationMode,
    lineStippleFactor,
    lineStipplePattern,
    lineSubPixelPrecisionBits,
    lineWidth,
    lineWidthGranularity,
    lineWidthRange,
    linearColorAttachment,
    linearSweptSpheres,
    linearTilingFeatures,
    linearTilingTensorFeatures,
    loadOp,
    localDeviceIndex,
    localDimmingEnable,
    localDimmingSupport,
    location,
    logicOp,
    logicOpEnable,
    longVector,
    lowLatencyBoost,
    lowLatencyMode,
    lumaBitDepth,
    magFilter,
    maintenance10,
    maintenance11,
    maintenance4,
    maintenance5,
    maintenance6,
    maintenance7,
    maintenance8,
    maintenance9,
    major,
    mapEntryCount,
    mappingCount,
    marker,
    mask,
    matrix,
    matrixInterpretation,
    matrixMotionInstance,
    maxAccelerationStructureCount,
    maxActiveReferencePictures,
    maxAnisotropy,
    maxApronSize,
    maxArrayLayers,
    maxBPictureL0ReferenceCount,
    maxBidirectionalCompoundGroup1ReferenceCount,
    maxBidirectionalCompoundGroup2ReferenceCount,
    maxBidirectionalCompoundReferenceCount,
    maxBitrate,
    maxBlockMatchRegion,
    maxBlockMatchWindow,
    maxBoundDescriptorSets,
    maxBoxFilterBlockSize,
    maxBufferCount,
    maxBufferSize,
    maxClipDistances,
    maxClusterCountPerAccelerationStructure,
    maxClusterGeometryIndex,
    maxClusterTriangleCount,
    maxClusterUniqueGeometryCount,
    maxClusterVertexCount,
    maxCodedExtent,
    maxColorAttachments,
    maxCombinedClipAndCullDistances,
    maxCombinedImageSamplerDescriptorCount,
    maxCommandBufferNestingLevel,
    maxComputePushConstantBanks,
    maxComputePushDataBanks,
    maxComputeSharedMemorySize,
    maxComputeWorkGroupCount,
    maxComputeWorkGroupInvocations,
    maxComputeWorkGroupSize,
    maxComputeWorkgroupSubgroups,
    maxContentLightLevel,
    maxCooperativeVectorComponents,
    maxCullDistances,
    maxCustomBorderColorSamplers,
    maxDecompressionCount,
    maxDecompressionIndirectCount,
    maxDepth,
    maxDepthBounds,
    maxDepthClamp,
    maxDescriptorBufferBindings,
    maxDescriptorHeapEmbeddedSamplers,
    maxDescriptorSetAccelerationStructures,
    maxDescriptorSetInlineUniformBlocks,
    maxDescriptorSetInputAttachments,
    maxDescriptorSetSampledImages,
    maxDescriptorSetSamplers,
    maxDescriptorSetStorageBuffers,
    maxDescriptorSetStorageBuffersDynamic,
    maxDescriptorSetStorageImages,
    maxDescriptorSetStorageTensors,
    maxDescriptorSetSubsampledSamplers,
    maxDescriptorSetTotalBuffersDynamic,
    maxDescriptorSetTotalStorageBuffersDynamic,
    maxDescriptorSetTotalUniformBuffersDynamic,
    maxDescriptorSetUniformBuffers,
    maxDescriptorSetUniformBuffersDynamic,
    maxDescriptorSetUpdateAfterBindAccelerationStructures,
    maxDescriptorSetUpdateAfterBindInlineUniformBlocks,
    maxDescriptorSetUpdateAfterBindInputAttachments,
    maxDescriptorSetUpdateAfterBindSampledImages,
    maxDescriptorSetUpdateAfterBindSamplers,
    maxDescriptorSetUpdateAfterBindStorageBuffers,
    maxDescriptorSetUpdateAfterBindStorageBuffersDynamic,
    maxDescriptorSetUpdateAfterBindStorageImages,
    maxDescriptorSetUpdateAfterBindStorageTensors,
    maxDescriptorSetUpdateAfterBindTotalBuffersDynamic,
    maxDescriptorSetUpdateAfterBindTotalStorageBuffersDynamic,
    maxDescriptorSetUpdateAfterBindTotalUniformBuffersDynamic,
    maxDescriptorSetUpdateAfterBindUniformBuffers,
    maxDescriptorSetUpdateAfterBindUniformBuffersDynamic,
    maxDeviceFaultCount,
    maxDiscardRectangles,
    maxDisplacementMicromapSubdivisionLevel,
    maxDpbSlots,
    maxDrawCount,
    maxDrawIndexedIndexValue,
    maxDrawIndirectCount,
    maxDrawMeshTasksCount,
    maxDstExtent,
    maxDstPosition,
    maxEmbeddedImmutableSamplerBindings,
    maxEmbeddedImmutableSamplers,
    maxEventID,
    maxExecutionGraphDepth,
    maxExecutionGraphShaderOutputNodes,
    maxExecutionGraphShaderPayloadCount,
    maxExecutionGraphShaderPayloadSize,
    maxExecutionGraphWorkgroupCount,
    maxExecutionGraphWorkgroups,
    maxExtent,
    maxExternalQueues,
    maxExtraPrimitiveOverestimationSize,
    maxFPS,
    maxFragmentCombinedOutputResources,
    maxFragmentDensityMapLayers,
    maxFragmentDensityTexelSize,
    maxFragmentDualSrcAttachments,
    maxFragmentInputComponents,
    maxFragmentOutputAttachments,
    maxFragmentShadingRateAttachmentTexelSize,
    maxFragmentShadingRateAttachmentTexelSizeAspectRatio,
    maxFragmentShadingRateCoverageSamples,
    maxFragmentShadingRateInvocationCount,
    maxFragmentShadingRateRasterizationSamples,
    maxFragmentSize,
    maxFragmentSizeAspectRatio,
    maxFrameAverageLightLevel,
    maxFrameSize,
    maxFramebufferHeight,
    maxFramebufferLayers,
    maxFramebufferWidth,
    maxGeometryCount,
    maxGeometryIndex,
    maxGeometryIndexValue,
    maxGeometryInputComponents,
    maxGeometryOutputComponents,
    maxGeometryOutputVertices,
    maxGeometryShaderInvocations,
    maxGeometryTotalOutputComponents,
    maxGlobalOnlyCounters,
    maxGlobalSharedCounters,
    maxGraphicsPushConstantBanks,
    maxGraphicsPushDataBanks,
    maxGraphicsShaderGroupCount,
    maxHeight,
    maxImageArrayLayers,
    maxImageCount,
    maxImageDimension1D,
    maxImageDimension2D,
    maxImageDimension3D,
    maxImageDimensionCube,
    maxImageExtent,
    maxIndirectCommandsIndirectStride,
    maxIndirectCommandsStreamCount,
    maxIndirectCommandsStreamStride,
    maxIndirectCommandsTokenCount,
    maxIndirectCommandsTokenOffset,
    maxIndirectPipelineCount,
    maxIndirectSequenceCount,
    maxIndirectShaderObjectCount,
    maxInlineUniformBlockBindings,
    maxInlineUniformBlockSize,
    maxInlineUniformTotalSize,
    maxInstanceCount,
    maxInstanceInGlobalPartitionCount,
    maxInstancePerPartitionCount,
    maxInstances,
    maxInterpolationOffset,
    maxIntraRefreshActiveReferencePictures,
    maxIntraRefreshCycleDuration,
    maxL1ReferenceCount,
    maxLevel,
    maxLevelIdc,
    maxLod,
    maxLuminance,
    maxMemoryAllocationCount,
    maxMemoryAllocationSize,
    maxMeshMultiviewViewCount,
    maxMeshOutputComponents,
    maxMeshOutputLayers,
    maxMeshOutputMemorySize,
    maxMeshOutputPrimitives,
    maxMeshOutputVertices,
    maxMeshPayloadAndOutputMemorySize,
    maxMeshPayloadAndSharedMemorySize,
    maxMeshSharedMemorySize,
    maxMeshTotalMemorySize,
    maxMeshWorkGroupCount,
    maxMeshWorkGroupInvocations,
    maxMeshWorkGroupSize,
    maxMeshWorkGroupTotalCount,
    maxMicromapTriangles,
    maxMipLevels,
    maxMovedBytes,
    maxMultiDrawCount,
    maxMultiviewInstanceIndex,
    maxMultiviewViewCount,
    maxNumRegionsOfInterest,
    maxOpacity2StateSubdivisionLevel,
    maxOpacity4StateSubdivisionLevel,
    maxOpacityLossy4StateSubdivisionLevel,
    maxOperatingPoints,
    maxOutputClusterCount,
    maxPPictureL0ReferenceCount,
    maxPartitionCount,
    maxPerDimensionTensorElements,
    maxPerPartitionFeedbackEntries,
    maxPerRegionPerformanceCounters,
    maxPerSetDescriptors,
    maxPerStageDescriptorAccelerationStructures,
    maxPerStageDescriptorInlineUniformBlocks,
    maxPerStageDescriptorInputAttachments,
    maxPerStageDescriptorSampledImages,
    maxPerStageDescriptorSamplers,
    maxPerStageDescriptorSetStorageTensors,
    maxPerStageDescriptorStorageBuffers,
    maxPerStageDescriptorStorageImages,
    maxPerStageDescriptorUniformBuffers,
    maxPerStageDescriptorUpdateAfterBindAccelerationStructures,
    maxPerStageDescriptorUpdateAfterBindInlineUniformBlocks,
    maxPerStageDescriptorUpdateAfterBindInputAttachments,
    maxPerStageDescriptorUpdateAfterBindSampledImages,
    maxPerStageDescriptorUpdateAfterBindSamplers,
    maxPerStageDescriptorUpdateAfterBindStorageBuffers,
    maxPerStageDescriptorUpdateAfterBindStorageImages,
    maxPerStageDescriptorUpdateAfterBindStorageTensors,
    maxPerStageDescriptorUpdateAfterBindUniformBuffers,
    maxPerStageResources,
    maxPerStageUpdateAfterBindResources,
    maxPipelineCount,
    maxPipelineRayHitAttributeSize,
    maxPipelineRayPayloadSize,
    maxPipelineRayRecursionDepth,
    maxPreferredMeshWorkGroupInvocations,
    maxPreferredTaskWorkGroupInvocations,
    maxPrimitiveCount,
    maxPrimitiveIndex,
    maxPushConstantsSize,
    maxPushDataSize,
    maxPushDescriptors,
    maxQIndex,
    maxQIndexDelta,
    maxQp,
    maxQpDelta,
    maxQualityLevels,
    maxQuantizationMapExtent,
    maxQueuedWorkGroupBatches,
    maxRateControlLayers,
    maxRayDispatchInvocationCount,
    maxRayHitAttributeSize,
    maxRayRecursionDepth,
    maxRecursionDepth,
    maxRenderPassStripes,
    maxResourceDescriptorBufferBindings,
    maxResourceDescriptorBufferRange,
    maxResourceHeapSize,
    maxResourceSize,
    maxSampleLocationGridSize,
    maxSampleMaskWords,
    maxSamplerAllocationCount,
    maxSamplerAnisotropy,
    maxSamplerDescriptorBufferBindings,
    maxSamplerDescriptorBufferRange,
    maxSamplerHeapSize,
    maxSamplerLodBias,
    maxScaledImageExtent,
    maxSequenceCount,
    maxSequencesCount,
    maxSets,
    maxSgprAllocation,
    maxShaderAbortMessageSize,
    maxShaderBindingTableRecordIndex,
    maxShaderCount,
    maxShaderGroupStride,
    maxShaderWaitQueues,
    maxSingleReferenceCount,
    maxSize,
    maxSliceCount,
    maxSliceSegmentCount,
    maxSpatialLayerCount,
    maxSqttSeBufferSize,
    maxSrcExtent,
    maxSrcPosition,
    maxStdPPSCount,
    maxStdSPSCount,
    maxStdVPSCount,
    maxStorageBufferRange,
    maxStreamingCounters,
    maxSubLayerCount,
    maxSubgroupSize,
    maxSubpassShadingWorkgroupSizeAspectRatio,
    maxSubsampledArrayLayers,
    maxTaskOutputCount,
    maxTaskPayloadAndSharedMemorySize,
    maxTaskPayloadSize,
    maxTaskSharedMemorySize,
    maxTaskTotalMemorySize,
    maxTaskWorkGroupCount,
    maxTaskWorkGroupInvocations,
    maxTaskWorkGroupSize,
    maxTaskWorkGroupTotalCount,
    maxTemporalLayerCount,
    maxTensorDimensionCount,
    maxTensorElements,
    maxTensorShaderAccessArrayLength,
    maxTensorShaderAccessSize,
    maxTensorSize,
    maxTensorStride,
    maxTessellationControlPerPatchOutputComponents,
    maxTessellationControlPerVertexInputComponents,
    maxTessellationControlPerVertexOutputComponents,
    maxTessellationControlTotalOutputComponents,
    maxTessellationEvaluationInputComponents,
    maxTessellationEvaluationOutputComponents,
    maxTessellationGenerationLevel,
    maxTessellationPatchSize,
    maxTexelBufferElements,
    maxTexelGatherOffset,
    maxTexelOffset,
    maxTileShadingRate,
    maxTileSize,
    maxTiles,
    maxTimelineSemaphoreValueDifference,
    maxTotalClusterCount,
    maxTotalTriangleCount,
    maxTotalVertexCount,
    maxTransformFeedbackBufferDataSize,
    maxTransformFeedbackBufferDataStride,
    maxTransformFeedbackBufferSize,
    maxTransformFeedbackBuffers,
    maxTransformFeedbackStreamDataSize,
    maxTransformFeedbackStreams,
    maxTriangleCount,
    maxTrianglesPerCluster,
    maxUnidirectionalCompoundGroup1ReferenceCount,
    maxUnidirectionalCompoundReferenceCount,
    maxUniformBufferRange,
    maxUpdateAfterBindDescriptorsInAllPools,
    maxVariableDescriptorCount,
    maxVectorComponents,
    maxVertex,
    maxVertexAttribDivisor,
    maxVertexInputAttributeOffset,
    maxVertexInputAttributes,
    maxVertexInputBindingStride,
    maxVertexInputBindings,
    maxVertexOutputComponents,
    maxVerticesPerCluster,
    maxVgprAllocation,
    maxViewportDimensions,
    maxViewports,
    maxWarpsPerShaderCore,
    maxWeightFilterDimension,
    maxWeightFilterPhases,
    maxWidth,
    maxWorkGroupCount,
    maxWorkGroupSize,
    maxX,
    maxY,
    maxZ,
    maximumRequestedAlignment,
    meanFlowL1NormHint,
    memory,
    memoryBarrierCount,
    memoryBindIndex,
    memoryClockFrequency,
    memoryClockRatioToPeak,
    memoryDecompression,
    memoryDeviceIndex,
    memoryHeapCount,
    memoryHeaps,
    memoryImageHeight,
    memoryMapPlaced,
    memoryMapRangePlaced,
    memoryObjectId,
    memoryOffset,
    memoryPriority,
    memoryProperties,
    memoryRangeBarrierCount,
    memoryRangeCount,
    memoryRequirements,
    memoryRowLength,
    memorySize,
    memoryTypeBits,
    memoryTypeCount,
    memoryTypeIndex,
    memoryTypes,
    memoryUnmapReserve,
    meshAndTaskShaderDerivatives,
    meshOutputPerPrimitiveGranularity,
    meshOutputPerVertexGranularity,
    meshShader,
    meshShaderQueries,
    messageCode,
    messageDataSize,
    messageIdNumber,
    messageSeverity,
    messageType,
    messageTypes,
    messenger,
    micromap,
    micromapCaptureReplay,
    micromapCount,
    micromapHostCommands,
    micromapSize,
    minAccelerationStructureScratchOffsetAlignment,
    minBitstreamBufferOffsetAlignment,
    minBitstreamBufferSizeAlignment,
    minBufferCount,
    minBufferCountForCamping,
    minBufferCountForDedicatedSlack,
    minBufferCountForSharedSlack,
    minCodedExtent,
    minDepth,
    minDepthBounds,
    minDepthClamp,
    minDstExtent,
    minDstPosition,
    minFilter,
    minFragmentDensityTexelSize,
    minFragmentShadingRateAttachmentTexelSize,
    minHeight,
    minImageCount,
    minImageExtent,
    minImageTransferGranularity,
    minImportedHostPointerAlignment,
    minIndirectCommandsBufferOffsetAlignment,
    minInterpolationOffset,
    minLod,
    minLuminance,
    minMemoryMapAlignment,
    minPlacedMemoryMapAlignment,
    minPositionTruncateBitCount,
    minQIndex,
    minQIndexDelta,
    minQp,
    minQpDelta,
    minResourceHeapReservedRange,
    minSampleShading,
    minSamplerHeapReservedRange,
    minSamplerHeapReservedRangeWithEmbedded,
    minScaledImageExtent,
    minSequencesCountBufferOffsetAlignment,
    minSequencesIndexBufferOffsetAlignment,
    minSgprAllocation,
    minSize,
    minSrcExtent,
    minSrcPosition,
    minStorageBufferOffsetAlignment,
    minSubgroupSize,
    minTexelBufferOffsetAlignment,
    minTexelGatherOffset,
    minTexelOffset,
    minTileSize,
    minUniformBufferOffsetAlignment,
    minVertexInputBindingStrideAlignment,
    minVgprAllocation,
    minWidth,
    minX,
    minY,
    minZ,
    minimumIntervalUs,
    minor,
    mipLevel,
    mipLevels,
    mipLodBias,
    mipmapMode,
    mipmapPrecisionBits,
    missShaderBindingOffset,
    missShaderBindingStride,
    missShaderBindingTableAddress,
    missShaderBindingTableBuffer,
    missShaderBindingTableSize,
    missShaderBindingTableStride,
    mode,
    modes,
    module,
    mtlBuffer,
    mtlCommandQueue,
    mtlDevice,
    mtlSharedEvent,
    mtlTexture,
    multiDraw,
    multiDrawIndirect,
    multiViewport,
    multisampleArrayImage,
    multisampledRenderToSingleSampled,
    multisampledRenderToSingleSampledEnable,
    multisampledRenderToSwapchain,
    multiview,
    multiviewClusterCullingShader,
    multiviewGeometryShader,
    multiviewMeshShader,
    multiviewPerViewRenderAreas,
    multiviewPerViewViewports,
    multiviewTessellationShader,
    mutableComparisonSamplers,
    mutableDescriptorType,
    mutableDescriptorTypeListCount,
    naluSliceEntryCount,
    naluSliceSegmentEntryCount,
    name,
    nativeUnalignedPerformance,
    negativeOneToOne,
    nestedCommandBuffer,
    nestedCommandBufferRendering,
    nestedCommandBufferSimultaneousUse,
    newLayout,
    nextStage,
    noInvocationFragmentShadingRates,
    noMoveOverlap,
    nodeIndex,
    nodeType,
    nonCoherentAtomSize,
    nonRectangularIntraRefreshRegions,
    nonSeamlessCubeMap,
    nonStrictSinglePixelWideLinesUseParallelogram,
    nonStrictWideLinesUseParallelogram,
    nullColorAttachmentWithExternalFormatResolve,
    nullDescriptor,
    numAABBs,
    numAvailableSgprs,
    numAvailableVgprs,
    numColumns,
    numFramesPerBatch,
    numMetrics,
    numObjects,
    numPhases,
    numPhysicalSgprs,
    numPhysicalVgprs,
    numRows,
    numTriangles,
    numUsedSgprs,
    numUsedVgprs,
    numVertices,
    object,
    objectCount,
    objectHandle,
    objectIndex,
    objectType,
    occlusionQueryEnable,
    occlusionQueryPrecise,
    occupancyPriority,
    occupancyThrottling,
    offset,
    oldLayout,
    oldSwapchain,
    opInput,
    opMode,
    opType,
    opacityMicromapArray,
    opacityMicromapIndexBuffer,
    opacityMicromapIndexBufferStride,
    opacityMicromapIndexType,
    opaqueCaptureAddress,
    opaqueCaptureDescriptorData,
    operation,
    operationType,
    opticalFlow,
    optimal,
    optimalBufferCopyOffsetAlignment,
    optimalBufferCopyRowPitchAlignment,
    optimalDeviceAccess,
    optimalImageTransferGranularity,
    optimalImageTransferToQueueFamilies,
    optimalTilingFeatures,
    optimalTilingLayoutUUID,
    optimalTilingTensorFeatures,
    origin,
    osRenderQueueEndTimeUs,
    osRenderQueueStartTimeUs,
    outputGridSize,
    overallocationBehavior,
    pAccelerationStructure,
    pAccelerationStructures,
    pAcquireInfo,
    pAcquireKeys,
    pAcquireSyncs,
    pAcquireTimeoutMilliseconds,
    pAcquireTimeouts,
    pAddress,
    pAddressInfos,
    pAddressRange,
    pAllocateInfo,
    pAllocator,
    pApiVersion,
    pApplicationInfo,
    pApplicationName,
    pAspectReferences,
    pAttachmentImageInfos,
    pAttachmentInitialSampleLocations,
    pAttachments,
    pAttributes,
    pBeginCustomResolveInfo,
    pBeginInfo,
    pBinaries,
    pBindDescriptorBufferEmbeddedSamplersInfo,
    pBindDescriptorSetsInfo,
    pBindInfo,
    pBindInfos,
    pBindPointRequirementCount,
    pBindPointRequirements,
    pBindSessionMemoryInfos,
    pBindingFlags,
    pBindingInfos,
    pBindingReference,
    pBindings,
    pBinds,
    pBlitImageInfo,
    pBorderColor,
    pBuffer,
    pBufferBinds,
    pBufferConstraintsInfo,
    pBufferIndices,
    pBufferInfo,
    pBufferMemoryBarriers,
    pBuffers,
    pBuildInfo,
    pCacheData,
    pCacheSize,
    pCallableShaderBindingTable,
    pCallback,
    pCallbackData,
    pCapabilities,
    pCheckpointData,
    pCheckpointDataCount,
    pCheckpointMarker,
    pClearValues,
    pClustersBottomLevel,
    pCmdBufLabels,
    pCode,
    pCodingControlInfo,
    pCollection,
    pColor,
    pColorAttachmentFormats,
    pColorAttachmentInputIndices,
    pColorAttachmentLocations,
    pColorAttachmentSamples,
    pColorAttachments,
    pColorBlendAdvanced,
    pColorBlendEnables,
    pColorBlendEquations,
    pColorBlendState,
    pColorSpaces,
    pColorWriteEnables,
    pColorWriteMasks,
    pCombinationCount,
    pCombinations,
    pCombinedImageSampler,
    pCommandBufferDeviceMasks,
    pCommandBufferInfos,
    pCommandBuffers,
    pCommandInfos,
    pCommandPool,
    pCommittedMemoryInBytes,
    pCompatibility,
    pConditionalRenderingBegin,
    pConfiguration,
    pConnections,
    pConstantData,
    pConstants,
    pCopyBufferInfo,
    pCopyBufferToImageInfo,
    pCopyDstLayouts,
    pCopyImageInfo,
    pCopyImageToBufferInfo,
    pCopyImageToImageInfo,
    pCopyImageToMemoryInfo,
    pCopyMemoryIndirectInfo,
    pCopyMemoryInfo,
    pCopyMemoryToImageIndirectInfo,
    pCopyMemoryToImageInfo,
    pCopySrcLayouts,
    pCopyTensorInfo,
    pCorrelatedViewMasks,
    pCorrelationMasks,
    pCountInfo,
    pCounterAddresses,
    pCounterBufferOffsets,
    pCounterBuffers,
    pCounterCount,
    pCounterDescriptions,
    pCounterIndices,
    pCounterInfo,
    pCounterInfos,
    pCounterValue,
    pCounters,
    pCoverageModulationTable,
    pCreateInfo,
    pCreateInfos,
    pCustomSampleOrders,
    pData,
    pDataSize,
    pDatas,
    pDebugInfo,
    pDecodeInfo,
    pDecompressMemoryInfoEXT,
    pDecompressMemoryRegions,
    pDeferredOperation,
    pDependencies,
    pDependencyInfo,
    pDependencyInfos,
    pDepthAttachment,
    pDepthBiasInfo,
    pDepthClampRange,
    pDepthInputAttachmentIndex,
    pDepthStencil,
    pDepthStencilAttachment,
    pDepthStencilResolveAttachment,
    pDepthStencilState,
    pDescription,
    pDescriptionCount,
    pDescriptions,
    pDescriptor,
    pDescriptorCopies,
    pDescriptorCounts,
    pDescriptorInfo,
    pDescriptorPool,
    pDescriptorSets,
    pDescriptorTypes,
    pDescriptorUpdateEntries,
    pDescriptorUpdateTemplate,
    pDescriptorWrites,
    pDescriptors,
    pDevice,
    pDeviceEventInfo,
    pDeviceGroupPresentCapabilities,
    pDeviceIndices,
    pDeviceMasks,
    pDeviceRenderAreas,
    pDimensions,
    pDisabledValidationChecks,
    pDisabledValidationFeatures,
    pDiscardRectangles,
    pDispatchParameters,
    pDispatchTileInfo,
    pDisplay,
    pDisplayCount,
    pDisplayEventInfo,
    pDisplayPlaneInfo,
    pDisplayPowerInfo,
    pDisplayTimingProperties,
    pDisplays,
    pDrivers,
    pDrmFormatModifierProperties,
    pDrmFormatModifiers,
    pDstOffset,
    pDstRange,
    pDstSize,
    pDynamicMetadata,
    pDynamicOffsets,
    pDynamicState,
    pDynamicStates,
    pEmbeddedSampler,
    pEnabledFeatures,
    pEnabledValidationFeatures,
    pEncodeInfo,
    pEndCodingInfo,
    pEngineName,
    pEvent,
    pEvents,
    pExclusiveScissorEnables,
    pExclusiveScissors,
    pExecutableCount,
    pExecutableInfo,
    pExecuteInfo,
    pExecutionSet,
    pExecutionSetWrites,
    pExtensions,
    pExtent,
    pExternalBufferInfo,
    pExternalBufferProperties,
    pExternalFenceInfo,
    pExternalFenceProperties,
    pExternalImageFormatProperties,
    pExternalQueue,
    pExternalSemaphoreInfo,
    pExternalSemaphoreProperties,
    pExternalTensorInfo,
    pExternalTensorProperties,
    pExtras,
    pFaultCounts,
    pFaultInfo,
    pFd,
    pFeatures,
    pFeedbackInfo,
    pFence,
    pFences,
    pFixedRateFlags,
    pFormatConstraints,
    pFormatCount,
    pFormatInfo,
    pFormatProperties,
    pFragmentDensityOffsets,
    pFragmentShadingRateAttachment,
    pFragmentShadingRateCount,
    pFragmentShadingRates,
    pFragmentSize,
    pFramebuffer,
    pFunction,
    pGeneratedCommandsInfo,
    pGeometries,
    pGetFdInfo,
    pGetMetalHandleInfo,
    pGetWin32HandleInfo,
    pGetZirconHandleInfo,
    pGpaSampleBeginInfo,
    pGpaSession,
    pGranularity,
    pGroups,
    pHandle,
    pHitShaderBindingTable,
    pHostMapping,
    pHostPointer,
    pIdentifier,
    pImage,
    pImageBinds,
    pImageConstraintsInfo,
    pImageFormatInfo,
    pImageFormatProperties,
    pImageIndex,
    pImageIndices,
    pImageInfo,
    pImageMemoryBarriers,
    pImageOpaqueBinds,
    pImageSubresources,
    pImages,
    pImmutableSamplers,
    pImportFenceFdInfo,
    pImportFenceWin32HandleInfo,
    pImportSemaphoreFdInfo,
    pImportSemaphoreWin32HandleInfo,
    pImportSemaphoreZirconHandleInfo,
    pIndex,
    pIndexBuffer,
    pIndexInfo,
    pIndexTypeValues,
    pIndexTypes,
    pIndirectCommandsLayout,
    pIndirectDeviceAddresses,
    pIndirectExecutionSet,
    pIndirectStrides,
    pInfo,
    pInfoSize,
    pInfos,
    pInheritanceInfo,
    pInitialData,
    pInitialShaders,
    pInitializeInfo,
    pInputAssemblyState,
    pInputAttachmentImage,
    pInputAttachmentIndexInfo,
    pInputAttachments,
    pInstance,
    pInstrumentation,
    pInternalRepresentationCount,
    pInternalRepresentations,
    pKeysAndDataInfo,
    pLabelInfo,
    pLabelName,
    pLatencyMarkerInfo,
    pLaunchInfo,
    pLayer,
    pLayerName,
    pLayerPrefix,
    pLayeredApis,
    pLayers,
    pLayout,
    pLayoutSizeInBytes,
    pLibraries,
    pLibraryInfo,
    pLibraryInterface,
    pLocationInfo,
    pLowLatencyMode,
    pMapEntries,
    pMappings,
    pMarkerInfo,
    pMarkerName,
    pMaxDeviation,
    pMaxPrimitiveCounts,
    pMaxWorkgroupSize,
    pMemory,
    pMemoryBarriers,
    pMemoryFdProperties,
    pMemoryGetRemoteAddressInfo,
    pMemoryHostPointerProperties,
    pMemoryMapInfo,
    pMemoryMetalHandleProperties,
    pMemoryProperties,
    pMemoryRangeBarriers,
    pMemoryRanges,
    pMemoryRequirements,
    pMemoryRequirementsCount,
    pMemoryUnmapInfo,
    pMemoryWin32HandleProperties,
    pMemoryZirconHandleProperties,
    pMessage,
    pMessageData,
    pMessageIdName,
    pMessenger,
    pMetadata,
    pMetalObjectsInfo,
    pMetricBlockCount,
    pMetricValues,
    pMicromap,
    pMicromaps,
    pMissShaderBindingTable,
    pMode,
    pModes,
    pModule,
    pMoveObjects,
    pMultisampleProperties,
    pMultisampleState,
    pMutableDescriptorTypeLists,
    pNaluSliceEntries,
    pNaluSliceSegmentEntries,
    pName,
    pNameInfo,
    pNext,
    pNodeIndex,
    pNodeInfo,
    pNumPasses,
    pObjectName,
    pObjects,
    pOffset,
    pOffsets,
    pOperation,
    pOpticalFlowImageFormatInfo,
    pOverrideInfo,
    pParameters,
    pParametersAddInfo,
    pParams,
    pPastPresentationTimingInfo,
    pPastPresentationTimingProperties,
    pPeerMemoryFeatures,
    pPerTileBeginInfo,
    pPerTileEndInfo,
    pPerViewRenderAreas,
    pPerfBlocks,
    pPerfCounters,
    pPerfHintInfo,
    pPerformanceQueryCreateInfo,
    pPhysicalDeviceCount,
    pPhysicalDeviceGroupCount,
    pPhysicalDeviceGroupProperties,
    pPhysicalDevices,
    pPictureResource,
    pPipelineBinaries,
    pPipelineBinaryData,
    pPipelineBinaryDataSize,
    pPipelineBinaryKey,
    pPipelineBinaryKeys,
    pPipelineCache,
    pPipelineCreateInfo,
    pPipelineCreationFeedback,
    pPipelineInfo,
    pPipelineKey,
    pPipelineLayout,
    pPipelineProperties,
    pPipelineStageCreationFeedbacks,
    pPipelines,
    pPlacedAddress,
    pPlaneLayouts,
    pPoolSizes,
    pPostSubpassSampleLocations,
    pPresentIds,
    pPresentInfo,
    pPresentModeCount,
    pPresentModes,
    pPresentStages,
    pPresentWait2Info,
    pPresentationInfo,
    pPresentationTimingCount,
    pPresentationTimings,
    pPreserveAttachments,
    pPrivateData,
    pPrivateDataSlot,
    pProcessingEngines,
    pProfiles,
    pProperties,
    pPropertiesCount,
    pPropertyCount,
    pPushConstant,
    pPushConstantRanges,
    pPushConstantsInfo,
    pPushDataInfo,
    pPushDescriptorSetInfo,
    pPushDescriptorSetWithTemplateInfo,
    pQualityLevelInfo,
    pQualityLevelProperties,
    pQueriedLowLatencyData,
    pQueryPool,
    pQueue,
    pQueueCreateInfos,
    pQueueFamilyDataGraphProcessingEngineInfo,
    pQueueFamilyDataGraphProcessingEngineProperties,
    pQueueFamilyDataGraphProperties,
    pQueueFamilyDataGraphPropertyCount,
    pQueueFamilyIndices,
    pQueueFamilyProperties,
    pQueueFamilyPropertyCount,
    pQueueInfo,
    pQueueLabels,
    pQueuePriorities,
    pQueueTypeInfo,
    pRanges,
    pRasterizationState,
    pRaygenShaderBindingTable,
    pRectCount,
    pRectangles,
    pRects,
    pReferenceSlots,
    pRegions,
    pReleaseInfo,
    pReleaseKeys,
    pReleaseSyncs,
    pRenderPass,
    pRenderPassBegin,
    pRenderPassFeedback,
    pRenderingAreaInfo,
    pRenderingEndInfo,
    pRenderingInfo,
    pResolveAttachments,
    pResolveImageInfo,
    pResourceHeapBindInfo,
    pResourceInfos,
    pResources,
    pResult,
    pResults,
    pSampleID,
    pSampleLocations,
    pSampleLocationsInfo,
    pSampleMask,
    pSampledImage,
    pSampler,
    pSamplerHeapBindInfo,
    pSamplers,
    pScissors,
    pSemaphore,
    pSemaphores,
    pSession,
    pSetDescriptorBufferOffsetsInfo,
    pSetLayout,
    pSetLayoutInfos,
    pSetLayouts,
    pSettingName,
    pSettings,
    pSetupReferenceSlot,
    pShaderGroupCaptureReplayHandle,
    pShaderInfo,
    pShaderModule,
    pShaders,
    pShadingRatePaletteEntries,
    pShadingRatePalettes,
    pSignalInfo,
    pSignalSemaphoreDeviceIndices,
    pSignalSemaphoreInfos,
    pSignalSemaphoreValues,
    pSignalSemaphores,
    pSizeInBytes,
    pSizeInfo,
    pSizes,
    pSleepInfo,
    pSleepModeInfo,
    pSliceOffsets,
    pSliceSegmentOffsets,
    pSparseMemoryRequirementCount,
    pSparseMemoryRequirements,
    pSpecializationInfo,
    pSplitInstanceBindRegions,
    pSrcCaches,
    pSrcOffset,
    pStages,
    pStatisticCount,
    pStatistics,
    pStdDecoderModelInfo,
    pStdHeaderVersion,
    pStdOperatingPoints,
    pStdPPS,
    pStdPPSs,
    pStdPictureInfo,
    pStdReferenceInfo,
    pStdSPS,
    pStdSPSs,
    pStdSequenceHeader,
    pStdSliceHeader,
    pStdSliceSegmentHeader,
    pStdVPS,
    pStdVPSs,
    pStencilAttachment,
    pStencilInputAttachmentIndex,
    pStorageBuffer,
    pStorageImage,
    pStorageTexelBuffer,
    pStreamStrides,
    pStreams,
    pStrides,
    pStripeInfos,
    pStripeSemaphoreInfos,
    pSubmits,
    pSubpassBeginInfo,
    pSubpassEndInfo,
    pSubpassFeedback,
    pSubpasses,
    pSubresource,
    pSupport,
    pSupported,
    pSurface,
    pSurfaceCapabilities,
    pSurfaceFormatCount,
    pSurfaceFormats,
    pSurfaceInfo,
    pSwapchain,
    pSwapchainImageCount,
    pSwapchainImages,
    pSwapchainTimeDomainProperties,
    pSwapchainTimingProperties,
    pSwapchainTimingPropertiesCounter,
    pSwapchains,
    pTag,
    pTagInfo,
    pTensor,
    pTensorARM,
    pTensorMemoryBarriers,
    pTensorViews,
    pTensors,
    pTessellationState,
    pTexelBuffer,
    pTexelBufferView,
    pTileMemoryBindInfo,
    pTileOffsets,
    pTileSizes,
    pTimeDomainCount,
    pTimeDomainIds,
    pTimeDomains,
    pTimeDomainsCounter,
    pTimes,
    pTimestampInfos,
    pTimestamps,
    pTimingInfos,
    pTimings,
    pTokens,
    pToolCount,
    pToolProperties,
    pTransitions,
    pTriangleClusters,
    pUniformBuffer,
    pUniformTexelBuffer,
    pUpdateInfo,
    pUsageCounts,
    pUserData,
    pValidationCache,
    pValue,
    pValues,
    pVendorBinaryData,
    pVendorInfos,
    pVendorOptions,
    pVersionData,
    pVersionInfo,
    pVertexAttributeDescriptions,
    pVertexBindingDescriptions,
    pVertexBindingDivisors,
    pVertexBuffer,
    pVertexInfo,
    pVertexInputState,
    pVertexOffset,
    pVideoFormatInfo,
    pVideoFormatProperties,
    pVideoFormatPropertyCount,
    pVideoProfile,
    pVideoSession,
    pVideoSessionParameters,
    pVideoSessionParametersInfo,
    pView,
    pViewFormats,
    pViewMasks,
    pViewOffsets,
    pViewportDepths,
    pViewportState,
    pViewportSwizzles,
    pViewportWScalings,
    pViewports,
    pWaitDstStageMask,
    pWaitInfo,
    pWaitSemaphoreDeviceIndices,
    pWaitSemaphoreInfos,
    pWaitSemaphoreValues,
    pWaitSemaphores,
    pYcbcrConversion,
    pZirconHandle,
    pageableDeviceLocalMemory,
    paramCount,
    parameter,
    parameters,
    params,
    partitionCount,
    partitionIndependentIntraRefreshRegions,
    partitionIndex,
    partitionTranslation,
    partitionedAccelerationStructure,
    passOp,
    patch,
    patchControlPoints,
    payloadCount,
    payloadStride,
    payloads,
    pciBus,
    pciDevice,
    pciDomain,
    pciFunction,
    perBasicBlockGranularity,
    perPartitionEncodeFeedbackFlags,
    perStageDescriptorSet,
    perViewAttributes,
    perViewAttributesPositionXOnly,
    perViewPositionAllComponents,
    perViewRenderAreaCount,
    perfBlockCount,
    perfCounterCount,
    perfCounterDeviceMemoryLimit,
    perfCounters,
    performEncodeRgbConversion,
    performanceCounterMultipleQueryPools,
    performanceCounterQueryPools,
    performanceCounterRegionSize,
    performanceCountersByRegion,
    performanceCountersSampling,
    performanceLevel,
    persistent,
    persistentContent,
    pfnAllocation,
    pfnCallback,
    pfnFree,
    pfnGetInstanceProcAddr,
    pfnInternalAllocation,
    pfnInternalFree,
    pfnReallocation,
    pfnUserCallback,
    physicalDevice,
    physicalDeviceCount,
    physicalDevices,
    physicalDimensions,
    physicalResolution,
    pictureAccessGranularity,
    pictureFormat,
    pictureLayout,
    pipeline,
    pipelineAddress,
    pipelineBinaries,
    pipelineBinary,
    pipelineBinaryCompressedData,
    pipelineBinaryCount,
    pipelineBinaryInternalCache,
    pipelineBinaryInternalCacheControl,
    pipelineBinaryPrecompiledInternalCache,
    pipelineBinaryPrefersInternalCache,
    pipelineBindPoint,
    pipelineCache,
    pipelineCacheIncrementalMode,
    pipelineCacheUUID,
    pipelineCount,
    pipelineCreationCacheControl,
    pipelineDeviceAddressCaptureReplay,
    pipelineExecutableInfo,
    pipelineFragmentShadingRate,
    pipelineIdentifier,
    pipelineLayout,
    pipelineLibraryGroupHandles,
    pipelineOpacityMicromap,
    pipelinePropertiesIdentifier,
    pipelineProtectedAccess,
    pipelineRobustness,
    pipelineStackSize,
    pipelineStage,
    pipelineStageCreationFeedbackCount,
    pipelineStatistics,
    pipelineStatisticsQuery,
    pixelRate,
    pixelX,
    pixelY,
    plane,
    planeAspect,
    planeIndex,
    planeReorderPossible,
    planeStackIndex,
    pointClippingBehavior,
    pointPolygons,
    pointSizeGranularity,
    pointSizeRange,
    polygonMode,
    polygonModePointSize,
    poolSizeCount,
    positionTruncateBitCount,
    postMergeIndex,
    postMergeSubpassCount,
    postSubpassSampleLocationsCount,
    powerState,
    ppBuildRangeInfos,
    ppData,
    ppEnabledExtensionNames,
    ppEnabledLayerNames,
    ppGeometries,
    ppMaxPrimitiveCounts,
    ppUsageCounts,
    preTransform,
    precedingExternallyEncodedBytes,
    predictionMode,
    predictiveFrameSize,
    predictiveQIndex,
    preferNonCoherent,
    preferredBidirectionalCompoundReferenceNameMask,
    preferredConsecutiveBFrameCount,
    preferredConsecutiveBipredictiveFrameCount,
    preferredConstantQIndex,
    preferredConstantQp,
    preferredGopFrameCount,
    preferredIdrPeriod,
    preferredKeyFramePeriod,
    preferredMaxBidirectionalCompoundGroup1ReferenceCount,
    preferredMaxBidirectionalCompoundGroup2ReferenceCount,
    preferredMaxBidirectionalCompoundReferenceCount,
    preferredMaxL0ReferenceCount,
    preferredMaxL1ReferenceCount,
    preferredMaxSingleReferenceCount,
    preferredMaxUnidirectionalCompoundGroup1ReferenceCount,
    preferredMaxUnidirectionalCompoundReferenceCount,
    preferredQueue,
    preferredRateControlFlags,
    preferredRateControlLayerCount,
    preferredRateControlMode,
    preferredSingleReferenceNameMask,
    preferredStdEntropyCodingModeFlag,
    preferredSubLayerCount,
    preferredTemporalLayerCount,
    preferredUnidirectionalCompoundReferenceNameMask,
    prefersCompactPrimitiveOutput,
    prefersCompactVertexOutput,
    prefersDedicatedAllocation,
    prefersGopRemainingFrames,
    prefersLocalInvocationPrimitiveOutput,
    prefersLocalInvocationVertexOutput,
    preprocessAddress,
    preprocessBuffer,
    preprocessOffset,
    preprocessSize,
    presentAtAbsoluteTime,
    presentAtAbsoluteTimeSupported,
    presentAtRelativeTime,
    presentAtRelativeTimeSupported,
    presentBarrier,
    presentBarrierEnable,
    presentBarrierSupported,
    presentConfigFeedback,
    presentEndTimeUs,
    presentGravityX,
    presentGravityY,
    presentID,
    presentId,
    presentId2,
    presentId2Supported,
    presentMargin,
    presentMask,
    presentMetering,
    presentMode,
    presentModeCount,
    presentModeFifoLatestReady,
    presentStage,
    presentStageCount,
    presentStageQueries,
    presentStartTimeUs,
    presentTiming,
    presentTimingSupported,
    presentWait,
    presentWait2,
    presentWait2Supported,
    presentationTimingCount,
    preserveAttachmentCount,
    primaryMajor,
    primaryMinor,
    primaryReferenceCdfOnly,
    primitiveCount,
    primitiveFragmentShadingRate,
    primitiveFragmentShadingRateMeshShader,
    primitiveFragmentShadingRateWithMultipleViewports,
    primitiveOffset,
    primitiveOverestimationSize,
    primitiveRestartEnable,
    primitiveRestartIndex,
    primitiveTopology,
    primitiveTopologyListRestart,
    primitiveTopologyPatchListRestart,
    primitiveUnderestimation,
    primitivesGeneratedQuery,
    primitivesGeneratedQueryWithNonZeroStreams,
    primitivesGeneratedQueryWithRasterizerDiscard,
    priorities,
    priority,
    priorityCount,
    privateData,
    privateDataSlot,
    privateDataSlotRequestCount,
    processingEngineCount,
    profileCount,
    properties,
    propertiesCount,
    property,
    propertyFlags,
    protectedDescriptorHeaps,
    protectedMemory,
    protectedNoFault,
    protectedSubmit,
    provokingVertexLast,
    provokingVertexMode,
    provokingVertexModePerPipeline,
    purposes,
    pushAddressOffset,
    pushConstantBank,
    pushConstantRangeCount,
    pushDataOffset,
    pushDataSize,
    pushDescriptor,
    pushIndex,
    pushOffset,
    pushconstantOffset,
    pushconstantPipelineLayout,
    pushconstantShaderStageFlags,
    pushconstantSize,
    pvx,
    pvy,
    pvz,
    qpB,
    qpI,
    qpP,
    quadDivergentImplicitLod,
    quadOperationsInAllStages,
    qualityFlags,
    qualityLevel,
    quantizationMap,
    quantizationMapExtent,
    quantizationMapTexelSize,
    query,
    queryCount,
    queryFlags,
    queryPool,
    queryResultFlags,
    queryResultStatusSupport,
    queryType,
    queue,
    queueCount,
    queueCreateInfoCount,
    queueFamilyIndex,
    queueFamilyIndexCount,
    queueFamilyProperties,
    queueFlags,
    queueIndex,
    queueLabelCount,
    queuePerfHint,
    queueSubmitBoundary,
    queueType,
    qw,
    qx,
    qy,
    qz,
    r,
    radiusData,
    radiusFormat,
    radiusStride,
    range,
    rangeCount,
    rasterizationOrder,
    rasterizationOrderColorAttachmentAccess,
    rasterizationOrderDepthAttachmentAccess,
    rasterizationOrderStencilAttachmentAccess,
    rasterizationSamples,
    rasterizationStream,
    rasterizerDiscardEnable,
    rateControlGroup,
    rateControlMode,
    rateControlModes,
    rayQuery,
    rayTracingInvocationReorder,
    rayTracingInvocationReorderReorderingHint,
    rayTracingMaintenance1,
    rayTracingMotionBlur,
    rayTracingMotionBlurPipelineTraceRaysIndirect,
    rayTracingPipeline,
    rayTracingPipelineShaderGroupHandleCaptureReplay,
    rayTracingPipelineShaderGroupHandleCaptureReplayMixed,
    rayTracingPipelineTraceRaysIndirect,
    rayTracingPipelineTraceRaysIndirect2,
    rayTracingPositionFetch,
    rayTracingValidation,
    rayTraversalPrimitiveCulling,
    raygenShaderBindingOffset,
    raygenShaderBindingTableBuffer,
    raygenShaderRecordAddress,
    raygenShaderRecordSize,
    rect,
    rectCount,
    rectangleCount,
    rectangularLines,
    reductionMode,
    reference,
    referenceNameSlotIndices,
    referencePictureFormat,
    referenceSlotCount,
    refreshDuration,
    refreshInterval,
    refreshRate,
    regionAlignment,
    regionCount,
    relaxedLineRasterization,
    releaseCount,
    remoteDeviceIndex,
    renderArea,
    renderMajor,
    renderMinor,
    renderPass,
    renderPassStripeGranularity,
    renderPassStriped,
    renderSubmitEndTimeUs,
    renderSubmitStartTimeUs,
    renderpass,
    reportAddressBinding,
    reportComplete,
    reportedAddress,
    representativeFragmentTest,
    representativeFragmentTestEnable,
    requestIndex,
    requiredFormatFeatures,
    requiredSubgroupSize,
    requiredSubgroupSizeStages,
    requiresDedicatedAllocation,
    requiresGopRemainingFrames,
    reserved,
    reservedExternalQueues,
    reservedRangeOffset,
    reservedRangeSize,
    residencyAlignedMipSize,
    residencyNonResidentStrict,
    residencyStandard2DBlockShape,
    residencyStandard2DMultisampleBlockShape,
    residencyStandard3DBlockShape,
    resolveImageLayout,
    resolveImageView,
    resolveMode,
    resolveSrgbFormatAppliesTransferFunction,
    resolveSrgbFormatSupportsTransferFunctionControl,
    resourceCount,
    resourceDescriptorBufferAddressSpaceSize,
    resourceDeviceIndex,
    resourceHeapAlignment,
    resourceInfoCount,
    resourceMask,
    resourceOffset,
    resourceUsage,
    resultIndex,
    resultSubIndex,
    resultType,
    revisionId,
    rgbModel,
    rgbModels,
    rgbRange,
    rgbRanges,
    rgba4OpaqueBlackSwizzled,
    robustBufferAccess,
    robustBufferAccess2,
    robustBufferAccessUpdateAfterBind,
    robustFragmentShadingRateAttachmentAccess,
    robustImageAccess,
    robustImageAccess2,
    robustStorageBufferAccessSizeAlignment,
    robustStorageBufferDescriptorSize,
    robustStorageTexelBufferDescriptorSize,
    robustUniformBufferAccessSizeAlignment,
    robustUniformBufferDescriptorSize,
    robustUniformTexelBufferDescriptorSize,
    roundingModeIndependence,
    rowPitch,
    rowStrideAlignment,
    rrOutput,
    runtimeDescriptorArray,
    sType,
    sample,
    sampleCount,
    sampleCounts,
    sampleID,
    sampleInternalOperations,
    sampleLocationCoordinateRange,
    sampleLocationCount,
    sampleLocationGridSize,
    sampleLocationSampleCounts,
    sampleLocationSubPixelBits,
    sampleLocationsCount,
    sampleLocationsEnable,
    sampleLocationsInfo,
    sampleLocationsPerPixel,
    sampleOrderType,
    sampleRateShading,
    sampleShadingEnable,
    sampleType,
    sampledImageColorSampleCounts,
    sampledImageDepthSampleCounts,
    sampledImageDescriptorSize,
    sampledImageIntegerSampleCounts,
    sampledImageStencilSampleCounts,
    sampler,
    sampler2DViewOf3D,
    samplerAddressOffset,
    samplerAnisotropy,
    samplerCaptureReplayDescriptorDataSize,
    samplerCount,
    samplerDescriptorAlignment,
    samplerDescriptorBufferAddressSpaceSize,
    samplerDescriptorSize,
    samplerFilterMinmax,
    samplerHeapAlignment,
    samplerHeapArrayStride,
    samplerHeapIndexStride,
    samplerHeapOffset,
    samplerIndex,
    samplerMipLodBias,
    samplerMirrorClampToEdge,
    samplerPushOffset,
    samplerShaderRecordOffset,
    samplerYcbcrConversion,
    samplerYcbcrConversionComponents,
    samplerYcbcrConversionCount,
    samples,
    saturatingAccumulation,
    scalarBlockLayout,
    scale,
    scalingBehavior,
    schedulingControls,
    schedulingControlsFlags,
    schedulingControlsMaxQueuedBatchesCount,
    schedulingControlsMaxWarpsCount,
    schedulingControlsMaxWorkGroupBatchSize,
    scissorCount,
    scope,
    scratch,
    scratchData,
    scratchMemUsageInBytes,
    scratchOffset,
    scratchSize,
    screenBufferImport,
    screenUsage,
    secondaryCopySource,
    selectableCubicWeights,
    semaphore,
    semaphoreCount,
    semaphoreType,
    separateDepthStencilAttachmentAccess,
    separateDepthStencilLayouts,
    separateStencilMaskRef,
    sequenceCountAddress,
    sequencesCount,
    sequencesCountBuffer,
    sequencesCountOffset,
    sequencesIndexBuffer,
    sequencesIndexOffset,
    serializeRegions,
    session,
    set,
    setCount,
    setLayoutCount,
    setStride,
    settingCount,
    sgprAllocationGranularity,
    sgprsPerSimd,
    shader,
    shader64BitIndexing,
    shaderAbort,
    shaderArraysPerEngineCount,
    shaderBFloat16CooperativeMatrix,
    shaderBFloat16DotProduct,
    shaderBFloat16Type,
    shaderBinaryUUID,
    shaderBinaryVersion,
    shaderBufferFloat16AtomicAdd,
    shaderBufferFloat16AtomicMinMax,
    shaderBufferFloat16Atomics,
    shaderBufferFloat32AtomicAdd,
    shaderBufferFloat32AtomicMinMax,
    shaderBufferFloat32Atomics,
    shaderBufferFloat64AtomicAdd,
    shaderBufferFloat64AtomicMinMax,
    shaderBufferFloat64Atomics,
    shaderBufferInt64Atomics,
    shaderClipDistance,
    shaderConstantData,
    shaderCoreBuiltins,
    shaderCoreCount,
    shaderCoreFeatures,
    shaderCoreMask,
    shaderCount,
    shaderCullDistance,
    shaderDemoteToHelperInvocation,
    shaderDenormFlushToZeroFloat16,
    shaderDenormFlushToZeroFloat32,
    shaderDenormFlushToZeroFloat64,
    shaderDenormPreserveFloat16,
    shaderDenormPreserveFloat32,
    shaderDenormPreserveFloat64,
    shaderDeviceClock,
    shaderDrawParameters,
    shaderEarlyAndLateFragmentTests,
    shaderEngineCount,
    shaderEnqueue,
    shaderExpectAssume,
    shaderFloat16,
    shaderFloat16VectorAtomics,
    shaderFloat4,
    shaderFloat6,
    shaderFloat64,
    shaderFloat8,
    shaderFloat8CooperativeMatrix,
    shaderFloat8UnsignedE8M0,
    shaderFloatControls2,
    shaderFmaFloat16,
    shaderFmaFloat32,
    shaderFmaFloat64,
    shaderGroupBaseAlignment,
    shaderGroupHandleAlignment,
    shaderGroupHandleCaptureReplaySize,
    shaderGroupHandleSize,
    shaderImageFloat32AtomicAdd,
    shaderImageFloat32AtomicMinMax,
    shaderImageFloat32Atomics,
    shaderImageGatherExtended,
    shaderImageInt64Atomics,
    shaderInputAttachmentArrayDynamicIndexing,
    shaderInputAttachmentArrayNonUniformIndexing,
    shaderInputAttachmentArrayNonUniformIndexingNative,
    shaderInstrumentation,
    shaderInt16,
    shaderInt64,
    shaderInt8,
    shaderIntegerDotProduct,
    shaderIntegerFunctions2,
    shaderMXInt8,
    shaderMaximalReconvergence,
    shaderMeshEnqueue,
    shaderMixedFloatDotProductBFloat16Acc,
    shaderMixedFloatDotProductFloat16AccFloat16,
    shaderMixedFloatDotProductFloat16AccFloat32,
    shaderMixedFloatDotProductFloat8AccFloat32,
    shaderModule,
    shaderModuleIdentifier,
    shaderModuleIdentifierAlgorithmUUID,
    shaderMultipleWaitQueues,
    shaderObject,
    shaderOutputLayer,
    shaderOutputViewportIndex,
    shaderQuadControl,
    shaderRawAccessChains,
    shaderRecordAddressOffset,
    shaderRecordDataOffset,
    shaderRecordIndex,
    shaderRecordOffset,
    shaderRelaxedExtendedInstruction,
    shaderReplicatedComposites,
    shaderResourceMinLod,
    shaderResourceResidency,
    shaderRoundingModeRTEFloat16,
    shaderRoundingModeRTEFloat32,
    shaderRoundingModeRTEFloat64,
    shaderRoundingModeRTZFloat16,
    shaderRoundingModeRTZFloat32,
    shaderRoundingModeRTZFloat64,
    shaderSMBuiltins,
    shaderSMCount,
    shaderSampleRateInterpolationFunctions,
    shaderSampledImageArrayDynamicIndexing,
    shaderSampledImageArrayNonUniformIndexing,
    shaderSampledImageArrayNonUniformIndexingNative,
    shaderSharedFloat16AtomicAdd,
    shaderSharedFloat16AtomicMinMax,
    shaderSharedFloat16Atomics,
    shaderSharedFloat32AtomicAdd,
    shaderSharedFloat32AtomicMinMax,
    shaderSharedFloat32Atomics,
    shaderSharedFloat64AtomicAdd,
    shaderSharedFloat64AtomicMinMax,
    shaderSharedFloat64Atomics,
    shaderSharedInt64Atomics,
    shaderSignedZeroInfNanPreserveFloat16,
    shaderSignedZeroInfNanPreserveFloat32,
    shaderSignedZeroInfNanPreserveFloat64,
    shaderSplitBarrier,
    shaderStage,
    shaderStageMask,
    shaderStages,
    shaderStorageBufferArrayDynamicIndexing,
    shaderStorageBufferArrayNonUniformIndexing,
    shaderStorageBufferArrayNonUniformIndexingNative,
    shaderStorageImageArrayDynamicIndexing,
    shaderStorageImageArrayNonUniformIndexing,
    shaderStorageImageArrayNonUniformIndexingNative,
    shaderStorageImageExtendedFormats,
    shaderStorageImageMultisample,
    shaderStorageImageReadWithoutFormat,
    shaderStorageImageWriteWithoutFormat,
    shaderStorageTensorArrayDynamicIndexing,
    shaderStorageTensorArrayNonUniformIndexing,
    shaderStorageTensorArrayNonUniformIndexingNative,
    shaderStorageTexelBufferArrayDynamicIndexing,
    shaderStorageTexelBufferArrayNonUniformIndexing,
    shaderSubgroupClock,
    shaderSubgroupExtendedTypes,
    shaderSubgroupPartitioned,
    shaderSubgroupRotate,
    shaderSubgroupRotateClustered,
    shaderSubgroupUniformControlFlow,
    shaderTensorAccess,
    shaderTensorSupportedStages,
    shaderTerminateInvocation,
    shaderTessellationAndGeometryPointSize,
    shaderTileImageCoherentReadAccelerated,
    shaderTileImageColorReadAccess,
    shaderTileImageDepthReadAccess,
    shaderTileImageReadFromHelperInvocation,
    shaderTileImageReadSampleFromPixelRateInvocation,
    shaderTileImageStencilReadAccess,
    shaderUniformBufferArrayDynamicIndexing,
    shaderUniformBufferArrayNonUniformIndexing,
    shaderUniformBufferArrayNonUniformIndexingNative,
    shaderUniformBufferUnsizedArray,
    shaderUniformTexelBufferArrayDynamicIndexing,
    shaderUniformTexelBufferArrayNonUniformIndexing,
    shaderUntypedPointers,
    shaderWarpsPerCore,
    shaderWarpsPerSM,
    shaderZeroInitializeWorkgroupMemory,
    shadingRate,
    shadingRateAttachmentTexelSize,
    shadingRateCoarseSampleOrder,
    shadingRateImage,
    shadingRateImageEnable,
    shadingRateMaxCoarseSamples,
    shadingRatePaletteEntryCount,
    shadingRatePaletteSize,
    shadingRateTexelSize,
    shadingRateType,
    sharedMemBytes,
    sharedPresentSupportedUsageFlags,
    sharingMode,
    signalSemaphore,
    signalSemaphoreCount,
    signalSemaphoreInfoCount,
    signalSemaphoreValueCount,
    signalSemaphoreValuesCount,
    simEndTimeUs,
    simStartTimeUs,
    simdPerComputeUnit,
    singleReferenceNameMask,
    size,
    sizeGranularity,
    sliceCount,
    sliceOffset,
    sliceSegmentCount,
    slotIndex,
    smoothLines,
    source,
    sourceData,
    sparseAddressSpaceSize,
    sparseBinding,
    sparseDescriptorHeaps,
    sparseImageFloat32AtomicAdd,
    sparseImageFloat32AtomicMinMax,
    sparseImageFloat32Atomics,
    sparseImageInt64Atomics,
    sparseProperties,
    sparseResidency16Samples,
    sparseResidency2Samples,
    sparseResidency4Samples,
    sparseResidency8Samples,
    sparseResidencyAliased,
    sparseResidencyBuffer,
    sparseResidencyImage2D,
    sparseResidencyImage3D,
    specVersion,
    spheres,
    splitBarrierReservedSharedMemory,
    splitInstanceBindRegionCount,
    sqShaderMask,
    sqShaderMaskEnable,
    sqThreadTraceDeviceMemoryLimit,
    sqThreadTraceEnable,
    sqThreadTraceSuppressInstructionTokens,
    sqThreadTracing,
    src,
    srcAccelerationStructure,
    srcAccelerationStructureData,
    srcAccessMask,
    srcAccessMask3,
    srcAddress,
    srcAlphaBlendFactor,
    srcArrayElement,
    srcBinding,
    srcBuffer,
    srcBufferOffset,
    srcBufferRange,
    srcCacheCount,
    srcColorBlendFactor,
    srcComponentType,
    srcCopyFlags,
    srcData,
    srcFlags,
    srcImage,
    srcImageLayout,
    srcInfos,
    srcInfosArray,
    srcInfosCount,
    srcLayout,
    srcOffset,
    srcOffsets,
    srcPictureResource,
    srcPremultiplied,
    srcQueueFamilyIndex,
    srcRange,
    srcRect,
    srcSet,
    srcSize,
    srcStageMask,
    srcStride,
    srcSubpass,
    srcSubresource,
    srcTensor,
    srgb,
    srtMotionInstance,
    stage,
    stageCount,
    stageFlags,
    stageMask,
    stages,
    standardSampleLocations,
    startAddress,
    stateCommandBuffer,
    staticInstance,
    stdHeaderVersion,
    stdOperatingPointCount,
    stdPPSCount,
    stdPPSId,
    stdProfile,
    stdProfileIdc,
    stdSPSCount,
    stdSPSId,
    stdSyntaxFlags,
    stdVPSCount,
    stdVPSId,
    stencil,
    stencilAttachmentFormat,
    stencilFinalLayout,
    stencilInitialLayout,
    stencilLayout,
    stencilLoadOp,
    stencilResolveMode,
    stencilStoreOp,
    stencilTestEnable,
    stencilUsage,
    stereoType,
    stippledBresenhamLines,
    stippledLineEnable,
    stippledRectangularLines,
    stippledSmoothLines,
    storage,
    storageBuffer16BitAccess,
    storageBuffer8BitAccess,
    storageBufferDescriptorSize,
    storageBuffers,
    storageImageDescriptorSize,
    storageImageSampleCounts,
    storageInputOutput16,
    storagePushConstant16,
    storagePushConstant8,
    storageTexelBufferDescriptorSize,
    storageTexelBufferOffsetAlignmentBytes,
    storageTexelBufferOffsetSingleTexelAlignment,
    storeOp,
    stream,
    streamCount,
    streamDescriptor,
    streamingPerfCounters,
    streamingPerfTraceSampleInterval,
    strictLines,
    stride,
    strideInBytes,
    stripeArea,
    stripeInfoCount,
    stripeSemaphoreInfoCount,
    subLayerCount,
    subPixelInterpolationOffsetBits,
    subPixelPrecisionBits,
    subTexelPrecisionBits,
    subdivisionLevel,
    subgroupBroadcastDynamicId,
    subgroupQuadOperationsInAllStages,
    subgroupSize,
    subgroupSizeControl,
    subgroupSupportedOperations,
    subgroupSupportedStages,
    subminor,
    submitCount,
    subpass,
    subpassCount,
    subpassIndex,
    subpassMergeFeedback,
    subpassMergeStatus,
    subpassShading,
    subresource,
    subresourceLayout,
    subresourceRange,
    subsampledCoarseReconstructionEarlyAccess,
    subsampledImageDescriptorCount,
    subsampledLoads,
    subsetAllocation,
    suggestedXChromaOffset,
    suggestedYChromaOffset,
    suggestedYcbcrModel,
    suggestedYcbcrRange,
    superblockSizes,
    supersampleFragmentShadingRates,
    supported,
    supportedAlpha,
    supportedCompositeAlpha,
    supportedDepthResolveModes,
    supportedEncodeFeedbackFlags,
    supportedHintGridSizes,
    supportedImageAlignmentMask,
    supportedIndirectCommandsInputModes,
    supportedIndirectCommandsShaderStages,
    supportedIndirectCommandsShaderStagesPipelineBinding,
    supportedIndirectCommandsShaderStagesShaderBinding,
    supportedOperations,
    supportedOutputGridSizes,
    supportedPerPartitionEncodeFeedbackFlags,
    supportedPresentGravityX,
    supportedPresentGravityY,
    supportedPresentScaling,
    supportedQueues,
    supportedStages,
    supportedStencilResolveModes,
    supportedSurfaceCounters,
    supportedTransforms,
    supportedUsageFlags,
    supportsNonZeroFirstInstance,
    supportsProtected,
    supportsTextureGatherLODBiasAMD,
    surface,
    surfaceCapabilities,
    surfaceCounters,
    surfaceFormat,
    swapBufferTimestamp,
    swapChain,
    swapchain,
    swapchainCount,
    swapchainMaintenance1,
    swapchainSupportedFlags,
    sx,
    sy,
    synchronization2,
    sysmemColorSpaceIndex,
    sysmemPixelFormat,
    sz,
    tagName,
    tagSize,
    targetTime,
    targetTimeDomainPresentStage,
    taskCount,
    taskShader,
    templateType,
    temporalLayerCount,
    tensor,
    tensorCaptureReplayDescriptorDataSize,
    tensorCaptureReplayOpaqueDataSize,
    tensorCount,
    tensorDescriptorAlignment,
    tensorDescriptorSize,
    tensorMemoryBarrierCount,
    tensorNonPacked,
    tensorView,
    tensorViewCaptureReplayDescriptorDataSize,
    tensorViewCount,
    tensors,
    tessellationIsolines,
    tessellationPointMode,
    tessellationShader,
    texelBufferAlignment,
    texelRate,
    textureBlockMatch,
    textureBlockMatch2,
    textureBoxFilter,
    textureCompressionASTC_3D,
    textureCompressionASTC_HDR,
    textureCompressionASTC_LDR,
    textureCompressionBC,
    textureCompressionETC2,
    textureSampleWeighted,
    throttleHint,
    tileApronSize,
    tileBufferTransfers,
    tileCount,
    tileGranularity,
    tileMemoryHeap,
    tileProperties,
    tileShading,
    tileShadingAnisotropicApron,
    tileShadingApron,
    tileShadingAtomicOps,
    tileShadingColorAttachments,
    tileShadingDepthAttachments,
    tileShadingDispatchTile,
    tileShadingFragmentStage,
    tileShadingImageProcessing,
    tileShadingInputAttachments,
    tileShadingPerTileDispatch,
    tileShadingPerTileDraw,
    tileShadingSampledAttachments,
    tileShadingStencilAttachments,
    tileSize,
    tilesOffset,
    tiling,
    time,
    timeDomain,
    timeDomainCount,
    timeDomainId,
    timeDomainsCounter,
    timelineSemaphore,
    timeout,
    timestampComputeAndGraphics,
    timestampCount,
    timestampPeriod,
    timestampValidBits,
    timingCount,
    timingPostSample,
    timingPreSample,
    timingPropertiesCounter,
    tokenCount,
    tokenType,
    toolchainVersion,
    topology,
    transform,
    transformBlockSizes,
    transformData,
    transformFeedback,
    transformFeedbackDraw,
    transformFeedbackPreservesProvokingVertex,
    transformFeedbackPreservesTriangleFanProvokingVertex,
    transformFeedbackQueries,
    transformFeedbackRasterizationStreamSelect,
    transformFeedbackStreamsLinesTriangles,
    transformOffset,
    transformT0,
    transformT1,
    transitionCount,
    transpose,
    triStripVertexOrderIndependentOfProvokingVertex,
    triangleArray,
    triangleArrayStride,
    triangleCount,
    triangleFans,
    triangles,
    tuningMode,
    tx,
    ty,
    type,
    tz,
    u64,
    uint32,
    uint64,
    uncompressedHeaderOffset,
    underlyingAPI,
    unidirectionalCompoundReferenceNameMask,
    unifiedImageLayouts,
    unifiedImageLayoutsVideo,
    uniformAndStorageBuffer16BitAccess,
    uniformAndStorageBuffer8BitAccess,
    uniformBufferDescriptorSize,
    uniformBufferStandardLayout,
    uniformBuffers,
    uniformTexelBufferDescriptorSize,
    uniformTexelBufferOffsetAlignmentBytes,
    uniformTexelBufferOffsetSingleTexelAlignment,
    unit,
    unnormalizedCoordinates,
    update,
    updateRange,
    updateScratchSize,
    updateSequenceCount,
    usage,
    usageCountsCount,
    use64bitTexturing,
    useCombinedImageSamplerIndex,
    useGopRemainingFrames,
    useMaxFrameSize,
    useMaxLevel,
    useMaxLevelIdc,
    useMaxQIndex,
    useMaxQp,
    useMinQIndex,
    useMinQp,
    uuid,
    validationCache,
    value,
    value32,
    value64,
    valueBool,
    valueCount,
    valueFloat,
    valueString,
    variableMultisampleRate,
    variablePointers,
    variablePointersStorageBuffer,
    variableSampleLocations,
    vendorBinarySize,
    vendorFaultCode,
    vendorFaultData,
    vendorID,
    vendorInfo,
    vendorInfoCount,
    version,
    vertexAttributeAccessBeyondStride,
    vertexAttributeDescriptionCount,
    vertexAttributeInstanceRateDivisor,
    vertexAttributeInstanceRateZeroDivisor,
    vertexAttributeRobustness,
    vertexBindingDescriptionCount,
    vertexBindingDivisorCount,
    vertexBindingUnit,
    vertexBuffer,
    vertexBufferStride,
    vertexCount,
    vertexData,
    vertexDynamicStride,
    vertexFormat,
    vertexInputDynamicState,
    vertexInputs,
    vertexOffset,
    vertexPipelineStoresAndAtomics,
    vertexStride,
    vgprAllocationGranularity,
    vgprsPerSimd,
    videoCodecOperation,
    videoCodecOperations,
    videoContentHints,
    videoDecodeVP9,
    videoEncodeAV1,
    videoEncodeFeedback2,
    videoEncodeIntraRefresh,
    videoEncodeQuantizationMap,
    videoEncodeRgbConversion,
    videoMaintenance1,
    videoMaintenance2,
    videoSession,
    videoSessionParameters,
    videoSessionParametersTemplate,
    videoUsageHints,
    view,
    viewFormatCount,
    viewMask,
    viewOffset,
    viewType,
    viewportBoundsRange,
    viewportCount,
    viewportDepthCount,
    viewportScissor2D,
    viewportSubPixelBits,
    viewportWScalingEnable,
    virtualBufferSizeInMs,
    visibleRegion,
    visualID,
    visual_id,
    vulkanMemoryModel,
    vulkanMemoryModelAvailabilityVisibilityChains,
    vulkanMemoryModelDeviceScope,
    w,
    waitAll,
    waitSemaphoreCount,
    waitSemaphoreInfoCount,
    waitSemaphoreValueCount,
    waitSemaphoreValuesCount,
    wavefrontSize,
    wavefrontsPerSimd,
    whitePoint,
    wideLines,
    width,
    window,
    windowCompareMode,
    windowExtent,
    workGroupBatchSize,
    workgroupInvocations,
    workgroupMemoryExplicitLayout,
    workgroupMemoryExplicitLayout16BitAccess,
    workgroupMemoryExplicitLayout8BitAccess,
    workgroupMemoryExplicitLayoutScalarBlockLayout,
    wraps,
    writeMask,
    writeStdPPS,
    writeStdSPS,
    writeStdVPS,
    x,
    xChromaOffset,
    xChromaOffsets,
    xcoeff,
    y,
    yChromaOffset,
    yChromaOffsets,
    ycbcr2plane444Formats,
    ycbcrConversion,
    ycbcrDegamma,
    ycbcrImageArrays,
    ycbcrModel,
    ycbcrRange,
    ycoeff,
    z,
    zeroCount,
    zeroInitializeDeviceMemory,
    zirconHandle,
};

enum class Enum {
    Empty = 0,
    VkAccelerationStructureBuildTypeKHR,
    VkAccelerationStructureCompatibilityKHR,
    VkAccelerationStructureMemoryRequirementsTypeNV,
    VkAccelerationStructureMotionInstanceTypeNV,
    VkAccelerationStructureSerializedBlockTypeKHR,
    VkAccelerationStructureTypeKHR,
    VkAntiLagModeAMD,
    VkAntiLagStageAMD,
    VkAttachmentLoadOp,
    VkAttachmentStoreOp,
    VkBlendFactor,
    VkBlendOp,
    VkBlendOverlapEXT,
    VkBlockMatchWindowCompareModeQCOM,
    VkBorderColor,
    VkBuildAccelerationStructureModeKHR,
    VkBuildMicromapModeEXT,
    VkChromaLocation,
    VkClusterAccelerationStructureOpModeNV,
    VkClusterAccelerationStructureOpTypeNV,
    VkClusterAccelerationStructureTypeNV,
    VkCoarseSampleOrderTypeNV,
    VkColorSpaceKHR,
    VkCommandBufferLevel,
    VkCompareOp,
    VkComponentSwizzle,
    VkComponentTypeKHR,
    VkCompressedTriangleFormatAMDX,
    VkConservativeRasterizationModeEXT,
    VkCooperativeVectorMatrixLayoutNV,
    VkCopyAccelerationStructureModeKHR,
    VkCopyMicromapModeEXT,
    VkCoverageModulationModeNV,
    VkCoverageReductionModeNV,
    VkCubicFilterWeightsQCOM,
    VkDataGraphModelCacheTypeQCOM,
    VkDataGraphOpticalFlowPerformanceLevelARM,
    VkDataGraphPipelineNodeConnectionTypeARM,
    VkDataGraphPipelineNodeTypeARM,
    VkDataGraphPipelinePropertyARM,
    VkDataGraphPipelineSessionBindPointARM,
    VkDataGraphPipelineSessionBindPointTypeARM,
    VkDataGraphTOSALevelARM,
    VkDebugReportObjectTypeEXT,
    VkDefaultVertexAttributeValueKHR,
    VkDepthBiasRepresentationEXT,
    VkDepthClampModeEXT,
    VkDescriptorMappingSourceEXT,
    VkDescriptorType,
    VkDescriptorUpdateTemplateType,
    VkDeviceAddressBindingTypeEXT,
    VkDeviceEventTypeEXT,
    VkDeviceFaultAddressTypeKHR,
    VkDeviceFaultVendorBinaryHeaderVersionKHR,
    VkDeviceMemoryReportEventTypeEXT,
    VkDirectDriverLoadingModeLUNARG,
    VkDiscardRectangleModeEXT,
    VkDisplacementMicromapFormatNV,
    VkDisplayEventTypeEXT,
    VkDisplayPowerStateEXT,
    VkDisplaySurfaceStereoTypeNV,
    VkDriverId,
    VkDynamicState,
    VkFilter,
    VkFormat,
    VkFragmentShadingRateCombinerOpKHR,
    VkFragmentShadingRateNV,
    VkFragmentShadingRateTypeNV,
    VkFrontFace,
    VkFullScreenExclusiveEXT,
    VkGeometryTypeKHR,
    VkGpaDeviceClockModeAMD,
    VkGpaPerfBlockAMD,
    VkGpaSampleTypeAMD,
    VkImageLayout,
    VkImageTiling,
    VkImageType,
    VkImageViewType,
    VkIndexType,
    VkIndirectCommandsTokenTypeEXT,
    VkIndirectCommandsTokenTypeNV,
    VkIndirectExecutionSetInfoTypeEXT,
    VkInternalAllocationType,
    VkLatencyMarkerNV,
    VkLayerSettingTypeEXT,
    VkLayeredDriverUnderlyingApiMSFT,
    VkLineRasterizationMode,
    VkLogicOp,
    VkMemoryOverallocationBehaviorAMD,
    VkMicromapTypeEXT,
    VkNeuralAcceleratorStatisticsModeARM,
    VkObjectType,
    VkOpacityMicromapFormatKHR,
    VkOpacityMicromapSpecialIndexKHR,
    VkOpticalFlowPerformanceLevelNV,
    VkOpticalFlowSessionBindingPointNV,
    VkOutOfBandQueueTypeNV,
    VkPartitionedAccelerationStructureOpTypeNV,
    VkPerfHintTypeQCOM,
    VkPerformanceConfigurationTypeINTEL,
    VkPerformanceCounterScopeKHR,
    VkPerformanceCounterStorageKHR,
    VkPerformanceCounterUnitKHR,
    VkPerformanceOverrideTypeINTEL,
    VkPerformanceParameterTypeINTEL,
    VkPerformanceValueTypeINTEL,
    VkPhysicalDeviceDataGraphOperationTypeARM,
    VkPhysicalDeviceDataGraphProcessingEngineTypeARM,
    VkPhysicalDeviceLayeredApiKHR,
    VkPhysicalDeviceType,
    VkPipelineBindPoint,
    VkPipelineCacheHeaderVersion,
    VkPipelineExecutableStatisticFormatKHR,
    VkPipelineRobustnessBufferBehavior,
    VkPipelineRobustnessImageBehavior,
    VkPointClippingBehavior,
    VkPolygonMode,
    VkPresentModeKHR,
    VkPrimitiveTopology,
    VkProvokingVertexModeEXT,
    VkQueryPoolSamplingModeINTEL,
    VkQueryResultStatusKHR,
    VkQueryType,
    VkQueueGlobalPriority,
    VkRasterizationOrderAMD,
    VkRayTracingInvocationReorderModeEXT,
    VkRayTracingLssIndexingModeNV,
    VkRayTracingLssPrimitiveEndCapsModeNV,
    VkRayTracingShaderGroupTypeKHR,
    VkResult,
    VkSamplerAddressMode,
    VkSamplerMipmapMode,
    VkSamplerReductionMode,
    VkSamplerYcbcrModelConversion,
    VkSamplerYcbcrRange,
    VkScopeKHR,
    VkSemaphoreType,
    VkShaderCodeTypeEXT,
    VkShaderFloatControlsIndependence,
    VkShaderGroupShaderKHR,
    VkShaderInfoTypeAMD,
    VkShadingRatePaletteEntryNV,
    VkSharingMode,
    VkStencilOp,
    VkStructureType,
    VkSubpassContents,
    VkSubpassMergeStatusEXT,
    VkSystemAllocationScope,
    VkTensorTilingARM,
    VkTessellationDomainOrigin,
    VkThrottleHintTypeSEC,
    VkTimeDomainKHR,
    VkValidationCacheHeaderVersionEXT,
    VkValidationCheckEXT,
    VkValidationFeatureDisableEXT,
    VkValidationFeatureEnableEXT,
    VkVendorId,
    VkVertexInputRate,
    VkVideoEncodeAV1PredictionModeKHR,
    VkVideoEncodeAV1RateControlGroupKHR,
    VkVideoEncodeTuningModeKHR,
    VkViewportCoordinateSwizzleNV,
};
enum class FlagBitmask {
    Empty = 0,
    VkAccelerationStructureCreateFlagBitsKHR,
    VkAccessFlagBits,
    VkAccessFlagBits2,
    VkAccessFlagBits3KHR,
    VkAcquireProfilingLockFlagBitsKHR,
    VkAddressCommandFlagBitsKHR,
    VkAddressCopyFlagBitsKHR,
    VkAttachmentDescriptionFlagBits,
    VkBufferCreateFlagBits,
    VkBufferUsageFlagBits,
    VkBufferUsageFlagBits2,
    VkBuildAccelerationStructureFlagBitsKHR,
    VkBuildMicromapFlagBitsEXT,
    VkClusterAccelerationStructureAddressResolutionFlagBitsNV,
    VkClusterAccelerationStructureClusterFlagBitsNV,
    VkClusterAccelerationStructureGeometryFlagBitsNV,
    VkClusterAccelerationStructureIndexFormatFlagBitsNV,
    VkColorComponentFlagBits,
    VkCommandBufferResetFlagBits,
    VkCommandBufferUsageFlagBits,
    VkCommandPoolCreateFlagBits,
    VkCommandPoolResetFlagBits,
    VkCompositeAlphaFlagBitsKHR,
    VkConditionalRenderingFlagBitsEXT,
    VkCullModeFlagBits,
    VkDataGraphOpticalFlowCreateFlagBitsARM,
    VkDataGraphOpticalFlowExecuteFlagBitsARM,
    VkDataGraphOpticalFlowGridSizeFlagBitsARM,
    VkDataGraphOpticalFlowImageUsageFlagBitsARM,
    VkDataGraphPipelineDispatchFlagBitsARM,
    VkDataGraphPipelineSessionCreateFlagBitsARM,
    VkDataGraphTOSAQualityFlagBitsARM,
    VkDebugReportFlagBitsEXT,
    VkDebugUtilsMessageSeverityFlagBitsEXT,
    VkDebugUtilsMessageTypeFlagBitsEXT,
    VkDependencyFlagBits,
    VkDescriptorBindingFlagBits,
    VkDescriptorPoolCreateFlagBits,
    VkDescriptorSetLayoutCreateFlagBits,
    VkDeviceAddressBindingFlagBitsEXT,
    VkDeviceDiagnosticsConfigFlagBitsNV,
    VkDeviceFaultFlagBitsKHR,
    VkDeviceGroupPresentModeFlagBitsKHR,
    VkDeviceQueueCreateFlagBits,
    VkDisplayPlaneAlphaFlagBitsKHR,
    VkEventCreateFlagBits,
    VkExportMetalObjectTypeFlagBitsEXT,
    VkExternalFenceFeatureFlagBits,
    VkExternalFenceHandleTypeFlagBits,
    VkExternalMemoryFeatureFlagBits,
    VkExternalMemoryFeatureFlagBitsNV,
    VkExternalMemoryHandleTypeFlagBits,
    VkExternalMemoryHandleTypeFlagBitsNV,
    VkExternalSemaphoreFeatureFlagBits,
    VkExternalSemaphoreHandleTypeFlagBits,
    VkFenceCreateFlagBits,
    VkFenceImportFlagBits,
    VkFormatFeatureFlagBits,
    VkFormatFeatureFlagBits2,
    VkFormatFeatureFlagBits4KHR,
    VkFrameBoundaryFlagBitsEXT,
    VkFramebufferCreateFlagBits,
    VkGeometryFlagBitsKHR,
    VkGeometryInstanceFlagBitsKHR,
    VkGpaSqShaderStageFlagBitsAMD,
    VkGraphicsPipelineLibraryFlagBitsEXT,
    VkHostImageCopyFlagBits,
    VkImageAspectFlagBits,
    VkImageCompressionFixedRateFlagBitsEXT,
    VkImageCompressionFlagBitsEXT,
    VkImageConstraintsInfoFlagBitsFUCHSIA,
    VkImageCreateFlagBits,
    VkImageCreateFlagBits2KHR,
    VkImageUsageFlagBits,
    VkImageUsageFlagBits2KHR,
    VkImageViewCreateFlagBits,
    VkIndirectCommandsInputModeFlagBitsEXT,
    VkIndirectCommandsLayoutUsageFlagBitsEXT,
    VkIndirectCommandsLayoutUsageFlagBitsNV,
    VkIndirectStateFlagBitsNV,
    VkInstanceCreateFlagBits,
    VkMemoryAllocateFlagBits,
    VkMemoryDecompressionMethodFlagBitsEXT,
    VkMemoryHeapFlagBits,
    VkMemoryMapFlagBits,
    VkMemoryPropertyFlagBits,
    VkMemoryUnmapFlagBits,
    VkMicromapCreateFlagBitsEXT,
    VkOpticalFlowExecuteFlagBitsNV,
    VkOpticalFlowGridSizeFlagBitsNV,
    VkOpticalFlowSessionCreateFlagBitsNV,
    VkOpticalFlowUsageFlagBitsNV,
    VkPartitionedAccelerationStructureInstanceFlagBitsNV,
    VkPastPresentationTimingFlagBitsEXT,
    VkPeerMemoryFeatureFlagBits,
    VkPerformanceCounterDescriptionFlagBitsKHR,
    VkPhysicalDeviceSchedulingControlsFlagBitsARM,
    VkPipelineCacheCreateFlagBits,
    VkPipelineColorBlendStateCreateFlagBits,
    VkPipelineCompilerControlFlagBitsAMD,
    VkPipelineCreateFlagBits,
    VkPipelineCreateFlagBits2,
    VkPipelineCreationFeedbackFlagBits,
    VkPipelineDepthStencilStateCreateFlagBits,
    VkPipelineLayoutCreateFlagBits,
    VkPipelineShaderStageCreateFlagBits,
    VkPipelineStageFlagBits,
    VkPipelineStageFlagBits2,
    VkPresentGravityFlagBitsKHR,
    VkPresentScalingFlagBitsKHR,
    VkPresentStageFlagBitsEXT,
    VkPresentTimingInfoFlagBitsEXT,
    VkQueryControlFlagBits,
    VkQueryPipelineStatisticFlagBits,
    VkQueryPoolCreateFlagBits,
    VkQueryResultFlagBits,
    VkQueueFlagBits,
    VkRenderPassCreateFlagBits,
    VkRenderingAttachmentFlagBitsKHR,
    VkRenderingFlagBits,
    VkResolveImageFlagBitsKHR,
    VkResolveModeFlagBits,
    VkSampleCountFlagBits,
    VkSamplerCreateFlagBits,
    VkSemaphoreImportFlagBits,
    VkSemaphoreWaitFlagBits,
    VkShaderCorePropertiesFlagBitsAMD,
    VkShaderCreateFlagBitsEXT,
    VkShaderStageFlagBits,
    VkSparseImageFormatFlagBits,
    VkSparseMemoryBindFlagBits,
    VkSpirvResourceTypeFlagBitsEXT,
    VkStencilFaceFlagBits,
    VkSubgroupFeatureFlagBits,
    VkSubmitFlagBits,
    VkSubpassDescriptionFlagBits,
    VkSurfaceCounterFlagBitsEXT,
    VkSurfaceTransformFlagBitsKHR,
    VkSwapchainCreateFlagBitsKHR,
    VkTensorCreateFlagBitsARM,
    VkTensorUsageFlagBitsARM,
    VkTensorViewCreateFlagBitsARM,
    VkTileShadingRenderPassFlagBitsQCOM,
    VkToolPurposeFlagBits,
    VkVideoCapabilityFlagBitsKHR,
    VkVideoChromaSubsamplingFlagBitsKHR,
    VkVideoCodecOperationFlagBitsKHR,
    VkVideoCodingControlFlagBitsKHR,
    VkVideoComponentBitDepthFlagBitsKHR,
    VkVideoDecodeCapabilityFlagBitsKHR,
    VkVideoDecodeH264PictureLayoutFlagBitsKHR,
    VkVideoDecodeUsageFlagBitsKHR,
    VkVideoEncodeAV1CapabilityFlagBitsKHR,
    VkVideoEncodeAV1RateControlFlagBitsKHR,
    VkVideoEncodeAV1StdFlagBitsKHR,
    VkVideoEncodeAV1SuperblockSizeFlagBitsKHR,
    VkVideoEncodeCapabilityFlagBitsKHR,
    VkVideoEncodeContentFlagBitsKHR,
    VkVideoEncodeFeedbackFlagBitsKHR,
    VkVideoEncodeFlagBitsKHR,
    VkVideoEncodeH264CapabilityFlagBitsKHR,
    VkVideoEncodeH264RateControlFlagBitsKHR,
    VkVideoEncodeH264StdFlagBitsKHR,
    VkVideoEncodeH265CapabilityFlagBitsKHR,
    VkVideoEncodeH265CtbSizeFlagBitsKHR,
    VkVideoEncodeH265RateControlFlagBitsKHR,
    VkVideoEncodeH265StdFlagBitsKHR,
    VkVideoEncodeH265TransformBlockSizeFlagBitsKHR,
    VkVideoEncodeIntraRefreshModeFlagBitsKHR,
    VkVideoEncodePerPartitionFeedbackFlagBitsKHR,
    VkVideoEncodeRateControlModeFlagBitsKHR,
    VkVideoEncodeRgbChromaOffsetFlagBitsVALVE,
    VkVideoEncodeRgbModelConversionFlagBitsVALVE,
    VkVideoEncodeRgbRangeCompressionFlagBitsVALVE,
    VkVideoEncodeUsageFlagBitsKHR,
    VkVideoSessionCreateFlagBitsKHR,
    VkVideoSessionParametersCreateFlagBitsKHR,
};

// Need underscore prefix to not conflict with namespace, but still easy to match generation
enum class Extension {
    Empty = 0,
    _VK_AMDX_dense_geometry_format,
    _VK_AMDX_shader_enqueue,
    _VK_AMD_anti_lag,
    _VK_AMD_buffer_marker,
    _VK_AMD_device_coherent_memory,
    _VK_AMD_display_native_hdr,
    _VK_AMD_draw_indirect_count,
    _VK_AMD_gcn_shader,
    _VK_AMD_gpa_interface,
    _VK_AMD_gpu_shader_half_float,
    _VK_AMD_gpu_shader_int16,
    _VK_AMD_memory_overallocation_behavior,
    _VK_AMD_mixed_attachment_samples,
    _VK_AMD_negative_viewport_height,
    _VK_AMD_pipeline_compiler_control,
    _VK_AMD_rasterization_order,
    _VK_AMD_shader_ballot,
    _VK_AMD_shader_core_properties,
    _VK_AMD_shader_core_properties2,
    _VK_AMD_shader_early_and_late_fragment_tests,
    _VK_AMD_shader_explicit_vertex_parameter,
    _VK_AMD_shader_fragment_mask,
    _VK_AMD_shader_image_load_store_lod,
    _VK_AMD_shader_info,
    _VK_AMD_shader_trinary_minmax,
    _VK_AMD_texture_gather_bias_lod,
    _VK_ANDROID_external_format_resolve,
    _VK_ANDROID_external_memory_android_hardware_buffer,
    _VK_ARM_data_graph,
    _VK_ARM_data_graph_instruction_set_tosa,
    _VK_ARM_data_graph_neural_accelerator_statistics,
    _VK_ARM_data_graph_optical_flow,
    _VK_ARM_format_pack,
    _VK_ARM_performance_counters_by_region,
    _VK_ARM_pipeline_opacity_micromap,
    _VK_ARM_rasterization_order_attachment_access,
    _VK_ARM_render_pass_striped,
    _VK_ARM_scheduling_controls,
    _VK_ARM_shader_core_builtins,
    _VK_ARM_shader_core_properties,
    _VK_ARM_shader_instrumentation,
    _VK_ARM_tensor_controls,
    _VK_ARM_tensors,
    _VK_EXT_4444_formats,
    _VK_EXT_acquire_drm_display,
    _VK_EXT_acquire_xlib_display,
    _VK_EXT_astc_decode_mode,
    _VK_EXT_attachment_feedback_loop_dynamic_state,
    _VK_EXT_attachment_feedback_loop_layout,
    _VK_EXT_blend_operation_advanced,
    _VK_EXT_border_color_swizzle,
    _VK_EXT_buffer_device_address,
    _VK_EXT_calibrated_timestamps,
    _VK_EXT_color_write_enable,
    _VK_EXT_conditional_rendering,
    _VK_EXT_conservative_rasterization,
    _VK_EXT_custom_border_color,
    _VK_EXT_custom_resolve,
    _VK_EXT_debug_marker,
    _VK_EXT_debug_report,
    _VK_EXT_debug_utils,
    _VK_EXT_depth_bias_control,
    _VK_EXT_depth_clamp_control,
    _VK_EXT_depth_clamp_zero_one,
    _VK_EXT_depth_clip_control,
    _VK_EXT_depth_clip_enable,
    _VK_EXT_depth_range_unrestricted,
    _VK_EXT_descriptor_buffer,
    _VK_EXT_descriptor_heap,
    _VK_EXT_descriptor_indexing,
    _VK_EXT_device_address_binding_report,
    _VK_EXT_device_fault,
    _VK_EXT_device_generated_commands,
    _VK_EXT_device_memory_report,
    _VK_EXT_direct_mode_display,
    _VK_EXT_directfb_surface,
    _VK_EXT_discard_rectangles,
    _VK_EXT_display_control,
    _VK_EXT_display_surface_counter,
    _VK_EXT_dynamic_rendering_unused_attachments,
    _VK_EXT_extended_dynamic_state,
    _VK_EXT_extended_dynamic_state2,
    _VK_EXT_extended_dynamic_state3,
    _VK_EXT_external_memory_acquire_unmodified,
    _VK_EXT_external_memory_dma_buf,
    _VK_EXT_external_memory_host,
    _VK_EXT_external_memory_metal,
    _VK_EXT_filter_cubic,
    _VK_EXT_fragment_density_map,
    _VK_EXT_fragment_density_map2,
    _VK_EXT_fragment_density_map_offset,
    _VK_EXT_fragment_shader_interlock,
    _VK_EXT_frame_boundary,
    _VK_EXT_full_screen_exclusive,
    _VK_EXT_global_priority,
    _VK_EXT_global_priority_query,
    _VK_EXT_graphics_pipeline_library,
    _VK_EXT_hdr_metadata,
    _VK_EXT_headless_surface,
    _VK_EXT_host_image_copy,
    _VK_EXT_host_query_reset,
    _VK_EXT_image_2d_view_of_3d,
    _VK_EXT_image_compression_control,
    _VK_EXT_image_compression_control_swapchain,
    _VK_EXT_image_drm_format_modifier,
    _VK_EXT_image_robustness,
    _VK_EXT_image_sliced_view_of_3d,
    _VK_EXT_image_view_min_lod,
    _VK_EXT_index_type_uint8,
    _VK_EXT_inline_uniform_block,
    _VK_EXT_layer_settings,
    _VK_EXT_legacy_dithering,
    _VK_EXT_legacy_vertex_attributes,
    _VK_EXT_line_rasterization,
    _VK_EXT_load_store_op_none,
    _VK_EXT_map_memory_placed,
    _VK_EXT_memory_budget,
    _VK_EXT_memory_decompression,
    _VK_EXT_memory_priority,
    _VK_EXT_mesh_shader,
    _VK_EXT_metal_objects,
    _VK_EXT_metal_surface,
    _VK_EXT_multi_draw,
    _VK_EXT_multisampled_render_to_single_sampled,
    _VK_EXT_multisampled_render_to_swapchain,
    _VK_EXT_mutable_descriptor_type,
    _VK_EXT_nested_command_buffer,
    _VK_EXT_non_seamless_cube_map,
    _VK_EXT_opacity_micromap,
    _VK_EXT_pageable_device_local_memory,
    _VK_EXT_pci_bus_info,
    _VK_EXT_physical_device_drm,
    _VK_EXT_pipeline_creation_cache_control,
    _VK_EXT_pipeline_creation_feedback,
    _VK_EXT_pipeline_library_group_handles,
    _VK_EXT_pipeline_properties,
    _VK_EXT_pipeline_protected_access,
    _VK_EXT_pipeline_robustness,
    _VK_EXT_post_depth_coverage,
    _VK_EXT_present_mode_fifo_latest_ready,
    _VK_EXT_present_timing,
    _VK_EXT_primitive_restart_index,
    _VK_EXT_primitive_topology_list_restart,
    _VK_EXT_primitives_generated_query,
    _VK_EXT_private_data,
    _VK_EXT_provoking_vertex,
    _VK_EXT_queue_family_foreign,
    _VK_EXT_rasterization_order_attachment_access,
    _VK_EXT_ray_tracing_invocation_reorder,
    _VK_EXT_rgba10x6_formats,
    _VK_EXT_robustness2,
    _VK_EXT_sample_locations,
    _VK_EXT_sampler_filter_minmax,
    _VK_EXT_scalar_block_layout,
    _VK_EXT_separate_stencil_usage,
    _VK_EXT_shader_64bit_indexing,
    _VK_EXT_shader_atomic_float,
    _VK_EXT_shader_atomic_float2,
    _VK_EXT_shader_demote_to_helper_invocation,
    _VK_EXT_shader_float8,
    _VK_EXT_shader_image_atomic_int64,
    _VK_EXT_shader_long_vector,
    _VK_EXT_shader_module_identifier,
    _VK_EXT_shader_object,
    _VK_EXT_shader_ocp_microscaling_types,
    _VK_EXT_shader_replicated_composites,
    _VK_EXT_shader_split_barrier,
    _VK_EXT_shader_stencil_export,
    _VK_EXT_shader_subgroup_ballot,
    _VK_EXT_shader_subgroup_partitioned,
    _VK_EXT_shader_subgroup_vote,
    _VK_EXT_shader_tile_image,
    _VK_EXT_shader_uniform_buffer_unsized_array,
    _VK_EXT_shader_viewport_index_layer,
    _VK_EXT_subgroup_size_control,
    _VK_EXT_subpass_merge_feedback,
    _VK_EXT_surface_maintenance1,
    _VK_EXT_swapchain_colorspace,
    _VK_EXT_swapchain_maintenance1,
    _VK_EXT_texel_buffer_alignment,
    _VK_EXT_texture_compression_astc_3d,
    _VK_EXT_texture_compression_astc_hdr,
    _VK_EXT_tooling_info,
    _VK_EXT_transform_feedback,
    _VK_EXT_validation_cache,
    _VK_EXT_validation_features,
    _VK_EXT_validation_flags,
    _VK_EXT_vertex_attribute_divisor,
    _VK_EXT_vertex_attribute_robustness,
    _VK_EXT_vertex_input_dynamic_state,
    _VK_EXT_ycbcr_2plane_444_formats,
    _VK_EXT_ycbcr_image_arrays,
    _VK_EXT_zero_initialize_device_memory,
    _VK_FUCHSIA_buffer_collection,
    _VK_FUCHSIA_external_memory,
    _VK_FUCHSIA_external_semaphore,
    _VK_FUCHSIA_imagepipe_surface,
    _VK_GGP_frame_token,
    _VK_GGP_stream_descriptor_surface,
    _VK_GOOGLE_decorate_string,
    _VK_GOOGLE_display_timing,
    _VK_GOOGLE_hlsl_functionality1,
    _VK_GOOGLE_surfaceless_query,
    _VK_GOOGLE_user_type,
    _VK_HUAWEI_cluster_culling_shader,
    _VK_HUAWEI_hdr_vivid,
    _VK_HUAWEI_invocation_mask,
    _VK_HUAWEI_subpass_shading,
    _VK_IMG_filter_cubic,
    _VK_IMG_filter_linear_2d,
    _VK_IMG_format_pvrtc,
    _VK_IMG_relaxed_line_rasterization,
    _VK_INTEL_performance_query,
    _VK_INTEL_shader_integer_functions2,
    _VK_KHR_16bit_storage,
    _VK_KHR_8bit_storage,
    _VK_KHR_acceleration_structure,
    _VK_KHR_android_surface,
    _VK_KHR_bind_memory2,
    _VK_KHR_buffer_device_address,
    _VK_KHR_calibrated_timestamps,
    _VK_KHR_compute_shader_derivatives,
    _VK_KHR_cooperative_matrix,
    _VK_KHR_copy_commands2,
    _VK_KHR_copy_memory_indirect,
    _VK_KHR_create_renderpass2,
    _VK_KHR_dedicated_allocation,
    _VK_KHR_deferred_host_operations,
    _VK_KHR_depth_clamp_zero_one,
    _VK_KHR_depth_stencil_resolve,
    _VK_KHR_descriptor_update_template,
    _VK_KHR_device_address_commands,
    _VK_KHR_device_fault,
    _VK_KHR_device_group,
    _VK_KHR_device_group_creation,
    _VK_KHR_display,
    _VK_KHR_display_swapchain,
    _VK_KHR_draw_indirect_count,
    _VK_KHR_driver_properties,
    _VK_KHR_dynamic_rendering,
    _VK_KHR_dynamic_rendering_local_read,
    _VK_KHR_extended_flags,
    _VK_KHR_external_fence,
    _VK_KHR_external_fence_capabilities,
    _VK_KHR_external_fence_fd,
    _VK_KHR_external_fence_win32,
    _VK_KHR_external_memory,
    _VK_KHR_external_memory_capabilities,
    _VK_KHR_external_memory_fd,
    _VK_KHR_external_memory_win32,
    _VK_KHR_external_semaphore,
    _VK_KHR_external_semaphore_capabilities,
    _VK_KHR_external_semaphore_fd,
    _VK_KHR_external_semaphore_win32,
    _VK_KHR_format_feature_flags2,
    _VK_KHR_fragment_shader_barycentric,
    _VK_KHR_fragment_shading_rate,
    _VK_KHR_get_display_properties2,
    _VK_KHR_get_memory_requirements2,
    _VK_KHR_get_physical_device_properties2,
    _VK_KHR_get_surface_capabilities2,
    _VK_KHR_global_priority,
    _VK_KHR_image_format_list,
    _VK_KHR_imageless_framebuffer,
    _VK_KHR_incremental_present,
    _VK_KHR_index_type_uint8,
    _VK_KHR_internally_synchronized_queues,
    _VK_KHR_line_rasterization,
    _VK_KHR_load_store_op_none,
    _VK_KHR_maintenance1,
    _VK_KHR_maintenance10,
    _VK_KHR_maintenance11,
    _VK_KHR_maintenance2,
    _VK_KHR_maintenance3,
    _VK_KHR_maintenance4,
    _VK_KHR_maintenance5,
    _VK_KHR_maintenance6,
    _VK_KHR_maintenance7,
    _VK_KHR_maintenance8,
    _VK_KHR_maintenance9,
    _VK_KHR_map_memory2,
    _VK_KHR_multiview,
    _VK_KHR_opacity_micromap,
    _VK_KHR_performance_query,
    _VK_KHR_pipeline_binary,
    _VK_KHR_pipeline_executable_properties,
    _VK_KHR_pipeline_library,
    _VK_KHR_portability_enumeration,
    _VK_KHR_portability_subset,
    _VK_KHR_present_id,
    _VK_KHR_present_id2,
    _VK_KHR_present_mode_fifo_latest_ready,
    _VK_KHR_present_wait,
    _VK_KHR_present_wait2,
    _VK_KHR_push_descriptor,
    _VK_KHR_ray_query,
    _VK_KHR_ray_tracing_maintenance1,
    _VK_KHR_ray_tracing_pipeline,
    _VK_KHR_ray_tracing_position_fetch,
    _VK_KHR_relaxed_block_layout,
    _VK_KHR_robustness2,
    _VK_KHR_sampler_mirror_clamp_to_edge,
    _VK_KHR_sampler_ycbcr_conversion,
    _VK_KHR_separate_depth_stencil_layouts,
    _VK_KHR_shader_abort,
    _VK_KHR_shader_atomic_int64,
    _VK_KHR_shader_bfloat16,
    _VK_KHR_shader_clock,
    _VK_KHR_shader_constant_data,
    _VK_KHR_shader_draw_parameters,
    _VK_KHR_shader_expect_assume,
    _VK_KHR_shader_float16_int8,
    _VK_KHR_shader_float_controls,
    _VK_KHR_shader_float_controls2,
    _VK_KHR_shader_fma,
    _VK_KHR_shader_integer_dot_product,
    _VK_KHR_shader_maximal_reconvergence,
    _VK_KHR_shader_non_semantic_info,
    _VK_KHR_shader_quad_control,
    _VK_KHR_shader_relaxed_extended_instruction,
    _VK_KHR_shader_subgroup_extended_types,
    _VK_KHR_shader_subgroup_rotate,
    _VK_KHR_shader_subgroup_uniform_control_flow,
    _VK_KHR_shader_terminate_invocation,
    _VK_KHR_shader_untyped_pointers,
    _VK_KHR_shared_presentable_image,
    _VK_KHR_spirv_1_4,
    _VK_KHR_storage_buffer_storage_class,
    _VK_KHR_surface,
    _VK_KHR_surface_maintenance1,
    _VK_KHR_surface_protected_capabilities,
    _VK_KHR_swapchain,
    _VK_KHR_swapchain_maintenance1,
    _VK_KHR_swapchain_mutable_format,
    _VK_KHR_synchronization2,
    _VK_KHR_timeline_semaphore,
    _VK_KHR_unified_image_layouts,
    _VK_KHR_uniform_buffer_standard_layout,
    _VK_KHR_variable_pointers,
    _VK_KHR_vertex_attribute_divisor,
    _VK_KHR_video_decode_av1,
    _VK_KHR_video_decode_h264,
    _VK_KHR_video_decode_h265,
    _VK_KHR_video_decode_queue,
    _VK_KHR_video_decode_vp9,
    _VK_KHR_video_encode_av1,
    _VK_KHR_video_encode_feedback2,
    _VK_KHR_video_encode_h264,
    _VK_KHR_video_encode_h265,
    _VK_KHR_video_encode_intra_refresh,
    _VK_KHR_video_encode_quantization_map,
    _VK_KHR_video_encode_queue,
    _VK_KHR_video_maintenance1,
    _VK_KHR_video_maintenance2,
    _VK_KHR_video_queue,
    _VK_KHR_vulkan_memory_model,
    _VK_KHR_wayland_surface,
    _VK_KHR_win32_keyed_mutex,
    _VK_KHR_win32_surface,
    _VK_KHR_workgroup_memory_explicit_layout,
    _VK_KHR_xcb_surface,
    _VK_KHR_xlib_surface,
    _VK_KHR_zero_initialize_workgroup_memory,
    _VK_LUNARG_direct_driver_loading,
    _VK_MESA_image_alignment_control,
    _VK_MSFT_layered_driver,
    _VK_MVK_ios_surface,
    _VK_MVK_macos_surface,
    _VK_NN_vi_surface,
    _VK_NVX_binary_import,
    _VK_NVX_image_view_handle,
    _VK_NVX_multiview_per_view_attributes,
    _VK_NV_acquire_winrt_display,
    _VK_NV_clip_space_w_scaling,
    _VK_NV_cluster_acceleration_structure,
    _VK_NV_command_buffer_inheritance,
    _VK_NV_compute_occupancy_priority,
    _VK_NV_compute_shader_derivatives,
    _VK_NV_cooperative_matrix,
    _VK_NV_cooperative_matrix2,
    _VK_NV_cooperative_matrix_decode_vector,
    _VK_NV_cooperative_vector,
    _VK_NV_copy_memory_indirect,
    _VK_NV_corner_sampled_image,
    _VK_NV_coverage_reduction_mode,
    _VK_NV_cuda_kernel_launch,
    _VK_NV_dedicated_allocation,
    _VK_NV_dedicated_allocation_image_aliasing,
    _VK_NV_descriptor_pool_overallocation,
    _VK_NV_device_diagnostic_checkpoints,
    _VK_NV_device_diagnostics_config,
    _VK_NV_device_generated_commands,
    _VK_NV_device_generated_commands_compute,
    _VK_NV_displacement_micromap,
    _VK_NV_display_stereo,
    _VK_NV_extended_sparse_address_space,
    _VK_NV_external_compute_queue,
    _VK_NV_external_memory,
    _VK_NV_external_memory_capabilities,
    _VK_NV_external_memory_rdma,
    _VK_NV_external_memory_win32,
    _VK_NV_fill_rectangle,
    _VK_NV_fragment_coverage_to_color,
    _VK_NV_fragment_shader_barycentric,
    _VK_NV_fragment_shading_rate_enums,
    _VK_NV_framebuffer_mixed_samples,
    _VK_NV_geometry_shader_passthrough,
    _VK_NV_glsl_shader,
    _VK_NV_inherited_viewport_scissor,
    _VK_NV_linear_color_attachment,
    _VK_NV_low_latency,
    _VK_NV_low_latency2,
    _VK_NV_memory_decompression,
    _VK_NV_mesh_shader,
    _VK_NV_optical_flow,
    _VK_NV_partitioned_acceleration_structure,
    _VK_NV_per_stage_descriptor_set,
    _VK_NV_present_barrier,
    _VK_NV_present_metering,
    _VK_NV_push_constant_bank,
    _VK_NV_raw_access_chains,
    _VK_NV_ray_tracing,
    _VK_NV_ray_tracing_invocation_reorder,
    _VK_NV_ray_tracing_linear_swept_spheres,
    _VK_NV_ray_tracing_motion_blur,
    _VK_NV_ray_tracing_validation,
    _VK_NV_representative_fragment_test,
    _VK_NV_sample_mask_override_coverage,
    _VK_NV_scissor_exclusive,
    _VK_NV_shader_atomic_float16_vector,
    _VK_NV_shader_image_footprint,
    _VK_NV_shader_sm_builtins,
    _VK_NV_shader_subgroup_partitioned,
    _VK_NV_shading_rate_image,
    _VK_NV_viewport_array2,
    _VK_NV_viewport_swizzle,
    _VK_NV_win32_keyed_mutex,
    _VK_OHOS_external_memory,
    _VK_OHOS_surface,
    _VK_QCOM_cooperative_matrix_conversion,
    _VK_QCOM_data_graph_model,
    _VK_QCOM_elapsed_timer_query,
    _VK_QCOM_filter_cubic_clamp,
    _VK_QCOM_filter_cubic_weights,
    _VK_QCOM_fragment_density_map_offset,
    _VK_QCOM_image_processing,
    _VK_QCOM_image_processing2,
    _VK_QCOM_image_processing3,
    _VK_QCOM_multiview_per_view_render_areas,
    _VK_QCOM_multiview_per_view_viewports,
    _VK_QCOM_queue_perf_hint,
    _VK_QCOM_render_pass_shader_resolve,
    _VK_QCOM_render_pass_store_ops,
    _VK_QCOM_render_pass_transform,
    _VK_QCOM_rotated_copy_commands,
    _VK_QCOM_shader_multiple_wait_queues,
    _VK_QCOM_tile_memory_heap,
    _VK_QCOM_tile_properties,
    _VK_QCOM_tile_shading,
    _VK_QCOM_ycbcr_degamma,
    _VK_QNX_external_memory_screen_buffer,
    _VK_QNX_screen_surface,
    _VK_SEC_amigo_profiling,
    _VK_SEC_pipeline_cache_incremental_mode,
    _VK_SEC_throttle_hint,
    _VK_SEC_ubm_surface,
    _VK_VALVE_descriptor_set_host_mapping,
    _VK_VALVE_fragment_density_map_layered,
    _VK_VALVE_mutable_descriptor_type,
    _VK_VALVE_shader_mixed_float_dot_product,
    _VK_VALVE_video_encode_rgb_conversion,
};

// Sometimes you know the requirement list doesn't contain any version values
typedef small_vector<vvl::Extension, 2, size_t> Extensions;

struct Requirement {
    const vvl::Extension extension;
    const vvl::Version version;

    Requirement(vvl::Extension extension_) : extension(extension_), version(vvl::Version::Empty) {}
    Requirement(vvl::Version version_) : extension(vvl::Extension::Empty), version(version_) {}
};
typedef small_vector<Requirement, 2, size_t> Requirements;

const char* String(Func func);
const char* String(Struct structure);
const char* String(Field field);
const char* String(Enum value);
const char* String(FlagBitmask value);
const char* String(Extension extension);
std::string String(const Extensions& extensions);
std::string String(const Requirement& requirement);
std::string String(const Requirements& requirements);

bool IsFieldPointer(Field field);

// Used for VUID maps were we only want the new function name
Func FindAlias(Func func);

// Used to help know which struct in a pNext chain is
Struct StypeToStruct(VkStructureType stype);

// The following are helpers to get the Field for a union look up
vvl::Field Field_VkDescriptorMappingSourceDataEXT(VkDescriptorMappingSourceEXT selector);
}  // namespace vvl
// NOLINTEND
